#define allocate 5
#define SYS_allocate 5
#define __NR_allocate 5
#define deallocate 6
#define SYS_deallocate 6
#define __NR_deallocate 6
#define fdwait 4
#define SYS_fdwait 4
#define __NR_fdwait 4
#define random 7
#define SYS_random 7
#define __NR_random 7
#define receive 3
#define SYS_receive 3
#define __NR_receive 3
#define terminate 1
#define SYS_terminate 1
#define __NR_terminate 1
#define transmit 2
#define SYS_transmit 2
#define __NR_transmit 2
