#define __NR_osf_syscall 0
#define __NR_exit 1
#define __NR_fork 2
#define __NR_read 3
#define __NR_write 4
#define __NR_osf_old_open 5
#define __NR_close 6
#define __NR_osf_wait4 7
#define __NR_osf_old_creat 8
#define __NR_link 9
#define __NR_unlink 10
#define __NR_osf_execve 11
#define __NR_chdir 12
#define __NR_fchdir 13
#define __NR_mknod 14
#define __NR_chmod 15
#define __NR_chown 16
#define __NR_brk 17
#define __NR_osf_getfsstat 18
#define __NR_lseek 19
#define __NR_getxpid 20
#define __NR_osf_mount 21
#define __NR_umount 22
#define __NR_setuid 23
#define __NR_getxuid 24
#define __NR_exec_with_loader 25
#define __NR_ptrace 26
#define __NR_osf_nrecvmsg 27
#define __NR_osf_nsendmsg 28
#define __NR_osf_nrecvfrom 29
#define __NR_osf_naccept 30
#define __NR_osf_ngetpeername 31
#define __NR_osf_ngetsockname 32
#define __NR_access 33
#define __NR_osf_chflags 34
#define __NR_osf_fchflags 35
#define __NR_sync 36
#define __NR_kill 37
#define __NR_osf_old_stat 38
#define __NR_setpgid 39
#define __NR_osf_old_lstat 40
#define __NR_dup 41
#define __NR_pipe 42
#define __NR_osf_set_program_attributes 43
#define __NR_osf_profil 44
#define __NR_open 45
#define __NR_osf_old_sigaction 46
#define __NR_getxgid 47
#define __NR_osf_sigprocmask 48
#define __NR_osf_getlogin 49
#define __NR_osf_setlogin 50
#define __NR_acct 51
#define __NR_sigpending 52
#define __NR_ioctl 54
#define __NR_osf_reboot 55
#define __NR_osf_revoke 56
#define __NR_symlink 57
#define __NR_readlink 58
#define __NR_execve 59
#define __NR_umask 60
#define __NR_chroot 61
#define __NR_osf_old_fstat 62
#define __NR_getpgrp 63
#define __NR_getpagesize 64
#define __NR_osf_mremap 65
#define __NR_vfork 66
#define __NR_stat 67
#define __NR_lstat 68
#define __NR_osf_sbrk 69
#define __NR_osf_sstk 70
#define __NR_mmap 71
#define __NR_osf_old_vadvise 72
#define __NR_munmap 73
#define __NR_mprotect 74
#define __NR_madvise 75
#define __NR_vhangup 76
#define __NR_osf_kmodcall 77
#define __NR_osf_mincore 78
#define __NR_getgroups 79
#define __NR_setgroups 80
#define __NR_osf_old_getpgrp 81
#define __NR_setpgrp 82
#define __NR_osf_setitimer 83
#define __NR_osf_old_wait 84
#define __NR_osf_table 85
#define __NR_osf_getitimer 86
#define __NR_gethostname 87
#define __NR_sethostname 88
#define __NR_getdtablesize 89
#define __NR_dup2 90
#define __NR_fstat 91
#define __NR_fcntl 92
#define __NR_osf_select 93
#define __NR_poll 94
#define __NR_fsync 95
#define __NR_setpriority 96
#define __NR_socket 97
#define __NR_connect 98
#define __NR_accept 99
#define __NR_getpriority 100
#define __NR_send 101
#define __NR_recv 102
#define __NR_sigreturn 103
#define __NR_bind 104
#define __NR_setsockopt 105
#define __NR_listen 106
#define __NR_osf_plock 107
#define __NR_osf_old_sigvec 108
#define __NR_osf_old_sigblock 109
#define __NR_osf_old_sigsetmask 110
#define __NR_sigsuspend 111
#define __NR_osf_sigstack 112
#define __NR_recvmsg 113
#define __NR_sendmsg 114
#define __NR_osf_old_vtrace 115
#define __NR_osf_gettimeofday 116
#define __NR_osf_getrusage 117
#define __NR_getsockopt 118
#define __NR_readv 120
#define __NR_writev 121
#define __NR_osf_settimeofday 122
#define __NR_fchown 123
#define __NR_fchmod 124
#define __NR_recvfrom 125
#define __NR_setreuid 126
#define __NR_setregid 127
#define __NR_rename 128
#define __NR_truncate 129
#define __NR_ftruncate 130
#define __NR_flock 131
#define __NR_setgid 132
#define __NR_sendto 133
#define __NR_shutdown 134
#define __NR_socketpair 135
#define __NR_mkdir 136
#define __NR_rmdir 137
#define __NR_osf_utimes 138
#define __NR_osf_old_sigreturn 139
#define __NR_osf_adjtime 140
#define __NR_getpeername 141
#define __NR_osf_gethostid 142
#define __NR_osf_sethostid 143
#define __NR_getrlimit 144
#define __NR_setrlimit 145
#define __NR_osf_old_killpg 146
#define __NR_setsid 147
#define __NR_quotactl 148
#define __NR_osf_oldquota 149
#define __NR_getsockname 150
#define __NR_osf_pid_block 153
#define __NR_osf_pid_unblock 154
#define __NR_sigaction 156
#define __NR_osf_sigwaitprim 157
#define __NR_osf_nfssvc 158
#define __NR_osf_getdirentries 159
#define __NR_osf_statfs 160
#define __NR_osf_fstatfs 161
#define __NR_osf_asynch_daemon 163
#define __NR_osf_getfh 164
#define __NR_osf_getdomainname 165
#define __NR_setdomainname 166
#define __NR_osf_exportfs 169
#define __NR_osf_alt_plock 181
#define __NR_osf_getmnt 184
#define __NR_osf_alt_sigpending 187
#define __NR_osf_alt_setsid 188
#define __NR_osf_swapon 199
#define __NR_msgctl 200
#define __NR_msgget 201
#define __NR_msgrcv 202
#define __NR_msgsnd 203
#define __NR_semctl 204
#define __NR_semget 205
#define __NR_semop 206
#define __NR_osf_utsname 207
#define __NR_lchown 208
#define __NR_osf_shmat 209
#define __NR_shmctl 210
#define __NR_shmdt 211
#define __NR_shmget 212
#define __NR_osf_mvalid 213
#define __NR_osf_getaddressconf 214
#define __NR_osf_msleep 215
#define __NR_osf_mwakeup 216
#define __NR_msync 217
#define __NR_osf_signal 218
#define __NR_osf_utc_gettime 219
#define __NR_osf_utc_adjtime 220
#define __NR_osf_security 222
#define __NR_osf_kloadcall 223
#define __NR_getpgid 233
#define __NR_getsid 234
#define __NR_sigaltstack 235
#define __NR_osf_waitid 236
#define __NR_osf_priocntlset 237
#define __NR_osf_sigsendset 238
#define __NR_osf_set_speculative 239
#define __NR_osf_msfs_syscall 240
#define __NR_osf_sysinfo 241
#define __NR_osf_uadmin 242
#define __NR_osf_fuser 243
#define __NR_osf_proplist_syscall 244
#define __NR_osf_ntp_adjtime 245
#define __NR_osf_ntp_gettime 246
#define __NR_osf_pathconf 247
#define __NR_osf_fpathconf 248
#define __NR_osf_uswitch 250
#define __NR_osf_usleep_thread 251
#define __NR_osf_audcntl 252
#define __NR_osf_audgen 253
#define __NR_sysfs 254
#define __NR_osf_subsys_info 255
#define __NR_osf_getsysinfo 256
#define __NR_osf_setsysinfo 257
#define __NR_osf_afs_syscall 258
#define __NR_osf_swapctl 259
#define __NR_osf_memcntl 260
#define __NR_osf_fdatasync 261
#define __NR_umount_with_flags 22
#define __NR_bdflush 300
#define __NR_sethae 301
#define __NR_mount 302
#define __NR_old_adjtimex 303
#define __NR_swapoff 304
#define __NR_getdents 305
#define __NR_create_module 306
#define __NR_init_module 307
#define __NR_delete_module 308
#define __NR_get_kernel_syms 309
#define __NR_syslog 310
#define __NR_reboot 311
#define __NR_clone 312
#define __NR_uselib 313
#define __NR_mlock 314
#define __NR_munlock 315
#define __NR_mlockall 316
#define __NR_munlockall 317
#define __NR_sysinfo 318
#define __NR__sysctl 319
#define __NR_oldumount 321
#define __NR_swapon 322
#define __NR_times 323
#define __NR_personality 324
#define __NR_setfsuid 325
#define __NR_setfsgid 326
#define __NR_ustat 327
#define __NR_statfs 328
#define __NR_fstatfs 329
#define __NR_sched_setparam 330
#define __NR_sched_getparam 331
#define __NR_sched_setscheduler 332
#define __NR_sched_getscheduler 333
#define __NR_sched_yield 334
#define __NR_sched_get_priority_max 335
#define __NR_sched_get_priority_min 336
#define __NR_sched_rr_get_interval 337
#define __NR_afs_syscall 338
#define __NR_uname 339
#define __NR_nanosleep 340
#define __NR_mremap 341
#define __NR_nfsservctl 342
#define __NR_setresuid 343
#define __NR_getresuid 344
#define __NR_pciconfig_read 345
#define __NR_pciconfig_write 346
#define __NR_query_module 347
#define __NR_prctl 348
#define __NR_pread 349
#define __NR_pwrite 350
#define __NR_rt_sigreturn 351
#define __NR_rt_sigaction 352
#define __NR_rt_sigprocmask 353
#define __NR_rt_sigpending 354
#define __NR_rt_sigtimedwait 355
#define __NR_rt_sigqueueinfo 356
#define __NR_rt_sigsuspend 357
#define __NR_select 358
#define __NR_gettimeofday 359
#define __NR_settimeofday 360
#define __NR_getitimer 361
#define __NR_setitimer 362
#define __NR_utimes 363
#define __NR_getrusage 364
#define __NR_wait4 365
#define __NR_adjtimex 366
#define __NR_getcwd 367
#define __NR_capget 368
#define __NR_capset 369
#define __NR_sendfile 370
#define __NR_setresgid 371
#define __NR_getresgid 372
#define __NR_dipc 373
#define __NR_pivot_root 374
#define __NR_mincore 375
#define __NR_pciconfig_iobase 376
#define __NR_getdents64 377
#define __NR_gettid 378
#define __NR_readahead 379
#define __NR_tkill 381
#define __NR_setxattr 382
#define __NR_lsetxattr 383
#define __NR_fsetxattr 384
#define __NR_getxattr 385
#define __NR_lgetxattr 386
#define __NR_fgetxattr 387
#define __NR_listxattr 388
#define __NR_llistxattr 389
#define __NR_flistxattr 390
#define __NR_removexattr 391
#define __NR_lremovexattr 392
#define __NR_fremovexattr 393
#define __NR_futex 394
#define __NR_sched_setaffinity 395
#define __NR_sched_getaffinity 396
#define __NR_tuxcall 397
#define __NR_io_setup 398
#define __NR_io_destroy 399
#define __NR_io_getevents 400
#define __NR_io_submit 401
#define __NR_io_cancel 402
#define __NR_exit_group 405
#define __NR_lookup_dcookie 406
#define __NR_sys_epoll_create 407
#define __NR_sys_epoll_ctl 408
#define __NR_sys_epoll_wait 409
#define __NR_remap_file_pages 410
#define __NR_set_tid_address 411
#define __NR_restart_syscall 412
#define __NR_fadvise64 413
#define __NR_timer_create 414
#define __NR_timer_settime 415
#define __NR_timer_gettime 416
#define __NR_timer_getoverrun 417
#define __NR_timer_delete 418
#define __NR_clock_settime 419
#define __NR_clock_gettime 420
#define __NR_clock_getres 421
#define __NR_clock_nanosleep 422
#define __NR_semtimedop 423
#define __NR_tgkill 424
#define __NR_stat64 425
#define __NR_lstat64 426
#define __NR_fstat64 427
#define __NR_vserver 428
#define __NR_mbind 429
#define __NR_get_mempolicy 430
#define __NR_set_mempolicy 431
#define __NR_mq_open 432
#define __NR_mq_unlink 433
#define __NR_mq_timedsend 434
#define __NR_mq_timedreceive 435
#define __NR_mq_notify 436
#define __NR_mq_getsetattr 437
#define __NR_waitid 438
#define __NR_add_key 439
#define __NR_request_key 440
#define __NR_keyctl 441
#define __NR_ioprio_set 442
#define __NR_ioprio_get 443
#define __NR_inotify_init 444
#define __NR_inotify_add_watch 445
#define __NR_inotify_rm_watch 446
#define __NR_fdatasync 447
#define __NR_kexec_load 448
#define __NR_migrate_pages 449
#define __NR_openat 450
#define __NR_mkdirat 451
#define __NR_mknodat 452
#define __NR_fchownat 453
#define __NR_futimesat 454
#define __NR_fstatat64 455
#define __NR_unlinkat 456
#define __NR_renameat 457
#define __NR_linkat 458
#define __NR_symlinkat 459
#define __NR_readlinkat 460
#define __NR_fchmodat 461
#define __NR_faccessat 462
#define __NR_pselect6 463
#define __NR_ppoll 464
#define __NR_unshare 465
#define __NR_set_robust_list 466
#define __NR_get_robust_list 467
#define __NR_splice 468
#define __NR_sync_file_range 469
#define __NR_tee 470
#define __NR_vmsplice 471
#define __NR_move_pages 472
#define __NR_getcpu 473
#define __NR_epoll_pwait 474
#define __NR_utimensat 475
#define __NR_signalfd 476
#define __NR_timerfd 477
#define __NR_eventfd 478
#define __NR_recvmmsg 479
#define __NR_fallocate 480
#define __NR_timerfd_create 481
#define __NR_timerfd_settime 482
#define __NR_timerfd_gettime 483
#define __NR_signalfd4 484
#define __NR_eventfd2 485
#define __NR_epoll_create1 486
#define __NR_dup3 487
#define __NR_pipe2 488
#define __NR_inotify_init1 489
#define __NR_preadv 490
#define __NR_pwritev 491
#define __NR_rt_tgsigqueueinfo 492
#define __NR_perf_event_open 493
#define __NR_fanotify_init 494
#define __NR_fanotify_mark 495
#define __NR_prlimit64 496
#define __NR_name_to_handle_at 497
#define __NR_open_by_handle_at 498
#define __NR_clock_adjtime 499
#define __NR_syncfs 500
#define __NR_setns 501
#define __NR_accept4 502
#define __NR_sendmmsg 503
#define __NR_process_vm_readv 504
#define __NR_process_vm_writev 505
#define __NR_kcmp 506
#define __NR_finit_module 507
#define __NR_sched_setattr 508
#define __NR_sched_getattr 509
#define __NR_renameat2 510
#define __NR_getrandom 511
#define __NR_memfd_create 512
#define __NR_execveat 513
#define __NR_seccomp 514
#define __NR_bpf 515
#define __NR_userfaultfd 516
#define __NR_membarrier 517
#define __NR_mlock2 518
#define __NR_copy_file_range 519
#define __NR_preadv2 520
#define __NR_pwritev2 521
#define __NR_statx 522
#define __NR_io_pgetevents 523
#define __NR_pkey_mprotect 524
#define __NR_pkey_alloc 525
#define __NR_pkey_free 526
#define __NR_rseq 527
#define __NR_statfs64 528
#define __NR_fstatfs64 529
#define __NR_getegid 530
#define __NR_geteuid 531
#define __NR_getppid 532
#define __NR_pidfd_send_signal 534
#define __NR_io_uring_setup 535
#define __NR_io_uring_enter 536
#define __NR_io_uring_register 537
#define __NR_open_tree 538
#define __NR_move_mount 539
#define __NR_fsopen 540
#define __NR_fsconfig 541
#define __NR_fsmount 542
#define __NR_fspick 543
#define __NR_pidfd_open 544
#define __NR_openat2 547
#define __NR_pidfd_getfd 548
#define MAP_32BIT 0x40
#define INADDR_ANY 0
#define INADDR_BROADCAST 0xffffffff
#define INADDR_NONE 0xffffffff
#define INADDR_LOOPBACK 0x7f000001
#define EPERM 1
#define ENOENT 2
#define ESRCH 3
#define EINTR 4
#define EIO 5
#define ENXIO 6
#define E2BIG 7
#define ENOEXEC 8
#define EBADF 9
#define ECHILD 10
#define EDEADLK 11
#define ENOMEM 12
#define EACCES 13
#define EFAULT 14
#define ENOTBLK 15
#define EBUSY 16
#define EEXIST 17
#define EXDEV 18
#define ENODEV 19
#define ENOTDIR 20
#define EISDIR 21
#define EINVAL 22
#define ENFILE 23
#define EMFILE 24
#define ENOTTY 25
#define ETXTBSY 26
#define EFBIG 27
#define ENOSPC 28
#define ESPIPE 29
#define EROFS 30
#define EMLINK 31
#define EPIPE 32
#define EDOM 33
#define ERANGE 34
#define EAGAIN 35
#define EWOULDBLOCK 35
#define EINPROGRESS 36
#define EALREADY 37
#define ENOTSOCK 38
#define EDESTADDRREQ 39
#define EMSGSIZE 40
#define EPROTOTYPE 41
#define ENOPROTOOPT 42
#define EPROTONOSUPPORT 43
#define ESOCKTNOSUPPORT 44
#define EOPNOTSUPP 45
#define ENOTSUP 45
#define EPFNOSUPPORT 46
#define EAFNOSUPPORT 47
#define EADDRINUSE 48
#define EADDRNOTAVAIL 49
#define ENETDOWN 50
#define ENETUNREACH 51
#define ENETRESET 52
#define ECONNABORTED 53
#define ECONNRESET 54
#define ENOBUFS 55
#define EISCONN 56
#define ENOTCONN 57
#define ESHUTDOWN 58
#define ETOOMANYREFS 59
#define ETIMEDOUT 60
#define ECONNREFUSED 61
#define ELOOP 62
#define ENAMETOOLONG 63
#define EHOSTDOWN 64
#define EHOSTUNREACH 65
#define ENOTEMPTY 66
#define EUSERS 68
#define EDQUOT 69
#define ESTALE 70
#define EREMOTE 71
#define ENOLCK 77
#define ENOSYS 78
#define ENOMSG 80
#define EIDRM 81
#define ENOSR 82
#define ETIME 83
#define EBADMSG 84
#define EPROTO 85
#define ENODATA 86
#define ENOSTR 87
#define ENOPKG 92
#define EILSEQ 116
#define ECHRNG 88
#define EL2NSYNC 89
#define EL3HLT 90
#define EL3RST 91
#define ELNRNG 93
#define EUNATCH 94
#define ENOCSI 95
#define EL2HLT 96
#define EBADE 97
#define EBADR 98
#define EXFULL 99
#define ENOANO 100
#define EBADRQC 101
#define EBADSLT 102
#define EDEADLOCK 11
#define EBFONT 104
#define ENONET 105
#define ENOLINK 106
#define EADV 107
#define ESRMNT 108
#define ECOMM 109
#define EMULTIHOP 110
#define EDOTDOT 111
#define EOVERFLOW 112
#define ENOTUNIQ 113
#define EBADFD 114
#define EREMCHG 115
#define EUCLEAN 117
#define ENOTNAM 118
#define ENAVAIL 119
#define EISNAM 120
#define EREMOTEIO 121
#define ELIBACC 122
#define ELIBBAD 123
#define ELIBSCN 124
#define ELIBMAX 125
#define ELIBEXEC 126
#define ERESTART 127
#define ESTRPIPE 128
#define ENOMEDIUM 129
#define EMEDIUMTYPE 130
#define ECANCELED 131
#define ENOKEY 132
#define EKEYEXPIRED 133
#define EKEYREVOKED 134
#define EKEYREJECTED 135
#define EOWNERDEAD 136
#define ENOTRECOVERABLE 137
#define ERFKILL 138
#define EHWPOISON 139
#define __SYS_NERR ((139) + 1)
#define __LITTLE_ENDIAN 1234
#define __BIG_ENDIAN 4321
#define __BYTE_ORDER 1234
#define __FLOAT_WORD_ORDER 1234
#define LITTLE_ENDIAN 1234
#define BIG_ENDIAN 4321
#define BYTE_ORDER 1234
#define __WORDSIZE 64
#define INT8_MAX (127)
#define INT16_MAX (32767)
#define INT32_MAX (2147483647)
#define INT64_MAX (9223372036854775807)
#define INT8_MIN (-1 - (127))
#define INT16_MIN (-1 - (32767))
#define INT32_MIN (-1 - (2147483647))
#define INT64_MIN (-1 - (9223372036854775807))
#define INT_LEAST8_MAX (127)
#define INT_LEAST8_MIN (-1 - (127))
#define INT_LEAST16_MAX (32767)
#define INT_LEAST16_MIN (-1 - (32767))
#define INT_LEAST32_MAX (2147483647)
#define INT_LEAST32_MIN (-1 - (2147483647))
#define INT_LEAST64_MAX (9223372036854775807)
#define INT_LEAST64_MIN (-1 - (9223372036854775807))
#define UINT8_MAX 0xff
#define UINT16_MAX 0xffff
#define UINT32_MAX 0xffffffff
#define UINT64_MAX 0xffffffffffffffff
#define UINT_LEAST8_MAX 0xff
#define UINT_LEAST16_MAX 0xffff
#define UINT_LEAST32_MAX 0xffffffff
#define UINT_LEAST64_MAX 0xffffffffffffffff
#define INTPTR_MIN (-1 - (9223372036854775807))
#define INTPTR_MAX (9223372036854775807)
#define UINTPTR_MAX 0xffffffffffffffff
#define SIZE_MAX 0xffffffffffffffff
#define PTRDIFF_MIN (-1 - (9223372036854775807))
#define PTRDIFF_MAX (9223372036854775807)
#define INTMAX_MIN (-1 - (9223372036854775807))
#define INTMAX_MAX (9223372036854775807)
#define UINTMAX_MAX 0xffffffffffffffff
#define INT_FAST8_MIN (-1 - (127))
#define INT_FAST8_MAX (127)
#define INT_FAST64_MIN (-1 - (9223372036854775807))
#define INT_FAST64_MAX (9223372036854775807)
#define UINT_FAST8_MAX 0xff
#define UINT_FAST64_MAX 0xffffffffffffffff
#define INT_FAST16_MIN (-1 - (9223372036854775807))
#define INT_FAST16_MAX (9223372036854775807)
#define UINT_FAST16_MAX 0xffffffffffffffff
#define INT_FAST32_MIN (-1 - (9223372036854775807))
#define INT_FAST32_MAX (9223372036854775807)
#define UINT_FAST32_MAX 0xffffffffffffffff
#define WINT_MIN 0
#define __FSUID_H 1
#define NSIG 32
#define _NSIG 65
#define SIGHUP 1
#define SIGINT 2
#define SIGQUIT 3
#define SIGILL 4
#define SIGTRAP 5
#define SIGABRT 6
#define SIGIOT 6
#define SIGFPE 8
#define SIGKILL 9
#define SIGSEGV 11
#define SIGPIPE 13
#define SIGALRM 14
#define SIGTERM 15
#define SIGUNUSED 31
#define SIGEMT 7
#define SIGBUS 10
#define SIGSYS 12
#define SIGURG 16
#define SIGSTOP 17
#define SIGTSTP 18
#define SIGCONT 19
#define SIGCHLD 20
#define SIGTTIN 21
#define SIGTTOU 22
#define SIGIO 23
#define SIGXCPU 24
#define SIGXFSZ 25
#define SIGVTALRM 26
#define SIGPROF 27
#define SIGWINCH 28
#define SIGPWR 29
#define SIGUSR1 30
#define SIGUSR2 31
#define SIGINFO 29
#define SIGCLD 20
#define SIGPOLL 23
#define SIGLOST 29
#define SIGRTMIN 32
#define SIGRTMAX (65-1)
#define SA_ONSTACK 0x00000001
#define SA_RESTART 0x00000002
#define SA_NOCLDSTOP 0x00000004
#define SA_NODEFER 0x00000008
#define SA_RESETHAND 0x00000010
#define SA_NOCLDWAIT 0x00000020
#define SA_SIGINFO 0x00000040
#define SA_INTERRUPT 0x20000000
#define SA_NOMASK 0x00000008
#define SA_ONESHOT 0x00000010
#define SS_ONSTACK 1
#define SS_DISABLE 2
#define MINSIGSTKSZ 2048
#define SIGSTKSZ 8192
#define SIG_BLOCK 1
#define SIG_UNBLOCK 2
#define SIG_SETMASK 3
#define SI_MAX_SIZE 128
#define SIGEV_SIGNAL 0
#define SIGEV_NONE 1
#define SIGEV_THREAD 2
#define SIGEV_THREAD_ID 4
#define SIGEV_MAX_SIZE 64
#define _SYS_TIME_H 1
#define ITIMER_REAL 0
#define ITIMER_VIRTUAL 1
#define ITIMER_PROF 2
#define FD_SETSIZE 1024
#define R_OK 4
#define W_OK 2
#define X_OK 1
#define F_OK 0
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
#define STDIN_FILENO 0
#define STDOUT_FILENO 1
#define STDERR_FILENO 2
#define _CS_PATH 1
#define _SC_CLK_TCK 1
#define _SC_ARG_MAX 2
#define _SC_NGROUPS_MAX 3
#define _SC_OPEN_MAX 4
#define _SC_PAGESIZE 5
#define _SC_NPROCESSORS_ONLN 6
#define _SC_NPROCESSORS_CONF 6
#define _SC_PHYS_PAGES 7
#define _SC_GETPW_R_SIZE_MAX 8
#define _SC_GETGR_R_SIZE_MAX 9
#define _PC_PATH_MAX 1
#define _PC_VDISABLE 2
#define L_cuserid 17
#define _POSIX_VERSION 199506
#define F_ULOCK 0
#define F_LOCK 1
#define F_TLOCK 2
#define F_TEST 3
#define _POSIX_MAPPED_FILES 200809
#define S_IFMT 0xf000
#define S_IFSOCK 0xc000
#define S_IFLNK 0xa000
#define S_IFREG 0x8000
#define S_IFBLK 0x6000
#define S_IFDIR 0x4000
#define S_IFCHR 0x2000
#define S_IFIFO 0x1000
#define S_ISUID 0x800
#define S_ISGID 0x400
#define S_ISVTX 0x200
#define S_IRWXU 0x1c0
#define S_IRUSR 0x100
#define S_IWUSR 0x80
#define S_IXUSR 0x40
#define S_IRWXG 0x38
#define S_IRGRP 0x20
#define S_IWGRP 0x10
#define S_IXGRP 0x8
#define S_IRWXO 0x7
#define S_IROTH 0x4
#define S_IWOTH 0x2
#define S_IXOTH 0x1
#define S_IREAD 0x100
#define S_IWRITE 0x80
#define S_IEXEC 0x40
#define _SYS_UIO 1
#define SOL_SOCKET 0xffff
#define SO_DEBUG 0x0001
#define SO_REUSEADDR 0x0004
#define SO_KEEPALIVE 0x0008
#define SO_DONTROUTE 0x0010
#define SO_BROADCAST 0x0020
#define SO_LINGER 0x0080
#define SO_OOBINLINE 0x0100
#define SO_REUSEPORT 0x0200
#define SO_TYPE 0x1008
#define SO_ERROR 0x1007
#define SO_SNDBUF 0x1001
#define SO_RCVBUF 0x1002
#define SO_NO_CHECK 11
#define SO_PRIORITY 12
#define SO_BSDCOMPAT 14
#define SO_PASSCRED 17
#define SO_PEERCRED 18
#define SO_SECURITY_AUTHENTICATION 19
#define SO_SECURITY_ENCRYPTION_TRANSPORT 20
#define SO_SECURITY_ENCRYPTION_NETWORK 21
#define SO_BINDTODEVICE 25
#define SO_ATTACH_FILTER 26
#define SO_DETACH_FILTER 27
#define SO_GET_FILTER 26
#define SO_PEERNAME 28
#define SO_TIMESTAMP 29
#define SCM_TIMESTAMP 29
#define SO_PEERSEC 30
#define SO_PASSSEC 34
#define SO_TIMESTAMPNS 35
#define SCM_TIMESTAMPNS 35
#define SO_MARK 36
#define SO_TIMESTAMPING 37
#define SCM_TIMESTAMPING 37
#define SO_RXQ_OVFL 40
#define SO_WIFI_STATUS 41
#define SCM_WIFI_STATUS 41
#define SO_PEEK_OFF 42
#define SO_NOFCS 43
#define SO_LOCK_FILTER 44
#define SO_SELECT_ERR_QUEUE 45
#define SO_BUSY_POLL 46
#define SO_MAX_PACING_RATE 47
#define SO_BPF_EXTENSIONS 48
#define SO_INCOMING_CPU 49
#define SO_ATTACH_BPF 50
#define SO_DETACH_BPF 27
#define SO_ATTACH_REUSEPORT_CBPF 51
#define SO_ATTACH_REUSEPORT_EBPF 52
#define SO_CNX_ADVICE 53
#define SCM_TIMESTAMPING_OPT_STATS 54
#define SO_MEMINFO 55
#define SO_INCOMING_NAPI_ID 56
#define SO_COOKIE 57
#define SCM_TIMESTAMPING_PKTINFO 58
#define SO_PEERGROUPS 59
#define SO_ZEROCOPY 60
#define SO_SNDBUFFORCE 0x100a
#define SO_RCVBUFFORCE 0x100b
#define SO_RCVLOWAT 0x1010
#define SO_SNDLOWAT 0x1011
#define SO_RCVTIMEO 0x1012
#define SO_SNDTIMEO 0x1013
#define SO_ACCEPTCONN 0x1014
#define SO_PROTOCOL 0x1028
#define SO_DOMAIN 0x1029
#define SO_STYLE 0x1008
#define SOCK_NONBLOCK 0x40000000
#define SOCK_STREAM 1
#define SOCK_DGRAM 2
#define SOCK_RAW 3
#define SOCK_RDM 4
#define SOCK_SEQPACKET 5
#define SOCK_DCCP 6
#define SOCK_PACKET 10
#define UIO_FASTIOV 8
#define UIO_MAXIOV 1024
#define SCM_RIGHTS 0x01
#define SCM_CREDENTIALS 0x02
#define SCM_CONNECT 0x03
#define AF_UNSPEC 0
#define AF_UNIX 1
#define AF_LOCAL 1
#define AF_INET 2
#define AF_AX25 3
#define AF_IPX 4
#define AF_APPLETALK 5
#define AF_NETROM 6
#define AF_BRIDGE 7
#define AF_ATMPVC 8
#define AF_X25 9
#define AF_INET6 10
#define AF_ROSE 11
#define AF_DECnet 12
#define AF_NETBEUI 13
#define AF_SECURITY 14
#define AF_KEY 15
#define AF_NETLINK 16
#define AF_ROUTE 16
#define AF_PACKET 17
#define AF_ASH 18
#define AF_ECONET 19
#define AF_ATMSVC 20
#define AF_SNA 22
#define AF_IRDA 23
#define AF_PPPOX 24
#define AF_WANPIPE 25
#define AF_LLC 26
#define AF_IB 27
#define AF_MPLS 28
#define AF_CAN 29
#define AF_TIPC 30
#define AF_BLUETOOTH 31
#define AF_IUCV 32
#define AF_RXRPC 33
#define AF_ISDN 34
#define AF_PHONET 35
#define AF_IEEE802154 36
#define AF_CAIF 37
#define AF_ALG 38
#define AF_NFC 39
#define AF_VSOCK 40
#define AF_KCM 41
#define AF_QIPCRTR 42
#define AF_SMC 43
#define AF_MAX 44
#define PF_UNSPEC 0
#define PF_UNIX 1
#define PF_LOCAL 1
#define PF_INET 2
#define PF_AX25 3
#define PF_IPX 4
#define PF_APPLETALK 5
#define PF_NETROM 6
#define PF_BRIDGE 7
#define PF_ATMPVC 8
#define PF_X25 9
#define PF_INET6 10
#define PF_ROSE 11
#define PF_DECnet 12
#define PF_NETBEUI 13
#define PF_SECURITY 14
#define PF_KEY 15
#define PF_NETLINK 16
#define PF_ROUTE 16
#define PF_PACKET 17
#define PF_ASH 18
#define PF_ECONET 19
#define PF_ATMSVC 20
#define PF_SNA 22
#define PF_IRDA 23
#define PF_PPPOX 24
#define PF_WANPIPE 25
#define PF_LLC 26
#define PF_IB 27
#define PF_MPLS 28
#define PF_CAN 29
#define PF_TIPC 30
#define PF_BLUETOOTH 31
#define PF_IUCV 32
#define PF_RXRPC 33
#define PF_ISDN 34
#define PF_PHONET 35
#define PF_IEEE802154 36
#define PF_CAIF 37
#define PF_ALG 38
#define PF_NFC 39
#define PF_VSOCK 40
#define PF_KCM 41
#define PF_QIPCRTR 42
#define PF_SMC 43
#define PF_MAX 44
#define SOMAXCONN 128
#define MSG_OOB 1
#define MSG_PEEK 2
#define MSG_DONTROUTE 4
#define MSG_TRYHARD 4
#define MSG_CTRUNC 8
#define MSG_PROBE 0x10
#define MSG_TRUNC 0x20
#define MSG_DONTWAIT 0x40
#define MSG_EOR 0x80
#define MSG_WAITALL 0x100
#define MSG_FIN 0x200
#define MSG_SYN 0x400
#define MSG_CONFIRM 0x800
#define MSG_RST 0x1000
#define MSG_ERRQUEUE 0x2000
#define MSG_NOSIGNAL 0x4000
#define MSG_MORE 0x8000
#define MSG_WAITFORONE 0x10000
#define MSG_SENDPAGE_NOTLAST 0x20000
#define MSG_BATCH 0x40000
#define MSG_EOF 0x200
#define MSG_ZEROCOPY 0x4000000
#define MSG_FASTOPEN 0x20000000
#define MSG_CMSG_CLOEXEC 0x40000000
#define SOL_IP 0
#define SOL_TCP 6
#define SOL_UDP 17
#define SOL_IPV6 41
#define SOL_ICMPV6 58
#define SOL_SCTP 132
#define SOL_UDPLITE 136
#define SOL_RAW 255
#define SOL_IPX 256
#define SOL_AX25 257
#define SOL_ATALK 258
#define SOL_NETROM 259
#define SOL_ROSE 260
#define SOL_DECNET 261
#define SOL_X25 262
#define SOL_PACKET 263
#define SOL_ATM 264
#define SOL_AAL 265
#define SOL_IRDA 266
#define SOL_NETBEUI 267
#define SOL_LLC 268
#define SOL_DCCP 269
#define SOL_NETLINK 270
#define SOL_TIPC 271
#define SOL_RXRPC 272
#define SOL_PPPOL2TP 273
#define SOL_BLUETOOTH 274
#define SOL_PNPIPE 275
#define SOL_RDS 276
#define SOL_IUCV 277
#define SOL_CAIF 278
#define SOL_ALG 279
#define SOL_NFC 280
#define SOL_KCM 281
#define SOL_TLS 282
#define IPX_TYPE 1
#define SHUT_RD 0
#define SHUT_WR 1
#define SHUT_RDWR 2
#define NI_NOFQDN 1
#define NI_NUMERICHOST 2
#define NI_NAMEREQD 4
#define NI_NUMERICSERV 8
#define NI_DGRAM 16
#define EAI_FAMILY -1
#define EAI_SOCKTYPE -2
#define EAI_BADFLAGS -3
#define EAI_NONAME -4
#define EAI_SERVICE -5
#define EAI_ADDRFAMILY -6
#define EAI_NODATA -7
#define EAI_MEMORY -8
#define EAI_FAIL -9
#define EAI_AGAIN -10
#define EAI_SYSTEM -11
#define AI_NUMERICHOST 1
#define AI_CANONNAME 2
#define AI_PASSIVE 4
#define AI_NUMERICSERV 8
#define AI_ADDRCONFIG 16
#define AI_V4MAPPED 32
#define AI_ALL 64
#define SIOCADDRT 0x890B
#define SIOCDELRT 0x890C
#define SIOCRTMSG 0x890D
#define SIOCGIFNAME 0x8910
#define SIOCSIFLINK 0x8911
#define SIOCGIFCONF 0x8912
#define SIOCGIFFLAGS 0x8913
#define SIOCSIFFLAGS 0x8914
#define SIOCGIFADDR 0x8915
#define SIOCSIFADDR 0x8916
#define SIOCGIFDSTADDR 0x8917
#define SIOCSIFDSTADDR 0x8918
#define SIOCGIFBRDADDR 0x8919
#define SIOCSIFBRDADDR 0x891a
#define SIOCGIFNETMASK 0x891b
#define SIOCSIFNETMASK 0x891c
#define SIOCGIFMETRIC 0x891d
#define SIOCSIFMETRIC 0x891e
#define SIOCGIFMEM 0x891f
#define SIOCSIFMEM 0x8920
#define SIOCGIFMTU 0x8921
#define SIOCSIFMTU 0x8922
#define SIOCSIFNAME 0x8923
#define SIOCSIFHWADDR 0x8924
#define SIOCGIFENCAP 0x8925
#define SIOCSIFENCAP 0x8926
#define SIOCGIFHWADDR 0x8927
#define SIOCGIFSLAVE 0x8929
#define SIOCSIFSLAVE 0x8930
#define SIOCADDMULTI 0x8931
#define SIOCDELMULTI 0x8932
#define SIOCGIFINDEX 0x8933
#define SIOGIFINDEX 0x8933
#define SIOCSIFPFLAGS 0x8934
#define SIOCGIFPFLAGS 0x8935
#define SIOCDIFADDR 0x8936
#define SIOCSIFHWBROADCAST 0x8937
#define SIOCGIFCOUNT 0x8938
#define SIOCGIFBR 0x8940
#define SIOCSIFBR 0x8941
#define SIOCGIFTXQLEN 0x8942
#define SIOCSIFTXQLEN 0x8943
#define SIOCGIFDIVERT 0x8944
#define SIOCSIFDIVERT 0x8945
#define SIOCETHTOOL 0x8946
#define SIOCDARP 0x8953
#define SIOCGARP 0x8954
#define SIOCSARP 0x8955
#define SIOCDRARP 0x8960
#define SIOCGRARP 0x8961
#define SIOCSRARP 0x8962
#define SIOCGIFMAP 0x8970
#define SIOCSIFMAP 0x8971
#define SIOCADDDLCI 0x8980
#define SIOCDELDLCI 0x8981
#define SIOCDEVPRIVATE 0x89F0
#define F_LINUX_SPECIFIC_BASE 1024
#define O_ACCMODE 0x3
#define O_RDONLY 0x0
#define O_WRONLY 0x1
#define O_RDWR 0x2
#define O_CREAT 0x200
#define O_TRUNC 0x400
#define O_EXCL 0x800
#define O_NOCTTY 0x1000
#define O_NONBLOCK 0x4
#define O_APPEND 0x8
#define O_NDELAY 0x4
#define O_DSYNC 0x4000
#define FASYNC 0x2000
#define O_DIRECTORY 0x8000
#define O_NOFOLLOW 0x10000
#define O_LARGEFILE 0x20000
#define O_DIRECT 0x80000
#define O_NOATIME 0x100000
#define O_CLOEXEC 0x200000
#define O_SYNC 0x404000
#define O_PATH 0x800000
#define __O_TMPFILE 0x1000000
#define F_DUPFD 0
#define F_GETFD 1
#define F_SETFD 2
#define F_GETFL 3
#define F_SETFL 4
#define F_GETLK 7
#define F_SETLK 8
#define F_SETLKW 9
#define F_SETOWN 5
#define F_GETOWN 6
#define F_SETSIG 10
#define F_GETSIG 11
#define FD_CLOEXEC 1
#define F_RDLCK 1
#define F_WRLCK 2
#define F_UNLCK 8
#define F_EXLCK 16
#define F_SHLCK 32
#define F_INPROGRESS 64
#define LOCK_SH 1
#define LOCK_EX 2
#define LOCK_NB 4
#define LOCK_UN 8
#define LOCK_MAND 32
#define LOCK_READ 64
#define LOCK_WRITE 128
#define LOCK_RW 192
#define O_TMPFILE 0x1008000
#define O_ASYNC 0x2000
#define F_SETOWN_EX 15
#define F_GETOWN_EX 16
#define F_GETOWNER_UIDS 17
#define F_OFD_GETLK 36
#define F_OFD_SETLK 37
#define F_OFD_SETLKW 38
#define F_OWNER_TID 0
#define F_OWNER_PID 1
#define F_OWNER_PGRP 2
#define AT_FDCWD -100
#define AT_SYMLINK_NOFOLLOW 0x100
#define AT_REMOVEDIR 0x200
#define AT_SYMLINK_FOLLOW 0x400
#define AT_NO_AUTOMOUNT 0x800
#define AT_EMPTY_PATH 0x1000
#define AT_EACCESS 0x200
#define MREMAP_MAYMOVE 1
#define MREMAP_FIXED 2
#define PROT_READ 0x1
#define PROT_WRITE 0x2
#define PROT_EXEC 0x4
#define PROT_SEM 0x8
#define PROT_NONE 0x0
#define PROT_GROWSDOWN 0x01000000
#define PROT_GROWSUP 0x02000000
#define MAP_SHARED 0x01
#define MAP_PRIVATE 0x02
#define MAP_TYPE 0xf
#define MADV_REMOVE 9
#define MADV_DONTFORK 10
#define MADV_DOFORK 11
#define MADV_MERGEABLE 12
#define MADV_UNMERGEABLE 13
#define MADV_HUGEPAGE 14
#define MADV_NOHUGEPAGE 15
#define MADV_DONTDUMP 16
#define MADV_DODUMP 17
#define MADV_HWPOISON 100
#define MADV_SOFT_OFFLINE 101
#define MLOCK_ONFAULT 1
#define MAP_FIXED 0x100
#define MAP_ANONYMOUS 0x10
#define MAP_GROWSDOWN 0x1000
#define MAP_DENYWRITE 0x2000
#define MAP_EXECUTABLE 0x4000
#define MAP_LOCKED 0x8000
#define MAP_NORESERVE 0x10000
#define MAP_POPULATE 0x20000
#define MAP_NONBLOCK 0x40000
#define MAP_STACK 0x80000
#define MAP_HUGETLB 0x100000
#define MS_ASYNC 1
#define MS_SYNC 2
#define MS_INVALIDATE 4
#define MCL_CURRENT 8192
#define MCL_FUTURE 16384
#define MCL_ONFAULT 32768
#define MADV_NORMAL 0
#define MADV_RANDOM 1
#define MADV_SEQUENTIAL 2
#define MADV_WILLNEED 3
#define MADV_SPACEAVAIL 5
#define MADV_DONTNEED 6
#define MAP_ANON 0x10
#define MAP_FILE 0
#define POSIX_MADV_NORMAL 0
#define POSIX_MADV_SEQUENTIAL 2
#define POSIX_MADV_RANDOM 1
#define POSIX_MADV_WILLNEED 3
#define POSIX_MADV_DONTNEED 6
#define PTRACE_TRACEME 0
#define PTRACE_PEEKTEXT 1
#define PTRACE_PEEKDATA 2
#define PTRACE_PEEKUSR 3
#define PTRACE_PEEKUSER 3
#define PTRACE_POKETEXT 4
#define PTRACE_POKEDATA 5
#define PTRACE_POKEUSR 6
#define PTRACE_POKEUSER 6
#define PTRACE_CONT 7
#define PTRACE_KILL 8
#define PTRACE_SINGLESTEP 9
#define PTRACE_ATTACH 0x10
#define PTRACE_DETACH 0x11
#define PTRACE_SYSCALL 24
#define PTRACE_GETEVENTMSG 0x4201
#define PTRACE_GETSIGINFO 0x4202
#define PTRACE_SETSIGINFO 0x4203
#define PTRACE_O_TRACESYSGOOD 0x00000001
#define PTRACE_O_TRACEFORK 0x00000002
#define PTRACE_O_TRACEVFORK 0x00000004
#define PTRACE_O_TRACECLONE 0x00000008
#define PTRACE_O_TRACEEXEC 0x00000010
#define PTRACE_O_TRACEVFORKDONE 0x00000020
#define PTRACE_O_TRACEEXIT 0x00000040
#define PTRACE_O_MASK 0x0000007f
#define PTRACE_EVENT_FORK 1
#define PTRACE_EVENT_VFORK 2
#define PTRACE_EVENT_CLONE 3
#define PTRACE_EVENT_EXEC 4
#define PTRACE_EVENT_VFORK_DONE 5
#define PTRACE_EVENT_EXIT 6
#define PT_TRACE_ME 0
#define PT_READ_I 1
#define PT_READ_D 2
#define PT_READ_U 3
#define PT_WRITE_I 4
#define PT_WRITE_D 5
#define PT_WRITE_U 6
#define PT_CONTINUE 7
#define PT_KILL 8
#define PT_STEP 9
#define PT_ATTACH 0x10
#define PT_DETACH 0x11
#define SYS_accept 99
#define SYS_accept4 502
#define SYS_access 33
#define SYS_acct 51
#define SYS_add_key 439
#define SYS_adjtimex 366
#define SYS_afs_syscall 338
#define SYS_bdflush 300
#define SYS_bind 104
#define SYS_bpf 515
#define SYS_brk 17
#define SYS_capget 368
#define SYS_capset 369
#define SYS_chdir 12
#define SYS_chmod 15
#define SYS_chown 16
#define SYS_chroot 61
#define SYS_clock_adjtime 499
#define SYS_clock_getres 421
#define SYS_clock_gettime 420
#define SYS_clock_nanosleep 422
#define SYS_clock_settime 419
#define SYS_clone 312
#define SYS_close 6
#define SYS_connect 98
#define SYS_copy_file_range 519
#define SYS_create_module 306
#define SYS_delete_module 308
#define SYS_dipc 373
#define SYS_dup 41
#define SYS_dup2 90
#define SYS_dup3 487
#define SYS_epoll_create1 486
#define SYS_epoll_pwait 474
#define SYS_eventfd 478
#define SYS_eventfd2 485
#define SYS_execve 59
#define SYS_execveat 513
#define SYS_exec_with_loader 25
#define SYS_exit 1
#define SYS_exit_group 405
#define SYS_faccessat 462
#define SYS_fadvise64 413
#define SYS_fallocate 480
#define SYS_fanotify_init 494
#define SYS_fanotify_mark 495
#define SYS_fchdir 13
#define SYS_fchmod 124
#define SYS_fchmodat 461
#define SYS_fchown 123
#define SYS_fchownat 453
#define SYS_fcntl 92
#define SYS_fdatasync 447
#define SYS_fgetxattr 387
#define SYS_finit_module 507
#define SYS_flistxattr 390
#define SYS_flock 131
#define SYS_fork 2
#define SYS_fremovexattr 393
#define SYS_fsconfig 541
#define SYS_fsetxattr 384
#define SYS_fsmount 542
#define SYS_fsopen 540
#define SYS_fspick 543
#define SYS_fstat 91
#define SYS_fstat64 427
#define SYS_fstatat64 455
#define SYS_fstatfs 329
#define SYS_fstatfs64 529
#define SYS_fsync 95
#define SYS_ftruncate 130
#define SYS_futex 394
#define SYS_futimesat 454
#define SYS_getcpu 473
#define SYS_getcwd 367
#define SYS_getdents 305
#define SYS_getdents64 377
#define SYS_getdtablesize 89
#define SYS_getegid 530
#define SYS_geteuid 531
#define SYS_getgroups 79
#define SYS_gethostname 87
#define SYS_getitimer 361
#define SYS_get_kernel_syms 309
#define SYS_get_mempolicy 430
#define SYS_getpagesize 64
#define SYS_getpeername 141
#define SYS_getpgid 233
#define SYS_getpgrp 63
#define SYS_getppid 532
#define SYS_getpriority 100
#define SYS_getrandom 511
#define SYS_getresgid 372
#define SYS_getresuid 344
#define SYS_getrlimit 144
#define SYS_get_robust_list 467
#define SYS_getrusage 364
#define SYS_getsid 234
#define SYS_getsockname 150
#define SYS_getsockopt 118
#define SYS_gettid 378
#define SYS_gettimeofday 359
#define SYS_getxattr 385
#define SYS_getxgid 47
#define SYS_getxpid 20
#define SYS_getxuid 24
#define SYS_init_module 307
#define SYS_inotify_add_watch 445
#define SYS_inotify_init 444
#define SYS_inotify_init1 489
#define SYS_inotify_rm_watch 446
#define SYS_io_cancel 402
#define SYS_ioctl 54
#define SYS_io_destroy 399
#define SYS_io_getevents 400
#define SYS_io_pgetevents 523
#define SYS_ioprio_get 443
#define SYS_ioprio_set 442
#define SYS_io_setup 398
#define SYS_io_submit 401
#define SYS_io_uring_enter 536
#define SYS_io_uring_register 537
#define SYS_io_uring_setup 535
#define SYS_kcmp 506
#define SYS_kexec_load 448
#define SYS_keyctl 441
#define SYS_kill 37
#define SYS_lchown 208
#define SYS_lgetxattr 386
#define SYS_link 9
#define SYS_linkat 458
#define SYS_listen 106
#define SYS_listxattr 388
#define SYS_llistxattr 389
#define SYS_lookup_dcookie 406
#define SYS_lremovexattr 392
#define SYS_lseek 19
#define SYS_lsetxattr 383
#define SYS_lstat 68
#define SYS_lstat64 426
#define SYS_madvise 75
#define SYS_mbind 429
#define SYS_membarrier 517
#define SYS_memfd_create 512
#define SYS_migrate_pages 449
#define SYS_mincore 375
#define SYS_mkdir 136
#define SYS_mkdirat 451
#define SYS_mknod 14
#define SYS_mknodat 452
#define SYS_mlock 314
#define SYS_mlock2 518
#define SYS_mlockall 316
#define SYS_mmap 71
#define SYS_mount 302
#define SYS_move_mount 539
#define SYS_move_pages 472
#define SYS_mprotect 74
#define SYS_mq_getsetattr 437
#define SYS_mq_notify 436
#define SYS_mq_open 432
#define SYS_mq_timedreceive 435
#define SYS_mq_timedsend 434
#define SYS_mq_unlink 433
#define SYS_mremap 341
#define SYS_msgctl 200
#define SYS_msgget 201
#define SYS_msgrcv 202
#define SYS_msgsnd 203
#define SYS_msync 217
#define SYS_munlock 315
#define SYS_munlockall 317
#define SYS_munmap 73
#define SYS_name_to_handle_at 497
#define SYS_nanosleep 340
#define SYS_nfsservctl 342
#define SYS_old_adjtimex 303
#define SYS_oldumount 321
#define SYS_open 45
#define SYS_openat 450
#define SYS_openat2 547
#define SYS_open_by_handle_at 498
#define SYS_open_tree 538
#define SYS_osf_adjtime 140
#define SYS_osf_afs_syscall 258
#define SYS_osf_alt_plock 181
#define SYS_osf_alt_setsid 188
#define SYS_osf_alt_sigpending 187
#define SYS_osf_asynch_daemon 163
#define SYS_osf_audcntl 252
#define SYS_osf_audgen 253
#define SYS_osf_chflags 34
#define SYS_osf_execve 11
#define SYS_osf_exportfs 169
#define SYS_osf_fchflags 35
#define SYS_osf_fdatasync 261
#define SYS_osf_fpathconf 248
#define SYS_osf_fstatfs 161
#define SYS_osf_fuser 243
#define SYS_osf_getaddressconf 214
#define SYS_osf_getdirentries 159
#define SYS_osf_getdomainname 165
#define SYS_osf_getfh 164
#define SYS_osf_getfsstat 18
#define SYS_osf_gethostid 142
#define SYS_osf_getitimer 86
#define SYS_osf_getlogin 49
#define SYS_osf_getmnt 184
#define SYS_osf_getrusage 117
#define SYS_osf_getsysinfo 256
#define SYS_osf_gettimeofday 116
#define SYS_osf_kloadcall 223
#define SYS_osf_kmodcall 77
#define SYS_osf_memcntl 260
#define SYS_osf_mincore 78
#define SYS_osf_mount 21
#define SYS_osf_mremap 65
#define SYS_osf_msfs_syscall 240
#define SYS_osf_msleep 215
#define SYS_osf_mvalid 213
#define SYS_osf_mwakeup 216
#define SYS_osf_naccept 30
#define SYS_osf_nfssvc 158
#define SYS_osf_ngetpeername 31
#define SYS_osf_ngetsockname 32
#define SYS_osf_nrecvfrom 29
#define SYS_osf_nrecvmsg 27
#define SYS_osf_nsendmsg 28
#define SYS_osf_ntp_adjtime 245
#define SYS_osf_ntp_gettime 246
#define SYS_osf_old_creat 8
#define SYS_osf_old_fstat 62
#define SYS_osf_old_getpgrp 81
#define SYS_osf_old_killpg 146
#define SYS_osf_old_lstat 40
#define SYS_osf_old_open 5
#define SYS_osf_oldquota 149
#define SYS_osf_old_sigaction 46
#define SYS_osf_old_sigblock 109
#define SYS_osf_old_sigreturn 139
#define SYS_osf_old_sigsetmask 110
#define SYS_osf_old_sigvec 108
#define SYS_osf_old_stat 38
#define SYS_osf_old_vadvise 72
#define SYS_osf_old_vtrace 115
#define SYS_osf_old_wait 84
#define SYS_osf_pathconf 247
#define SYS_osf_pid_block 153
#define SYS_osf_pid_unblock 154
#define SYS_osf_plock 107
#define SYS_osf_priocntlset 237
#define SYS_osf_profil 44
#define SYS_osf_proplist_syscall 244
#define SYS_osf_reboot 55
#define SYS_osf_revoke 56
#define SYS_osf_sbrk 69
#define SYS_osf_security 222
#define SYS_osf_select 93
#define SYS_osf_sethostid 143
#define SYS_osf_setitimer 83
#define SYS_osf_setlogin 50
#define SYS_osf_set_program_attributes 43
#define SYS_osf_set_speculative 239
#define SYS_osf_setsysinfo 257
#define SYS_osf_settimeofday 122
#define SYS_osf_shmat 209
#define SYS_osf_signal 218
#define SYS_osf_sigprocmask 48
#define SYS_osf_sigsendset 238
#define SYS_osf_sigstack 112
#define SYS_osf_sigwaitprim 157
#define SYS_osf_sstk 70
#define SYS_osf_statfs 160
#define SYS_osf_subsys_info 255
#define SYS_osf_swapctl 259
#define SYS_osf_swapon 199
#define SYS_osf_syscall 0
#define SYS_osf_sysinfo 241
#define SYS_osf_table 85
#define SYS_osf_uadmin 242
#define SYS_osf_usleep_thread 251
#define SYS_osf_uswitch 250
#define SYS_osf_utc_adjtime 220
#define SYS_osf_utc_gettime 219
#define SYS_osf_utimes 138
#define SYS_osf_utsname 207
#define SYS_osf_wait4 7
#define SYS_osf_waitid 236
#define SYS_pciconfig_iobase 376
#define SYS_pciconfig_read 345
#define SYS_pciconfig_write 346
#define SYS_perf_event_open 493
#define SYS_personality 324
#define SYS_pidfd_getfd 548
#define SYS_pidfd_open 544
#define SYS_pidfd_send_signal 534
#define SYS_pipe 42
#define SYS_pipe2 488
#define SYS_pivot_root 374
#define SYS_pkey_alloc 525
#define SYS_pkey_free 526
#define SYS_pkey_mprotect 524
#define SYS_poll 94
#define SYS_ppoll 464
#define SYS_prctl 348
#define SYS_pread 349
#define SYS_preadv 490
#define SYS_preadv2 520
#define SYS_prlimit64 496
#define SYS_process_vm_readv 504
#define SYS_process_vm_writev 505
#define SYS_pselect6 463
#define SYS_ptrace 26
#define SYS_pwrite 350
#define SYS_pwritev 491
#define SYS_pwritev2 521
#define SYS_query_module 347
#define SYS_quotactl 148
#define SYS_read 3
#define SYS_readahead 379
#define SYS_readlink 58
#define SYS_readlinkat 460
#define SYS_readv 120
#define SYS_reboot 311
#define SYS_recv 102
#define SYS_recvfrom 125
#define SYS_recvmmsg 479
#define SYS_recvmsg 113
#define SYS_remap_file_pages 410
#define SYS_removexattr 391
#define SYS_rename 128
#define SYS_renameat 457
#define SYS_renameat2 510
#define SYS_request_key 440
#define SYS_restart_syscall 412
#define SYS_rmdir 137
#define SYS_rseq 527
#define SYS_rt_sigaction 352
#define SYS_rt_sigpending 354
#define SYS_rt_sigprocmask 353
#define SYS_rt_sigqueueinfo 356
#define SYS_rt_sigreturn 351
#define SYS_rt_sigsuspend 357
#define SYS_rt_sigtimedwait 355
#define SYS_rt_tgsigqueueinfo 492
#define SYS_sched_getaffinity 396
#define SYS_sched_getattr 509
#define SYS_sched_getparam 331
#define SYS_sched_get_priority_max 335
#define SYS_sched_get_priority_min 336
#define SYS_sched_getscheduler 333
#define SYS_sched_rr_get_interval 337
#define SYS_sched_setaffinity 395
#define SYS_sched_setattr 508
#define SYS_sched_setparam 330
#define SYS_sched_setscheduler 332
#define SYS_sched_yield 334
#define SYS_seccomp 514
#define SYS_select 358
#define SYS_semctl 204
#define SYS_semget 205
#define SYS_semop 206
#define SYS_semtimedop 423
#define SYS_send 101
#define SYS_sendfile 370
#define SYS_sendmmsg 503
#define SYS_sendmsg 114
#define SYS_sendto 133
#define SYS_setdomainname 166
#define SYS_setfsgid 326
#define SYS_setfsuid 325
#define SYS_setgid 132
#define SYS_setgroups 80
#define SYS_sethae 301
#define SYS_sethostname 88
#define SYS_setitimer 362
#define SYS_set_mempolicy 431
#define SYS_setns 501
#define SYS_setpgid 39
#define SYS_setpgrp 82
#define SYS_setpriority 96
#define SYS_setregid 127
#define SYS_setresgid 371
#define SYS_setresuid 343
#define SYS_setreuid 126
#define SYS_setrlimit 145
#define SYS_set_robust_list 466
#define SYS_setsid 147
#define SYS_setsockopt 105
#define SYS_set_tid_address 411
#define SYS_settimeofday 360
#define SYS_setuid 23
#define SYS_setxattr 382
#define SYS_shmctl 210
#define SYS_shmdt 211
#define SYS_shmget 212
#define SYS_shutdown 134
#define SYS_sigaction 156
#define SYS_sigaltstack 235
#define SYS_signalfd 476
#define SYS_signalfd4 484
#define SYS_sigpending 52
#define SYS_sigreturn 103
#define SYS_sigsuspend 111
#define SYS_socket 97
#define SYS_socketpair 135
#define SYS_splice 468
#define SYS_stat 67
#define SYS_stat64 425
#define SYS_statfs 328
#define SYS_statfs64 528
#define SYS_statx 522
#define SYS_swapoff 304
#define SYS_swapon 322
#define SYS_symlink 57
#define SYS_symlinkat 459
#define SYS_sync 36
#define SYS_sync_file_range 469
#define SYS_syncfs 500
#define SYS__sysctl 319
#define SYS_sys_epoll_create 407
#define SYS_sys_epoll_ctl 408
#define SYS_sys_epoll_wait 409
#define SYS_sysfs 254
#define SYS_sysinfo 318
#define SYS_syslog 310
#define SYS_tee 470
#define SYS_tgkill 424
#define SYS_timer_create 414
#define SYS_timer_delete 418
#define SYS_timerfd 477
#define SYS_timerfd_create 481
#define SYS_timerfd_gettime 483
#define SYS_timerfd_settime 482
#define SYS_timer_getoverrun 417
#define SYS_timer_gettime 416
#define SYS_timer_settime 415
#define SYS_times 323
#define SYS_tkill 381
#define SYS_truncate 129
#define SYS_tuxcall 397
#define SYS_umask 60
#define SYS_umount 22
#define SYS_umount_with_flags 22
#define SYS_umount_without_flags 321
#define SYS_uname 339
#define SYS_unlink 10
#define SYS_unlinkat 456
#define SYS_unshare 465
#define SYS_uselib 313
#define SYS_userfaultfd 516
#define SYS_ustat 327
#define SYS_utimensat 475
#define SYS_utimes 363
#define SYS_vfork 66
#define SYS_vhangup 76
#define SYS_vmsplice 471
#define SYS_vserver 428
#define SYS_wait4 365
#define SYS_waitid 438
#define SYS_write 4
#define SYS_writev 121
