#define STDIN_FILENO 0
#define STDOUT_FILENO 1
#define STDERR_FILENO 2
#define __BSD_VISIBLE 99999999
#define __POSIX_VISIBLE 99999999
#define __XSI_VISIBLE 99999999
#define INADDR_ANY 0
#define INADDR_BROADCAST 0xffffffff
#define INADDR_NONE 0xffffffff
#define INADDR_LOOPBACK 0x7f000001
#define EPERM 1
#define ENOENT 2
#define ESRCH 3
#define EINTR 4
#define EIO 5
#define ENXIO 6
#define E2BIG 7
#define ENOEXEC 8
#define EBADF 9
#define ECHILD 10
#define EDEADLK 11
#define ENOMEM 12
#define EACCES 13
#define EFAULT 14
#define ENOTBLK 15
#define EBUSY 16
#define EEXIST 17
#define EXDEV 18
#define ENODEV 19
#define ENOTDIR 20
#define EISDIR 21
#define EINVAL 22
#define ENFILE 23
#define EMFILE 24
#define ENOTTY 25
#define ETXTBSY 26
#define EFBIG 27
#define ENOSPC 28
#define ESPIPE 29
#define EROFS 30
#define EMLINK 31
#define EPIPE 32
#define EDOM 33
#define ERANGE 34
#define EAGAIN 35
#define EWOULDBLOCK 35
#define EINPROGRESS 36
#define EALREADY 37
#define ENOTSOCK 38
#define EDESTADDRREQ 39
#define EMSGSIZE 40
#define EPROTOTYPE 41
#define ENOPROTOOPT 42
#define EPROTONOSUPPORT 43
#define ESOCKTNOSUPPORT 44
#define EOPNOTSUPP 45
#define ENOTSUP 45
#define EPFNOSUPPORT 46
#define EAFNOSUPPORT 47
#define EADDRINUSE 48
#define EADDRNOTAVAIL 49
#define ENETDOWN 50
#define ENETUNREACH 51
#define ENETRESET 52
#define ECONNABORTED 53
#define ECONNRESET 54
#define ENOBUFS 55
#define EISCONN 56
#define ENOTCONN 57
#define ESHUTDOWN 58
#define ETOOMANYREFS 59
#define ETIMEDOUT 60
#define ECONNREFUSED 61
#define ELOOP 62
#define ENAMETOOLONG 63
#define EHOSTDOWN 64
#define EHOSTUNREACH 65
#define ENOTEMPTY 66
#define EPROCLIM 67
#define EUSERS 68
#define EDQUOT 69
#define ESTALE 70
#define EREMOTE 71
#define EBADRPC 72
#define ERPCMISMATCH 73
#define EPROGUNAVAIL 74
#define EPROGMISMATCH 75
#define EPROCUNAVAIL 76
#define ENOLCK 77
#define ENOSYS 78
#define EFTYPE 79
#define EAUTH 80
#define ENEEDAUTH 81
#define EIDRM 82
#define ENOMSG 83
#define EOVERFLOW 84
#define ECANCELED 85
#define EILSEQ 86
#define ENOATTR 87
#define EDOOFUS 88
#define EBADMSG 89
#define EMULTIHOP 90
#define ENOLINK 91
#define EPROTO 92
#define ENOTCAPABLE 93
#define ECAPMODE 94
#define ELAST 94
#define O_RDONLY 0x0000
#define O_WRONLY 0x0001
#define O_RDWR 0x0002
#define O_ACCMODE 0x0003
#define FREAD 0x0001
#define FWRITE 0x0002
#define O_NONBLOCK 0x0004
#define O_APPEND 0x0008
#define O_SHLOCK 0x0010
#define O_EXLOCK 0x0020
#define O_ASYNC 0x0040
#define O_FSYNC 0x0080
#define O_SYNC 0x0080
#define O_NOFOLLOW 0x0100
#define O_CREAT 0x0200
#define O_TRUNC 0x0400
#define O_EXCL 0x0800
#define O_NOCTTY 0x8000
#define O_DIRECT 0x00010000
#define O_DIRECTORY 0x00020000
#define O_EXEC 0x00040000
#define O_TTY_INIT 0x00080000
#define O_CLOEXEC 0x00100000
#define FAPPEND 0x0008
#define FASYNC 0x0040
#define FFSYNC 0x0080
#define FNONBLOCK 0x0004
#define FNDELAY 0x0004
#define O_NDELAY 0x0004
#define FRDAHEAD 0x0200
#define AT_FDCWD -100
#define AT_EACCESS 0x100
#define AT_SYMLINK_NOFOLLOW 0x200
#define AT_SYMLINK_FOLLOW 0x400
#define AT_REMOVEDIR 0x800
#define F_DUPFD 0
#define F_GETFD 1
#define F_SETFD 2
#define F_GETFL 3
#define F_SETFL 4
#define F_GETOWN 5
#define F_SETOWN 6
#define F_OGETLK 7
#define F_OSETLK 8
#define F_OSETLKW 9
#define F_DUP2FD 10
#define F_GETLK 11
#define F_SETLK 12
#define F_SETLKW 13
#define F_SETLK_REMOTE 14
#define F_READAHEAD 15
#define F_RDAHEAD 16
#define F_DUPFD_CLOEXEC 17
#define F_DUP2FD_CLOEXEC 18
#define FD_CLOEXEC 1
#define F_RDLCK 1
#define F_UNLCK 2
#define F_WRLCK 3
#define F_UNLCKSYS 4
#define F_CANCEL 5
#define LOCK_SH 0x01
#define LOCK_EX 0x02
#define LOCK_NB 0x04
#define LOCK_UN 0x08
#define POSIX_FADV_NORMAL 0
#define POSIX_FADV_RANDOM 1
#define POSIX_FADV_SEQUENTIAL 2
#define POSIX_FADV_WILLNEED 3
#define POSIX_FADV_DONTNEED 4
#define POSIX_FADV_NOREUSE 5
#define INHERIT_SHARE 0
#define INHERIT_COPY 1
#define INHERIT_NONE 2
#define PROT_NONE 0x00
#define PROT_READ 0x01
#define PROT_WRITE 0x02
#define PROT_EXEC 0x04
#define MAP_SHARED 0x0001
#define MAP_PRIVATE 0x0002
#define MAP_COPY 0x0002
#define MAP_FIXED 0x0010
#define MAP_RENAME 0x0020
#define MAP_NORESERVE 0x0040
#define MAP_RESERVED0080 0x0080
#define MAP_RESERVED0100 0x0100
#define MAP_HASSEMAPHORE 0x0200
#define MAP_STACK 0x0400
#define MAP_NOSYNC 0x0800
#define MAP_FILE 0x0000
#define MAP_ANON 0x1000
#define MAP_ANONYMOUS 0x1000
#define MAP_NOCORE 0x00020000
#define MAP_PREFAULT_READ 0x00040000
#define MCL_CURRENT 0x0001
#define MCL_FUTURE 0x0002
#define MS_SYNC 0x0000
#define MS_ASYNC 0x0001
#define MS_INVALIDATE 0x0002
#define _MADV_NORMAL 0
#define _MADV_RANDOM 1
#define _MADV_SEQUENTIAL 2
#define _MADV_WILLNEED 3
#define _MADV_DONTNEED 4
#define MADV_NORMAL 0
#define MADV_RANDOM 1
#define MADV_SEQUENTIAL 2
#define MADV_WILLNEED 3
#define MADV_DONTNEED 4
#define MADV_FREE 5
#define MADV_NOSYNC 6
#define MADV_AUTOSYNC 7
#define MADV_NOCORE 8
#define MADV_CORE 9
#define MADV_PROTECT 10
#define MINCORE_INCORE 0x1
#define MINCORE_REFERENCED 0x2
#define MINCORE_MODIFIED 0x4
#define MINCORE_REFERENCED_OTHER 0x8
#define MINCORE_MODIFIED_OTHER 0x10
#define POSIX_MADV_NORMAL 0
#define POSIX_MADV_RANDOM 1
#define POSIX_MADV_SEQUENTIAL 2
#define POSIX_MADV_WILLNEED 3
#define POSIX_MADV_DONTNEED 4
#define SIGHUP 1
#define SIGINT 2
#define SIGQUIT 3
#define SIGILL 4
#define SIGTRAP 5
#define SIGABRT 6
#define SIGIOT 6
#define SIGEMT 7
#define SIGFPE 8
#define SIGKILL 9
#define SIGBUS 10
#define SIGSEGV 11
#define SIGSYS 12
#define SIGPIPE 13
#define SIGALRM 14
#define SIGTERM 15
#define SIGURG 16
#define SIGSTOP 17
#define SIGTSTP 18
#define SIGCONT 19
#define SIGCHLD 20
#define SIGTTIN 21
#define SIGTTOU 22
#define SIGIO 23
#define SIGXCPU 24
#define SIGXFSZ 25
#define SIGVTALRM 26
#define SIGPROF 27
#define SIGWINCH 28
#define SIGINFO 29
#define SIGUSR1 30
#define SIGUSR2 31
#define SIGTHR 32
#define SIGLWP 32
#define SIGRTMIN 65
#define SIGRTMAX 126
#define SIGEV_NONE 0
#define SIGEV_SIGNAL 1
#define SIGEV_THREAD 2
#define SIGEV_KEVENT 3
#define SIGEV_THREAD_ID 4
#define ILL_ILLOPC 1
#define ILL_ILLOPN 2
#define ILL_ILLADR 3
#define ILL_ILLTRP 4
#define ILL_PRVOPC 5
#define ILL_PRVREG 6
#define ILL_COPROC 7
#define ILL_BADSTK 8
#define BUS_ADRALN 1
#define BUS_ADRERR 2
#define BUS_OBJERR 3
#define SEGV_MAPERR 1
#define SEGV_ACCERR 2
#define FPE_INTOVF 1
#define FPE_INTDIV 2
#define FPE_FLTDIV 3
#define FPE_FLTOVF 4
#define FPE_FLTUND 5
#define FPE_FLTRES 6
#define FPE_FLTINV 7
#define FPE_FLTSUB 8
#define TRAP_BRKPT 1
#define TRAP_TRACE 2
#define TRAP_DTRACE 3
#define CLD_EXITED 1
#define CLD_KILLED 2
#define CLD_DUMPED 3
#define CLD_TRAPPED 4
#define CLD_STOPPED 5
#define CLD_CONTINUED 6
#define POLL_IN 1
#define POLL_OUT 2
#define POLL_MSG 3
#define POLL_ERR 4
#define POLL_PRI 5
#define POLL_HUP 6
#define SA_NOCLDSTOP 0x0008
#define SA_ONSTACK 0x0001
#define SA_RESTART 0x0002
#define SA_RESETHAND 0x0004
#define SA_NODEFER 0x0010
#define SA_NOCLDWAIT 0x0020
#define SA_SIGINFO 0x0040
#define NSIG 32
#define SI_NOINFO 0
#define SI_USER 0x10001
#define SI_QUEUE 0x10002
#define SI_TIMER 0x10003
#define SI_ASYNCIO 0x10004
#define SI_MESGQ 0x10005
#define SI_KERNEL 0x10006
#define SI_LWP 0x10007
#define SI_UNDEFINED 0
#define SS_ONSTACK 0x0001
#define SS_DISABLE 0x0004
#define SV_ONSTACK 0x0001
#define SV_INTERRUPT 0x0002
#define SV_RESETHAND 0x0004
#define SV_NODEFER 0x0010
#define SV_NOCLDSTOP 0x0008
#define SV_SIGINFO 0x0040
#define SIG_BLOCK 1
#define SIG_UNBLOCK 2
#define SIG_SETMASK 3
#define SOCK_STREAM 1
#define SOCK_DGRAM 2
#define SOCK_RAW 3
#define SOCK_RDM 4
#define SOCK_SEQPACKET 5
#define SO_DEBUG 0x0001
#define SO_ACCEPTCONN 0x0002
#define SO_REUSEADDR 0x0004
#define SO_KEEPALIVE 0x0008
#define SO_DONTROUTE 0x0010
#define SO_BROADCAST 0x0020
#define SO_USELOOPBACK 0x0040
#define SO_LINGER 0x0080
#define SO_OOBINLINE 0x0100
#define SO_REUSEPORT 0x0200
#define SO_TIMESTAMP 0x0400
#define SO_NOSIGPIPE 0x0800
#define SO_ACCEPTFILTER 0x1000
#define SO_BINTIME 0x2000
#define SO_NO_OFFLOAD 0x4000
#define SO_NO_DDP 0x8000
#define SO_SNDBUF 0x1001
#define SO_RCVBUF 0x1002
#define SO_SNDLOWAT 0x1003
#define SO_RCVLOWAT 0x1004
#define SO_SNDTIMEO 0x1005
#define SO_RCVTIMEO 0x1006
#define SO_ERROR 0x1007
#define SO_TYPE 0x1008
#define SO_LABEL 0x1009
#define SO_PEERLABEL 0x1010
#define SO_LISTENQLIMIT 0x1011
#define SO_LISTENQLEN 0x1012
#define SO_LISTENINCQLEN 0x1013
#define SO_SETFIB 0x1014
#define SO_USER_COOKIE 0x1015
#define SO_PROTOCOL 0x1016
#define SO_PROTOTYPE 0x1016
#define SO_VENDOR 0x80000000
#define SOL_SOCKET 0xffff
#define AF_UNSPEC 0
#define AF_UNIX 1
#define AF_INET 2
#define AF_IMPLINK 3
#define AF_PUP 4
#define AF_CHAOS 5
#define AF_NETBIOS 6
#define AF_ISO 7
#define AF_OSI 7
#define AF_ECMA 8
#define AF_DATAKIT 9
#define AF_CCITT 10
#define AF_SNA 11
#define AF_DECnet 12
#define AF_DLI 13
#define AF_LAT 14
#define AF_HYLINK 15
#define AF_APPLETALK 16
#define AF_ROUTE 17
#define AF_LINK 18
#define pseudo_AF_XTP 19
#define AF_COIP 20
#define AF_CNT 21
#define pseudo_AF_RTIP 22
#define AF_IPX 23
#define AF_SIP 24
#define pseudo_AF_PIP 25
#define AF_ISDN 26
#define AF_E164 26
#define pseudo_AF_KEY 27
#define AF_INET6 28
#define AF_NATM 29
#define AF_ATM 30
#define pseudo_AF_HDRCMPLT 31
#define AF_NETGRAPH 32
#define AF_SLOW 33
#define AF_SCLUSTER 34
#define AF_ARP 35
#define AF_BLUETOOTH 36
#define AF_IEEE80211 37
#define AF_MAX 38
#define AF_VENDOR00 39
#define AF_VENDOR01 41
#define AF_VENDOR02 43
#define AF_VENDOR03 45
#define AF_VENDOR04 47
#define AF_VENDOR05 49
#define AF_VENDOR06 51
#define AF_VENDOR07 53
#define AF_VENDOR08 55
#define AF_VENDOR09 57
#define AF_VENDOR10 59
#define AF_VENDOR11 61
#define AF_VENDOR12 63
#define AF_VENDOR13 65
#define AF_VENDOR14 67
#define AF_VENDOR15 69
#define AF_VENDOR16 71
#define AF_VENDOR17 73
#define AF_VENDOR18 75
#define AF_VENDOR19 77
#define AF_VENDOR20 79
#define AF_VENDOR21 81
#define AF_VENDOR22 83
#define AF_VENDOR23 85
#define AF_VENDOR24 87
#define AF_VENDOR25 89
#define AF_VENDOR26 91
#define AF_VENDOR27 93
#define AF_VENDOR28 95
#define AF_VENDOR29 97
#define AF_VENDOR30 99
#define AF_VENDOR31 101
#define AF_VENDOR32 103
#define AF_VENDOR33 105
#define AF_VENDOR34 107
#define AF_VENDOR35 109
#define AF_VENDOR36 111
#define AF_VENDOR37 113
#define AF_VENDOR38 115
#define AF_VENDOR39 117
#define AF_VENDOR40 119
#define AF_VENDOR41 121
#define AF_VENDOR42 123
#define AF_VENDOR43 125
#define AF_VENDOR44 127
#define AF_VENDOR45 129
#define AF_VENDOR46 131
#define AF_VENDOR47 133
#define SOCK_MAXADDRLEN 255
#define PF_UNSPEC 0
#define PF_LOCAL 1
#define PF_UNIX 1
#define PF_INET 2
#define PF_IMPLINK 3
#define PF_PUP 4
#define PF_CHAOS 5
#define PF_NETBIOS 6
#define PF_ISO 7
#define PF_OSI 7
#define PF_ECMA 8
#define PF_DATAKIT 9
#define PF_CCITT 10
#define PF_SNA 11
#define PF_DECnet 12
#define PF_DLI 13
#define PF_LAT 14
#define PF_HYLINK 15
#define PF_APPLETALK 16
#define PF_ROUTE 17
#define PF_LINK 18
#define PF_XTP 19
#define PF_COIP 20
#define PF_CNT 21
#define PF_SIP 24
#define PF_IPX 23
#define PF_RTIP 22
#define PF_PIP 25
#define PF_ISDN 26
#define PF_KEY 27
#define PF_INET6 28
#define PF_NATM 29
#define PF_ATM 30
#define PF_NETGRAPH 32
#define PF_SLOW 33
#define PF_SCLUSTER 34
#define PF_ARP 35
#define PF_BLUETOOTH 36
#define PF_MAX 38
#define NET_MAXID 38
#define NET_RT_DUMP 1
#define NET_RT_FLAGS 2
#define NET_RT_IFLIST 3
#define NET_RT_IFMALIST 4
#define NET_RT_IFLISTL 5
#define NET_RT_MAXID 6
#define SOMAXCONN 128
#define MSG_OOB 0x1
#define MSG_PEEK 0x2
#define MSG_DONTROUTE 0x4
#define MSG_EOR 0x8
#define MSG_TRUNC 0x10
#define MSG_CTRUNC 0x20
#define MSG_WAITALL 0x40
#define MSG_NOTIFICATION 0x2000
#define MSG_DONTWAIT 0x80
#define MSG_EOF 0x100
#define MSG_NBIO 0x4000
#define MSG_COMPAT 0x8000
#define MSG_NOSIGNAL 0x20000
#define CMGROUP_MAX 16
#define SCM_RIGHTS 0x01
#define SCM_TIMESTAMP 0x02
#define SCM_CREDS 0x03
#define SCM_BINTIME 0x04
#define SHUT_RD 0
#define SHUT_WR 1
#define SHUT_RDWR 2
#define PRU_FLUSH_RD 0
#define PRU_FLUSH_WR 1
#define PRU_FLUSH_RDWR 2
#define SF_NODISKIO 0x00000001
#define SF_MNOWAIT 0x00000002
#define SF_SYNC 0x00000004
#define S_ISUID 0x800
#define S_ISGID 0x400
#define S_ISTXT 0x200
#define S_IRWXU 0x1c0
#define S_IRUSR 0x100
#define S_IWUSR 0x80
#define S_IXUSR 0x40
#define S_IREAD 0x100
#define S_IWRITE 0x80
#define S_IEXEC 0x40
#define S_IRWXG 0x38
#define S_IRGRP 0x20
#define S_IWGRP 0x10
#define S_IXGRP 0x8
#define S_IRWXO 0x7
#define S_IROTH 0x4
#define S_IWOTH 0x2
#define S_IXOTH 0x1
#define S_IFMT 0xf000
#define S_IFIFO 0x1000
#define S_IFCHR 0x2000
#define S_IFDIR 0x4000
#define S_IFBLK 0x6000
#define S_IFREG 0x8000
#define S_IFLNK 0xa000
#define S_IFSOCK 0xc000
#define S_ISVTX 0x200
#define S_IFWHT 0xe000
#define ACCESSPERMS 0x1ff
#define ALLPERMS 0xfff
#define DEFFILEMODE 0x1b6
#define S_BLKSIZE 512
#define UF_SETTABLE 0x0000ffff
#define UF_NODUMP 0x00000001
#define UF_IMMUTABLE 0x00000002
#define UF_APPEND 0x00000004
#define UF_OPAQUE 0x00000008
#define UF_NOUNLINK 0x00000010
#define SF_SETTABLE 0xffff0000
#define SF_ARCHIVED 0x00010000
#define SF_IMMUTABLE 0x00020000
#define SF_APPEND 0x00040000
#define SF_NOUNLINK 0x00100000
#define SF_SNAPSHOT 0x00200000
#define SYS_syscall 0
#define SYS_exit 1
#define SYS_fork 2
#define SYS_read 3
#define SYS_write 4
#define SYS_open 5
#define SYS_close 6
#define SYS_wait4 7
#define SYS_link 9
#define SYS_unlink 10
#define SYS_chdir 12
#define SYS_fchdir 13
#define SYS_mknod 14
#define SYS_chmod 15
#define SYS_chown 16
#define SYS_break 17
#define SYS_freebsd4_getfsstat 18
#define SYS_getpid 20
#define SYS_mount 21
#define SYS_unmount 22
#define SYS_setuid 23
#define SYS_getuid 24
#define SYS_geteuid 25
#define SYS_ptrace 26
#define SYS_recvmsg 27
#define SYS_sendmsg 28
#define SYS_recvfrom 29
#define SYS_accept 30
#define SYS_getpeername 31
#define SYS_getsockname 32
#define SYS_access 33
#define SYS_chflags 34
#define SYS_fchflags 35
#define SYS_sync 36
#define SYS_kill 37
#define SYS_getppid 39
#define SYS_dup 41
#define SYS_pipe 42
#define SYS_getegid 43
#define SYS_profil 44
#define SYS_ktrace 45
#define SYS_getgid 47
#define SYS_getlogin 49
#define SYS_setlogin 50
#define SYS_acct 51
#define SYS_sigaltstack 53
#define SYS_ioctl 54
#define SYS_reboot 55
#define SYS_revoke 56
#define SYS_symlink 57
#define SYS_readlink 58
#define SYS_execve 59
#define SYS_umask 60
#define SYS_chroot 61
#define SYS_msync 65
#define SYS_vfork 66
#define SYS_sbrk 69
#define SYS_sstk 70
#define SYS_vadvise 72
#define SYS_munmap 73
#define SYS_mprotect 74
#define SYS_madvise 75
#define SYS_mincore 78
#define SYS_getgroups 79
#define SYS_setgroups 80
#define SYS_getpgrp 81
#define SYS_setpgid 82
#define SYS_setitimer 83
#define SYS_swapon 85
#define SYS_getitimer 86
#define SYS_getdtablesize 89
#define SYS_dup2 90
#define SYS_fcntl 92
#define SYS_select 93
#define SYS_fsync 95
#define SYS_setpriority 96
#define SYS_socket 97
#define SYS_connect 98
#define SYS_getpriority 100
#define SYS_bind 104
#define SYS_setsockopt 105
#define SYS_listen 106
#define SYS_gettimeofday 116
#define SYS_getrusage 117
#define SYS_getsockopt 118
#define SYS_readv 120
#define SYS_writev 121
#define SYS_settimeofday 122
#define SYS_fchown 123
#define SYS_fchmod 124
#define SYS_setreuid 126
#define SYS_setregid 127
#define SYS_rename 128
#define SYS_flock 131
#define SYS_mkfifo 132
#define SYS_sendto 133
#define SYS_shutdown 134
#define SYS_socketpair 135
#define SYS_mkdir 136
#define SYS_rmdir 137
#define SYS_utimes 138
#define SYS_adjtime 140
#define SYS_setsid 147
#define SYS_quotactl 148
#define SYS_nlm_syscall 154
#define SYS_nfssvc 155
#define SYS_freebsd4_statfs 157
#define SYS_freebsd4_fstatfs 158
#define SYS_lgetfh 160
#define SYS_getfh 161
#define SYS_freebsd4_getdomainname 162
#define SYS_freebsd4_setdomainname 163
#define SYS_freebsd4_uname 164
#define SYS_sysarch 165
#define SYS_rtprio 166
#define SYS_semsys 169
#define SYS_msgsys 170
#define SYS_shmsys 171
#define SYS_freebsd6_pread 173
#define SYS_freebsd6_pwrite 174
#define SYS_setfib 175
#define SYS_ntp_adjtime 176
#define SYS_setgid 181
#define SYS_setegid 182
#define SYS_seteuid 183
#define SYS_stat 188
#define SYS_fstat 189
#define SYS_lstat 190
#define SYS_pathconf 191
#define SYS_fpathconf 192
#define SYS_getrlimit 194
#define SYS_setrlimit 195
#define SYS_getdirentries 196
#define SYS_freebsd6_mmap 197
#define SYS___syscall 198
#define SYS_freebsd6_lseek 199
#define SYS_freebsd6_truncate 200
#define SYS_freebsd6_ftruncate 201
#define SYS___sysctl 202
#define SYS_mlock 203
#define SYS_munlock 204
#define SYS_undelete 205
#define SYS_futimes 206
#define SYS_getpgid 207
#define SYS_poll 209
#define SYS_freebsd7___semctl 220
#define SYS_semget 221
#define SYS_semop 222
#define SYS_freebsd7_msgctl 224
#define SYS_msgget 225
#define SYS_msgsnd 226
#define SYS_msgrcv 227
#define SYS_shmat 228
#define SYS_freebsd7_shmctl 229
#define SYS_shmdt 230
#define SYS_shmget 231
#define SYS_clock_gettime 232
#define SYS_clock_settime 233
#define SYS_clock_getres 234
#define SYS_ktimer_create 235
#define SYS_ktimer_delete 236
#define SYS_ktimer_settime 237
#define SYS_ktimer_gettime 238
#define SYS_ktimer_getoverrun 239
#define SYS_nanosleep 240
#define SYS_ntp_gettime 248
#define SYS_minherit 250
#define SYS_rfork 251
#define SYS_openbsd_poll 252
#define SYS_issetugid 253
#define SYS_lchown 254
#define SYS_aio_read 255
#define SYS_aio_write 256
#define SYS_lio_listio 257
#define SYS_getdents 272
#define SYS_lchmod 274
#define SYS_netbsd_lchown 275
#define SYS_lutimes 276
#define SYS_netbsd_msync 277
#define SYS_nstat 278
#define SYS_nfstat 279
#define SYS_nlstat 280
#define SYS_preadv 289
#define SYS_pwritev 290
#define SYS_freebsd4_fhstatfs 297
#define SYS_fhopen 298
#define SYS_fhstat 299
#define SYS_modnext 300
#define SYS_modstat 301
#define SYS_modfnext 302
#define SYS_modfind 303
#define SYS_kldload 304
#define SYS_kldunload 305
#define SYS_kldfind 306
#define SYS_kldnext 307
#define SYS_kldstat 308
#define SYS_kldfirstmod 309
#define SYS_getsid 310
#define SYS_setresuid 311
#define SYS_setresgid 312
#define SYS_aio_return 314
#define SYS_aio_suspend 315
#define SYS_aio_cancel 316
#define SYS_aio_error 317
#define SYS_oaio_read 318
#define SYS_oaio_write 319
#define SYS_olio_listio 320
#define SYS_yield 321
#define SYS_mlockall 324
#define SYS_munlockall 325
#define SYS___getcwd 326
#define SYS_sched_setparam 327
#define SYS_sched_getparam 328
#define SYS_sched_setscheduler 329
#define SYS_sched_getscheduler 330
#define SYS_sched_yield 331
#define SYS_sched_get_priority_max 332
#define SYS_sched_get_priority_min 333
#define SYS_sched_rr_get_interval 334
#define SYS_utrace 335
#define SYS_freebsd4_sendfile 336
#define SYS_kldsym 337
#define SYS_jail 338
#define SYS_nnpfs_syscall 339
#define SYS_sigprocmask 340
#define SYS_sigsuspend 341
#define SYS_freebsd4_sigaction 342
#define SYS_sigpending 343
#define SYS_freebsd4_sigreturn 344
#define SYS_sigtimedwait 345
#define SYS_sigwaitinfo 346
#define SYS___acl_get_file 347
#define SYS___acl_set_file 348
#define SYS___acl_get_fd 349
#define SYS___acl_set_fd 350
#define SYS___acl_delete_file 351
#define SYS___acl_delete_fd 352
#define SYS___acl_aclcheck_file 353
#define SYS___acl_aclcheck_fd 354
#define SYS_extattrctl 355
#define SYS_extattr_set_file 356
#define SYS_extattr_get_file 357
#define SYS_extattr_delete_file 358
#define SYS_aio_waitcomplete 359
#define SYS_getresuid 360
#define SYS_getresgid 361
#define SYS_kqueue 362
#define SYS_kevent 363
#define SYS_extattr_set_fd 371
#define SYS_extattr_get_fd 372
#define SYS_extattr_delete_fd 373
#define SYS___setugid 374
#define SYS_eaccess 376
#define SYS_afs3_syscall 377
#define SYS_nmount 378
#define SYS___mac_get_proc 384
#define SYS___mac_set_proc 385
#define SYS___mac_get_fd 386
#define SYS___mac_get_file 387
#define SYS___mac_set_fd 388
#define SYS___mac_set_file 389
#define SYS_kenv 390
#define SYS_lchflags 391
#define SYS_uuidgen 392
#define SYS_sendfile 393
#define SYS_mac_syscall 394
#define SYS_getfsstat 395
#define SYS_statfs 396
#define SYS_fstatfs 397
#define SYS_fhstatfs 398
#define SYS_ksem_close 400
#define SYS_ksem_post 401
#define SYS_ksem_wait 402
#define SYS_ksem_trywait 403
#define SYS_ksem_init 404
#define SYS_ksem_open 405
#define SYS_ksem_unlink 406
#define SYS_ksem_getvalue 407
#define SYS_ksem_destroy 408
#define SYS___mac_get_pid 409
#define SYS___mac_get_link 410
#define SYS___mac_set_link 411
#define SYS_extattr_set_link 412
#define SYS_extattr_get_link 413
#define SYS_extattr_delete_link 414
#define SYS___mac_execve 415
#define SYS_sigaction 416
#define SYS_sigreturn 417
#define SYS_getcontext 421
#define SYS_setcontext 422
#define SYS_swapcontext 423
#define SYS_swapoff 424
#define SYS___acl_get_link 425
#define SYS___acl_set_link 426
#define SYS___acl_delete_link 427
#define SYS___acl_aclcheck_link 428
#define SYS_sigwait 429
#define SYS_thr_create 430
#define SYS_thr_exit 431
#define SYS_thr_self 432
#define SYS_thr_kill 433
#define SYS__umtx_lock 434
#define SYS__umtx_unlock 435
#define SYS_jail_attach 436
#define SYS_extattr_list_fd 437
#define SYS_extattr_list_file 438
#define SYS_extattr_list_link 439
#define SYS_ksem_timedwait 441
#define SYS_thr_suspend 442
#define SYS_thr_wake 443
#define SYS_kldunloadf 444
#define SYS_audit 445
#define SYS_auditon 446
#define SYS_getauid 447
#define SYS_setauid 448
#define SYS_getaudit 449
#define SYS_setaudit 450
#define SYS_getaudit_addr 451
#define SYS_setaudit_addr 452
#define SYS_auditctl 453
#define SYS__umtx_op 454
#define SYS_thr_new 455
#define SYS_sigqueue 456
#define SYS_kmq_open 457
#define SYS_kmq_setattr 458
#define SYS_kmq_timedreceive 459
#define SYS_kmq_timedsend 460
#define SYS_kmq_notify 461
#define SYS_kmq_unlink 462
#define SYS_abort2 463
#define SYS_thr_set_name 464
#define SYS_aio_fsync 465
#define SYS_rtprio_thread 466
#define SYS_sctp_peeloff 471
#define SYS_sctp_generic_sendmsg 472
#define SYS_sctp_generic_sendmsg_iov 473
#define SYS_sctp_generic_recvmsg 474
#define SYS_pread 475
#define SYS_pwrite 476
#define SYS_mmap 477
#define SYS_lseek 478
#define SYS_truncate 479
#define SYS_ftruncate 480
#define SYS_thr_kill2 481
#define SYS_shm_open 482
#define SYS_shm_unlink 483
#define SYS_cpuset 484
#define SYS_cpuset_setid 485
#define SYS_cpuset_getid 486
#define SYS_cpuset_getaffinity 487
#define SYS_cpuset_setaffinity 488
#define SYS_faccessat 489
#define SYS_fchmodat 490
#define SYS_fchownat 491
#define SYS_fexecve 492
#define SYS_fstatat 493
#define SYS_futimesat 494
#define SYS_linkat 495
#define SYS_mkdirat 496
#define SYS_mkfifoat 497
#define SYS_mknodat 498
#define SYS_openat 499
#define SYS_readlinkat 500
#define SYS_renameat 501
#define SYS_symlinkat 502
#define SYS_unlinkat 503
#define SYS_posix_openpt 504
#define SYS_gssd_syscall 505
#define SYS_jail_get 506
#define SYS_jail_set 507
#define SYS_jail_remove 508
#define SYS_closefrom 509
#define SYS___semctl 510
#define SYS_msgctl 511
#define SYS_shmctl 512
#define SYS_lpathconf 513
#define SYS_cap_new 514
#define SYS_cap_getrights 515
#define SYS_cap_enter 516
#define SYS_cap_getmode 517
#define SYS_pdfork 518
#define SYS_pdkill 519
#define SYS_pdgetpid 520
#define SYS_pselect 522
#define SYS_getloginclass 523
#define SYS_setloginclass 524
#define SYS_rctl_get_racct 525
#define SYS_rctl_get_rules 526
#define SYS_rctl_get_limits 527
#define SYS_rctl_add_rule 528
#define SYS_rctl_remove_rule 529
#define SYS_posix_fallocate 530
#define SYS_posix_fadvise 531
#define SYS_wait6 532
#define SYS_MAXSYSCALL 533
#define _POSIX_ADVISORY_INFO 200112
#define _POSIX_ASYNCHRONOUS_IO 0
#define _POSIX_CHOWN_RESTRICTED 1
#define _POSIX_CLOCK_SELECTION (-1)
#define _POSIX_CPUTIME (-1)
#define _POSIX_FSYNC 200112
#define _POSIX_IPV6 0
#define _POSIX_JOB_CONTROL 1
#define _POSIX_MAPPED_FILES 200112
#define _POSIX_MEMLOCK (-1)
#define _POSIX_MEMLOCK_RANGE 200112
#define _POSIX_MEMORY_PROTECTION 200112
#define _POSIX_MESSAGE_PASSING 200112
#define _POSIX_MONOTONIC_CLOCK 200112
#define _POSIX_NO_TRUNC 1
#define _POSIX_PRIORITIZED_IO (-1)
#define _POSIX_PRIORITY_SCHEDULING 200112
#define _POSIX_RAW_SOCKETS 200112
#define _POSIX_REALTIME_SIGNALS 200112
#define _POSIX_SEMAPHORES 200112
#define _POSIX_SHARED_MEMORY_OBJECTS 200112
#define _POSIX_SPORADIC_SERVER (-1)
#define _POSIX_SYNCHRONIZED_IO (-1)
#define _POSIX_TIMEOUTS 200112
#define _POSIX_TIMERS 200112
#define _POSIX_TYPED_MEMORY_OBJECTS (-1)
#define _POSIX_VDISABLE 0xff
#define _XOPEN_SHM 1
#define _XOPEN_STREAMS (-1)
#define _POSIX_VERSION 200112
#define F_OK 0
#define X_OK 0x01
#define W_OK 0x02
#define R_OK 0x04
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
#define SEEK_DATA 3
#define SEEK_HOLE 4
#define L_SET 0
#define L_INCR 1
#define L_XTND 2
#define _PC_LINK_MAX 1
#define _PC_MAX_CANON 2
#define _PC_MAX_INPUT 3
#define _PC_NAME_MAX 4
#define _PC_PATH_MAX 5
#define _PC_PIPE_BUF 6
#define _PC_CHOWN_RESTRICTED 7
#define _PC_NO_TRUNC 8
#define _PC_VDISABLE 9
#define _PC_ASYNC_IO 53
#define _PC_PRIO_IO 54
#define _PC_SYNC_IO 55
#define _PC_ALLOC_SIZE_MIN 10
#define _PC_FILESIZEBITS 12
#define _PC_REC_INCR_XFER_SIZE 14
#define _PC_REC_MAX_XFER_SIZE 15
#define _PC_REC_MIN_XFER_SIZE 16
#define _PC_REC_XFER_ALIGN 17
#define _PC_SYMLINK_MAX 18
#define _PC_ACL_EXTENDED 59
#define _PC_ACL_PATH_MAX 60
#define _PC_CAP_PRESENT 61
#define _PC_INF_PRESENT 62
#define _PC_MAC_PRESENT 63
#define _PC_ACL_NFS4 64
#define _PC_MIN_HOLE_SIZE 21
#define RFNAMEG (1<<0)
#define RFENVG (1<<1)
#define RFFDG (1<<2)
#define RFNOTEG (1<<3)
#define RFPROC (1<<4)
#define RFMEM (1<<5)
#define RFNOWAIT (1<<6)
#define RFCNAMEG (1<<10)
#define RFCENVG (1<<11)
#define RFCFDG (1<<12)
#define RFTHREAD (1<<13)
#define RFSIGSHARE (1<<14)
#define RFLINUXTHPN (1<<16)
#define RFSTOPPED (1<<17)
#define RFHIGHPID (1<<18)
#define RFTSIGZMB (1<<19)
#define RFTSIGSHIFT 20
#define RFTSIGMASK 0xFF
#define RFPROCDESC (1<<28)
#define RFPPWAIT (1<<31)
#define RFFLAGS ((1<<2) | (1<<4) | (1<<5) | (1<<6) | (1<<12) |      (1<<13) | (1<<14) | (1<<16) | (1<<17) | (1<<18) | (1<<19) |      (1<<28) | (1<<31))
#define RFKERNELONLY ((1<<17) | (1<<18) | (1<<31) | (1<<28))
