from pwnlib.constants.constant import Constant
STDIN_FILENO = Constant('STDIN_FILENO',0)
STDOUT_FILENO = Constant('STDOUT_FILENO',1)
STDERR_FILENO = Constant('STDERR_FILENO',2)
__BSD_VISIBLE = Constant('__BSD_VISIBLE',99999999)
__POSIX_VISIBLE = Constant('__POSIX_VISIBLE',99999999)
__XSI_VISIBLE = Constant('__XSI_VISIBLE',99999999)
INADDR_ANY = Constant('INADDR_ANY',0)
INADDR_BROADCAST = Constant('INADDR_BROADCAST',0xffffffff)
INADDR_NONE = Constant('INADDR_NONE',0xffffffff)
INADDR_LOOPBACK = Constant('INADDR_LOOPBACK',0x7f000001)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EDEADLK = Constant('EDEADLK',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EAGAIN = Constant('EAGAIN',35)
EWOULDBLOCK = Constant('EWOULDBLOCK',35)
EINPROGRESS = Constant('EINPROGRESS',36)
EALREADY = Constant('EALREADY',37)
ENOTSOCK = Constant('ENOTSOCK',38)
EDESTADDRREQ = Constant('EDESTADDRREQ',39)
EMSGSIZE = Constant('EMSGSIZE',40)
EPROTOTYPE = Constant('EPROTOTYPE',41)
ENOPROTOOPT = Constant('ENOPROTOOPT',42)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',43)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',44)
EOPNOTSUPP = Constant('EOPNOTSUPP',45)
ENOTSUP = Constant('ENOTSUP',45)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',46)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',47)
EADDRINUSE = Constant('EADDRINUSE',48)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',49)
ENETDOWN = Constant('ENETDOWN',50)
ENETUNREACH = Constant('ENETUNREACH',51)
ENETRESET = Constant('ENETRESET',52)
ECONNABORTED = Constant('ECONNABORTED',53)
ECONNRESET = Constant('ECONNRESET',54)
ENOBUFS = Constant('ENOBUFS',55)
EISCONN = Constant('EISCONN',56)
ENOTCONN = Constant('ENOTCONN',57)
ESHUTDOWN = Constant('ESHUTDOWN',58)
ETOOMANYREFS = Constant('ETOOMANYREFS',59)
ETIMEDOUT = Constant('ETIMEDOUT',60)
ECONNREFUSED = Constant('ECONNREFUSED',61)
ELOOP = Constant('ELOOP',62)
ENAMETOOLONG = Constant('ENAMETOOLONG',63)
EHOSTDOWN = Constant('EHOSTDOWN',64)
EHOSTUNREACH = Constant('EHOSTUNREACH',65)
ENOTEMPTY = Constant('ENOTEMPTY',66)
EPROCLIM = Constant('EPROCLIM',67)
EUSERS = Constant('EUSERS',68)
EDQUOT = Constant('EDQUOT',69)
ESTALE = Constant('ESTALE',70)
EREMOTE = Constant('EREMOTE',71)
EBADRPC = Constant('EBADRPC',72)
ERPCMISMATCH = Constant('ERPCMISMATCH',73)
EPROGUNAVAIL = Constant('EPROGUNAVAIL',74)
EPROGMISMATCH = Constant('EPROGMISMATCH',75)
EPROCUNAVAIL = Constant('EPROCUNAVAIL',76)
ENOLCK = Constant('ENOLCK',77)
ENOSYS = Constant('ENOSYS',78)
EFTYPE = Constant('EFTYPE',79)
EAUTH = Constant('EAUTH',80)
ENEEDAUTH = Constant('ENEEDAUTH',81)
EIDRM = Constant('EIDRM',82)
ENOMSG = Constant('ENOMSG',83)
EOVERFLOW = Constant('EOVERFLOW',84)
ECANCELED = Constant('ECANCELED',85)
EILSEQ = Constant('EILSEQ',86)
ENOATTR = Constant('ENOATTR',87)
EDOOFUS = Constant('EDOOFUS',88)
EBADMSG = Constant('EBADMSG',89)
EMULTIHOP = Constant('EMULTIHOP',90)
ENOLINK = Constant('ENOLINK',91)
EPROTO = Constant('EPROTO',92)
ENOTCAPABLE = Constant('ENOTCAPABLE',93)
ECAPMODE = Constant('ECAPMODE',94)
ELAST = Constant('ELAST',94)
O_RDONLY = Constant('O_RDONLY',0x0000)
O_WRONLY = Constant('O_WRONLY',0x0001)
O_RDWR = Constant('O_RDWR',0x0002)
O_ACCMODE = Constant('O_ACCMODE',0x0003)
FREAD = Constant('FREAD',0x0001)
FWRITE = Constant('FWRITE',0x0002)
O_NONBLOCK = Constant('O_NONBLOCK',0x0004)
O_APPEND = Constant('O_APPEND',0x0008)
O_SHLOCK = Constant('O_SHLOCK',0x0010)
O_EXLOCK = Constant('O_EXLOCK',0x0020)
O_ASYNC = Constant('O_ASYNC',0x0040)
O_FSYNC = Constant('O_FSYNC',0x0080)
O_SYNC = Constant('O_SYNC',0x0080)
O_NOFOLLOW = Constant('O_NOFOLLOW',0x0100)
O_CREAT = Constant('O_CREAT',0x0200)
O_TRUNC = Constant('O_TRUNC',0x0400)
O_EXCL = Constant('O_EXCL',0x0800)
O_NOCTTY = Constant('O_NOCTTY',0x8000)
O_DIRECT = Constant('O_DIRECT',0x00010000)
O_DIRECTORY = Constant('O_DIRECTORY',0x00020000)
O_EXEC = Constant('O_EXEC',0x00040000)
O_TTY_INIT = Constant('O_TTY_INIT',0x00080000)
O_CLOEXEC = Constant('O_CLOEXEC',0x00100000)
FAPPEND = Constant('FAPPEND',0x0008)
FASYNC = Constant('FASYNC',0x0040)
FFSYNC = Constant('FFSYNC',0x0080)
FNONBLOCK = Constant('FNONBLOCK',0x0004)
FNDELAY = Constant('FNDELAY',0x0004)
O_NDELAY = Constant('O_NDELAY',0x0004)
FRDAHEAD = Constant('FRDAHEAD',0x0200)
AT_FDCWD = Constant('AT_FDCWD',-100)
AT_EACCESS = Constant('AT_EACCESS',0x100)
AT_SYMLINK_NOFOLLOW = Constant('AT_SYMLINK_NOFOLLOW',0x200)
AT_SYMLINK_FOLLOW = Constant('AT_SYMLINK_FOLLOW',0x400)
AT_REMOVEDIR = Constant('AT_REMOVEDIR',0x800)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETOWN = Constant('F_GETOWN',5)
F_SETOWN = Constant('F_SETOWN',6)
F_OGETLK = Constant('F_OGETLK',7)
F_OSETLK = Constant('F_OSETLK',8)
F_OSETLKW = Constant('F_OSETLKW',9)
F_DUP2FD = Constant('F_DUP2FD',10)
F_GETLK = Constant('F_GETLK',11)
F_SETLK = Constant('F_SETLK',12)
F_SETLKW = Constant('F_SETLKW',13)
F_SETLK_REMOTE = Constant('F_SETLK_REMOTE',14)
F_READAHEAD = Constant('F_READAHEAD',15)
F_RDAHEAD = Constant('F_RDAHEAD',16)
F_DUPFD_CLOEXEC = Constant('F_DUPFD_CLOEXEC',17)
F_DUP2FD_CLOEXEC = Constant('F_DUP2FD_CLOEXEC',18)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',1)
F_UNLCK = Constant('F_UNLCK',2)
F_WRLCK = Constant('F_WRLCK',3)
F_UNLCKSYS = Constant('F_UNLCKSYS',4)
F_CANCEL = Constant('F_CANCEL',5)
LOCK_SH = Constant('LOCK_SH',0x01)
LOCK_EX = Constant('LOCK_EX',0x02)
LOCK_NB = Constant('LOCK_NB',0x04)
LOCK_UN = Constant('LOCK_UN',0x08)
POSIX_FADV_NORMAL = Constant('POSIX_FADV_NORMAL',0)
POSIX_FADV_RANDOM = Constant('POSIX_FADV_RANDOM',1)
POSIX_FADV_SEQUENTIAL = Constant('POSIX_FADV_SEQUENTIAL',2)
POSIX_FADV_WILLNEED = Constant('POSIX_FADV_WILLNEED',3)
POSIX_FADV_DONTNEED = Constant('POSIX_FADV_DONTNEED',4)
POSIX_FADV_NOREUSE = Constant('POSIX_FADV_NOREUSE',5)
INHERIT_SHARE = Constant('INHERIT_SHARE',0)
INHERIT_COPY = Constant('INHERIT_COPY',1)
INHERIT_NONE = Constant('INHERIT_NONE',2)
PROT_NONE = Constant('PROT_NONE',0x00)
PROT_READ = Constant('PROT_READ',0x01)
PROT_WRITE = Constant('PROT_WRITE',0x02)
PROT_EXEC = Constant('PROT_EXEC',0x04)
MAP_SHARED = Constant('MAP_SHARED',0x0001)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x0002)
MAP_COPY = Constant('MAP_COPY',0x0002)
MAP_FIXED = Constant('MAP_FIXED',0x0010)
MAP_RENAME = Constant('MAP_RENAME',0x0020)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x0040)
MAP_RESERVED0080 = Constant('MAP_RESERVED0080',0x0080)
MAP_RESERVED0100 = Constant('MAP_RESERVED0100',0x0100)
MAP_HASSEMAPHORE = Constant('MAP_HASSEMAPHORE',0x0200)
MAP_STACK = Constant('MAP_STACK',0x0400)
MAP_NOSYNC = Constant('MAP_NOSYNC',0x0800)
MAP_FILE = Constant('MAP_FILE',0x0000)
MAP_ANON = Constant('MAP_ANON',0x1000)
MAP_ANONYMOUS = Constant('MAP_ANONYMOUS',0x1000)
MAP_NOCORE = Constant('MAP_NOCORE',0x00020000)
MAP_PREFAULT_READ = Constant('MAP_PREFAULT_READ',0x00040000)
MCL_CURRENT = Constant('MCL_CURRENT',0x0001)
MCL_FUTURE = Constant('MCL_FUTURE',0x0002)
MS_SYNC = Constant('MS_SYNC',0x0000)
MS_ASYNC = Constant('MS_ASYNC',0x0001)
MS_INVALIDATE = Constant('MS_INVALIDATE',0x0002)
_MADV_NORMAL = Constant('_MADV_NORMAL',0)
_MADV_RANDOM = Constant('_MADV_RANDOM',1)
_MADV_SEQUENTIAL = Constant('_MADV_SEQUENTIAL',2)
_MADV_WILLNEED = Constant('_MADV_WILLNEED',3)
_MADV_DONTNEED = Constant('_MADV_DONTNEED',4)
MADV_NORMAL = Constant('MADV_NORMAL',0)
MADV_RANDOM = Constant('MADV_RANDOM',1)
MADV_SEQUENTIAL = Constant('MADV_SEQUENTIAL',2)
MADV_WILLNEED = Constant('MADV_WILLNEED',3)
MADV_DONTNEED = Constant('MADV_DONTNEED',4)
MADV_FREE = Constant('MADV_FREE',5)
MADV_NOSYNC = Constant('MADV_NOSYNC',6)
MADV_AUTOSYNC = Constant('MADV_AUTOSYNC',7)
MADV_NOCORE = Constant('MADV_NOCORE',8)
MADV_CORE = Constant('MADV_CORE',9)
MADV_PROTECT = Constant('MADV_PROTECT',10)
MINCORE_INCORE = Constant('MINCORE_INCORE',0x1)
MINCORE_REFERENCED = Constant('MINCORE_REFERENCED',0x2)
MINCORE_MODIFIED = Constant('MINCORE_MODIFIED',0x4)
MINCORE_REFERENCED_OTHER = Constant('MINCORE_REFERENCED_OTHER',0x8)
MINCORE_MODIFIED_OTHER = Constant('MINCORE_MODIFIED_OTHER',0x10)
POSIX_MADV_NORMAL = Constant('POSIX_MADV_NORMAL',0)
POSIX_MADV_RANDOM = Constant('POSIX_MADV_RANDOM',1)
POSIX_MADV_SEQUENTIAL = Constant('POSIX_MADV_SEQUENTIAL',2)
POSIX_MADV_WILLNEED = Constant('POSIX_MADV_WILLNEED',3)
POSIX_MADV_DONTNEED = Constant('POSIX_MADV_DONTNEED',4)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGIOT = Constant('SIGIOT',6)
SIGEMT = Constant('SIGEMT',7)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGBUS = Constant('SIGBUS',10)
SIGSEGV = Constant('SIGSEGV',11)
SIGSYS = Constant('SIGSYS',12)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGURG = Constant('SIGURG',16)
SIGSTOP = Constant('SIGSTOP',17)
SIGTSTP = Constant('SIGTSTP',18)
SIGCONT = Constant('SIGCONT',19)
SIGCHLD = Constant('SIGCHLD',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGIO = Constant('SIGIO',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGINFO = Constant('SIGINFO',29)
SIGUSR1 = Constant('SIGUSR1',30)
SIGUSR2 = Constant('SIGUSR2',31)
SIGTHR = Constant('SIGTHR',32)
SIGLWP = Constant('SIGLWP',32)
SIGRTMIN = Constant('SIGRTMIN',65)
SIGRTMAX = Constant('SIGRTMAX',126)
SIGEV_NONE = Constant('SIGEV_NONE',0)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',2)
SIGEV_KEVENT = Constant('SIGEV_KEVENT',3)
SIGEV_THREAD_ID = Constant('SIGEV_THREAD_ID',4)
ILL_ILLOPC = Constant('ILL_ILLOPC',1)
ILL_ILLOPN = Constant('ILL_ILLOPN',2)
ILL_ILLADR = Constant('ILL_ILLADR',3)
ILL_ILLTRP = Constant('ILL_ILLTRP',4)
ILL_PRVOPC = Constant('ILL_PRVOPC',5)
ILL_PRVREG = Constant('ILL_PRVREG',6)
ILL_COPROC = Constant('ILL_COPROC',7)
ILL_BADSTK = Constant('ILL_BADSTK',8)
BUS_ADRALN = Constant('BUS_ADRALN',1)
BUS_ADRERR = Constant('BUS_ADRERR',2)
BUS_OBJERR = Constant('BUS_OBJERR',3)
SEGV_MAPERR = Constant('SEGV_MAPERR',1)
SEGV_ACCERR = Constant('SEGV_ACCERR',2)
FPE_INTOVF = Constant('FPE_INTOVF',1)
FPE_INTDIV = Constant('FPE_INTDIV',2)
FPE_FLTDIV = Constant('FPE_FLTDIV',3)
FPE_FLTOVF = Constant('FPE_FLTOVF',4)
FPE_FLTUND = Constant('FPE_FLTUND',5)
FPE_FLTRES = Constant('FPE_FLTRES',6)
FPE_FLTINV = Constant('FPE_FLTINV',7)
FPE_FLTSUB = Constant('FPE_FLTSUB',8)
TRAP_BRKPT = Constant('TRAP_BRKPT',1)
TRAP_TRACE = Constant('TRAP_TRACE',2)
TRAP_DTRACE = Constant('TRAP_DTRACE',3)
CLD_EXITED = Constant('CLD_EXITED',1)
CLD_KILLED = Constant('CLD_KILLED',2)
CLD_DUMPED = Constant('CLD_DUMPED',3)
CLD_TRAPPED = Constant('CLD_TRAPPED',4)
CLD_STOPPED = Constant('CLD_STOPPED',5)
CLD_CONTINUED = Constant('CLD_CONTINUED',6)
POLL_IN = Constant('POLL_IN',1)
POLL_OUT = Constant('POLL_OUT',2)
POLL_MSG = Constant('POLL_MSG',3)
POLL_ERR = Constant('POLL_ERR',4)
POLL_PRI = Constant('POLL_PRI',5)
POLL_HUP = Constant('POLL_HUP',6)
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',0x0008)
SA_ONSTACK = Constant('SA_ONSTACK',0x0001)
SA_RESTART = Constant('SA_RESTART',0x0002)
SA_RESETHAND = Constant('SA_RESETHAND',0x0004)
SA_NODEFER = Constant('SA_NODEFER',0x0010)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x0020)
SA_SIGINFO = Constant('SA_SIGINFO',0x0040)
NSIG = Constant('NSIG',32)
SI_NOINFO = Constant('SI_NOINFO',0)
SI_USER = Constant('SI_USER',0x10001)
SI_QUEUE = Constant('SI_QUEUE',0x10002)
SI_TIMER = Constant('SI_TIMER',0x10003)
SI_ASYNCIO = Constant('SI_ASYNCIO',0x10004)
SI_MESGQ = Constant('SI_MESGQ',0x10005)
SI_KERNEL = Constant('SI_KERNEL',0x10006)
SI_LWP = Constant('SI_LWP',0x10007)
SI_UNDEFINED = Constant('SI_UNDEFINED',0)
SS_ONSTACK = Constant('SS_ONSTACK',0x0001)
SS_DISABLE = Constant('SS_DISABLE',0x0004)
SV_ONSTACK = Constant('SV_ONSTACK',0x0001)
SV_INTERRUPT = Constant('SV_INTERRUPT',0x0002)
SV_RESETHAND = Constant('SV_RESETHAND',0x0004)
SV_NODEFER = Constant('SV_NODEFER',0x0010)
SV_NOCLDSTOP = Constant('SV_NOCLDSTOP',0x0008)
SV_SIGINFO = Constant('SV_SIGINFO',0x0040)
SIG_BLOCK = Constant('SIG_BLOCK',1)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',2)
SIG_SETMASK = Constant('SIG_SETMASK',3)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SO_DEBUG = Constant('SO_DEBUG',0x0001)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',0x0002)
SO_REUSEADDR = Constant('SO_REUSEADDR',0x0004)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',0x0008)
SO_DONTROUTE = Constant('SO_DONTROUTE',0x0010)
SO_BROADCAST = Constant('SO_BROADCAST',0x0020)
SO_USELOOPBACK = Constant('SO_USELOOPBACK',0x0040)
SO_LINGER = Constant('SO_LINGER',0x0080)
SO_OOBINLINE = Constant('SO_OOBINLINE',0x0100)
SO_REUSEPORT = Constant('SO_REUSEPORT',0x0200)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',0x0400)
SO_NOSIGPIPE = Constant('SO_NOSIGPIPE',0x0800)
SO_ACCEPTFILTER = Constant('SO_ACCEPTFILTER',0x1000)
SO_BINTIME = Constant('SO_BINTIME',0x2000)
SO_NO_OFFLOAD = Constant('SO_NO_OFFLOAD',0x4000)
SO_NO_DDP = Constant('SO_NO_DDP',0x8000)
SO_SNDBUF = Constant('SO_SNDBUF',0x1001)
SO_RCVBUF = Constant('SO_RCVBUF',0x1002)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',0x1003)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',0x1004)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',0x1005)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',0x1006)
SO_ERROR = Constant('SO_ERROR',0x1007)
SO_TYPE = Constant('SO_TYPE',0x1008)
SO_LABEL = Constant('SO_LABEL',0x1009)
SO_PEERLABEL = Constant('SO_PEERLABEL',0x1010)
SO_LISTENQLIMIT = Constant('SO_LISTENQLIMIT',0x1011)
SO_LISTENQLEN = Constant('SO_LISTENQLEN',0x1012)
SO_LISTENINCQLEN = Constant('SO_LISTENINCQLEN',0x1013)
SO_SETFIB = Constant('SO_SETFIB',0x1014)
SO_USER_COOKIE = Constant('SO_USER_COOKIE',0x1015)
SO_PROTOCOL = Constant('SO_PROTOCOL',0x1016)
SO_PROTOTYPE = Constant('SO_PROTOTYPE',0x1016)
SO_VENDOR = Constant('SO_VENDOR',0x80000000)
SOL_SOCKET = Constant('SOL_SOCKET',0xffff)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_INET = Constant('AF_INET',2)
AF_IMPLINK = Constant('AF_IMPLINK',3)
AF_PUP = Constant('AF_PUP',4)
AF_CHAOS = Constant('AF_CHAOS',5)
AF_NETBIOS = Constant('AF_NETBIOS',6)
AF_ISO = Constant('AF_ISO',7)
AF_OSI = Constant('AF_OSI',7)
AF_ECMA = Constant('AF_ECMA',8)
AF_DATAKIT = Constant('AF_DATAKIT',9)
AF_CCITT = Constant('AF_CCITT',10)
AF_SNA = Constant('AF_SNA',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_DLI = Constant('AF_DLI',13)
AF_LAT = Constant('AF_LAT',14)
AF_HYLINK = Constant('AF_HYLINK',15)
AF_APPLETALK = Constant('AF_APPLETALK',16)
AF_ROUTE = Constant('AF_ROUTE',17)
AF_LINK = Constant('AF_LINK',18)
pseudo_AF_XTP = Constant('pseudo_AF_XTP',19)
AF_COIP = Constant('AF_COIP',20)
AF_CNT = Constant('AF_CNT',21)
pseudo_AF_RTIP = Constant('pseudo_AF_RTIP',22)
AF_IPX = Constant('AF_IPX',23)
AF_SIP = Constant('AF_SIP',24)
pseudo_AF_PIP = Constant('pseudo_AF_PIP',25)
AF_ISDN = Constant('AF_ISDN',26)
AF_E164 = Constant('AF_E164',26)
pseudo_AF_KEY = Constant('pseudo_AF_KEY',27)
AF_INET6 = Constant('AF_INET6',28)
AF_NATM = Constant('AF_NATM',29)
AF_ATM = Constant('AF_ATM',30)
pseudo_AF_HDRCMPLT = Constant('pseudo_AF_HDRCMPLT',31)
AF_NETGRAPH = Constant('AF_NETGRAPH',32)
AF_SLOW = Constant('AF_SLOW',33)
AF_SCLUSTER = Constant('AF_SCLUSTER',34)
AF_ARP = Constant('AF_ARP',35)
AF_BLUETOOTH = Constant('AF_BLUETOOTH',36)
AF_IEEE80211 = Constant('AF_IEEE80211',37)
AF_MAX = Constant('AF_MAX',38)
AF_VENDOR00 = Constant('AF_VENDOR00',39)
AF_VENDOR01 = Constant('AF_VENDOR01',41)
AF_VENDOR02 = Constant('AF_VENDOR02',43)
AF_VENDOR03 = Constant('AF_VENDOR03',45)
AF_VENDOR04 = Constant('AF_VENDOR04',47)
AF_VENDOR05 = Constant('AF_VENDOR05',49)
AF_VENDOR06 = Constant('AF_VENDOR06',51)
AF_VENDOR07 = Constant('AF_VENDOR07',53)
AF_VENDOR08 = Constant('AF_VENDOR08',55)
AF_VENDOR09 = Constant('AF_VENDOR09',57)
AF_VENDOR10 = Constant('AF_VENDOR10',59)
AF_VENDOR11 = Constant('AF_VENDOR11',61)
AF_VENDOR12 = Constant('AF_VENDOR12',63)
AF_VENDOR13 = Constant('AF_VENDOR13',65)
AF_VENDOR14 = Constant('AF_VENDOR14',67)
AF_VENDOR15 = Constant('AF_VENDOR15',69)
AF_VENDOR16 = Constant('AF_VENDOR16',71)
AF_VENDOR17 = Constant('AF_VENDOR17',73)
AF_VENDOR18 = Constant('AF_VENDOR18',75)
AF_VENDOR19 = Constant('AF_VENDOR19',77)
AF_VENDOR20 = Constant('AF_VENDOR20',79)
AF_VENDOR21 = Constant('AF_VENDOR21',81)
AF_VENDOR22 = Constant('AF_VENDOR22',83)
AF_VENDOR23 = Constant('AF_VENDOR23',85)
AF_VENDOR24 = Constant('AF_VENDOR24',87)
AF_VENDOR25 = Constant('AF_VENDOR25',89)
AF_VENDOR26 = Constant('AF_VENDOR26',91)
AF_VENDOR27 = Constant('AF_VENDOR27',93)
AF_VENDOR28 = Constant('AF_VENDOR28',95)
AF_VENDOR29 = Constant('AF_VENDOR29',97)
AF_VENDOR30 = Constant('AF_VENDOR30',99)
AF_VENDOR31 = Constant('AF_VENDOR31',101)
AF_VENDOR32 = Constant('AF_VENDOR32',103)
AF_VENDOR33 = Constant('AF_VENDOR33',105)
AF_VENDOR34 = Constant('AF_VENDOR34',107)
AF_VENDOR35 = Constant('AF_VENDOR35',109)
AF_VENDOR36 = Constant('AF_VENDOR36',111)
AF_VENDOR37 = Constant('AF_VENDOR37',113)
AF_VENDOR38 = Constant('AF_VENDOR38',115)
AF_VENDOR39 = Constant('AF_VENDOR39',117)
AF_VENDOR40 = Constant('AF_VENDOR40',119)
AF_VENDOR41 = Constant('AF_VENDOR41',121)
AF_VENDOR42 = Constant('AF_VENDOR42',123)
AF_VENDOR43 = Constant('AF_VENDOR43',125)
AF_VENDOR44 = Constant('AF_VENDOR44',127)
AF_VENDOR45 = Constant('AF_VENDOR45',129)
AF_VENDOR46 = Constant('AF_VENDOR46',131)
AF_VENDOR47 = Constant('AF_VENDOR47',133)
SOCK_MAXADDRLEN = Constant('SOCK_MAXADDRLEN',255)
PF_UNSPEC = Constant('PF_UNSPEC',0)
PF_LOCAL = Constant('PF_LOCAL',1)
PF_UNIX = Constant('PF_UNIX',1)
PF_INET = Constant('PF_INET',2)
PF_IMPLINK = Constant('PF_IMPLINK',3)
PF_PUP = Constant('PF_PUP',4)
PF_CHAOS = Constant('PF_CHAOS',5)
PF_NETBIOS = Constant('PF_NETBIOS',6)
PF_ISO = Constant('PF_ISO',7)
PF_OSI = Constant('PF_OSI',7)
PF_ECMA = Constant('PF_ECMA',8)
PF_DATAKIT = Constant('PF_DATAKIT',9)
PF_CCITT = Constant('PF_CCITT',10)
PF_SNA = Constant('PF_SNA',11)
PF_DECnet = Constant('PF_DECnet',12)
PF_DLI = Constant('PF_DLI',13)
PF_LAT = Constant('PF_LAT',14)
PF_HYLINK = Constant('PF_HYLINK',15)
PF_APPLETALK = Constant('PF_APPLETALK',16)
PF_ROUTE = Constant('PF_ROUTE',17)
PF_LINK = Constant('PF_LINK',18)
PF_XTP = Constant('PF_XTP',19)
PF_COIP = Constant('PF_COIP',20)
PF_CNT = Constant('PF_CNT',21)
PF_SIP = Constant('PF_SIP',24)
PF_IPX = Constant('PF_IPX',23)
PF_RTIP = Constant('PF_RTIP',22)
PF_PIP = Constant('PF_PIP',25)
PF_ISDN = Constant('PF_ISDN',26)
PF_KEY = Constant('PF_KEY',27)
PF_INET6 = Constant('PF_INET6',28)
PF_NATM = Constant('PF_NATM',29)
PF_ATM = Constant('PF_ATM',30)
PF_NETGRAPH = Constant('PF_NETGRAPH',32)
PF_SLOW = Constant('PF_SLOW',33)
PF_SCLUSTER = Constant('PF_SCLUSTER',34)
PF_ARP = Constant('PF_ARP',35)
PF_BLUETOOTH = Constant('PF_BLUETOOTH',36)
PF_MAX = Constant('PF_MAX',38)
NET_MAXID = Constant('NET_MAXID',38)
NET_RT_DUMP = Constant('NET_RT_DUMP',1)
NET_RT_FLAGS = Constant('NET_RT_FLAGS',2)
NET_RT_IFLIST = Constant('NET_RT_IFLIST',3)
NET_RT_IFMALIST = Constant('NET_RT_IFMALIST',4)
NET_RT_IFLISTL = Constant('NET_RT_IFLISTL',5)
NET_RT_MAXID = Constant('NET_RT_MAXID',6)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',0x1)
MSG_PEEK = Constant('MSG_PEEK',0x2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',0x4)
MSG_EOR = Constant('MSG_EOR',0x8)
MSG_TRUNC = Constant('MSG_TRUNC',0x10)
MSG_CTRUNC = Constant('MSG_CTRUNC',0x20)
MSG_WAITALL = Constant('MSG_WAITALL',0x40)
MSG_NOTIFICATION = Constant('MSG_NOTIFICATION',0x2000)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x80)
MSG_EOF = Constant('MSG_EOF',0x100)
MSG_NBIO = Constant('MSG_NBIO',0x4000)
MSG_COMPAT = Constant('MSG_COMPAT',0x8000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x20000)
CMGROUP_MAX = Constant('CMGROUP_MAX',16)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',0x02)
SCM_CREDS = Constant('SCM_CREDS',0x03)
SCM_BINTIME = Constant('SCM_BINTIME',0x04)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
PRU_FLUSH_RD = Constant('PRU_FLUSH_RD',0)
PRU_FLUSH_WR = Constant('PRU_FLUSH_WR',1)
PRU_FLUSH_RDWR = Constant('PRU_FLUSH_RDWR',2)
SF_NODISKIO = Constant('SF_NODISKIO',0x00000001)
SF_MNOWAIT = Constant('SF_MNOWAIT',0x00000002)
SF_SYNC = Constant('SF_SYNC',0x00000004)
S_ISUID = Constant('S_ISUID',0o004000)
S_ISGID = Constant('S_ISGID',0o002000)
S_ISTXT = Constant('S_ISTXT',0o001000)
S_IRWXU = Constant('S_IRWXU',0o000700)
S_IRUSR = Constant('S_IRUSR',0o000400)
S_IWUSR = Constant('S_IWUSR',0o000200)
S_IXUSR = Constant('S_IXUSR',0o000100)
S_IREAD = Constant('S_IREAD',0o000400)
S_IWRITE = Constant('S_IWRITE',0o000200)
S_IEXEC = Constant('S_IEXEC',0o000100)
S_IRWXG = Constant('S_IRWXG',0o000070)
S_IRGRP = Constant('S_IRGRP',0o000040)
S_IWGRP = Constant('S_IWGRP',0o000020)
S_IXGRP = Constant('S_IXGRP',0o000010)
S_IRWXO = Constant('S_IRWXO',0o000007)
S_IROTH = Constant('S_IROTH',0o000004)
S_IWOTH = Constant('S_IWOTH',0o000002)
S_IXOTH = Constant('S_IXOTH',0o000001)
S_IFMT = Constant('S_IFMT',0o170000)
S_IFIFO = Constant('S_IFIFO',0o010000)
S_IFCHR = Constant('S_IFCHR',0o020000)
S_IFDIR = Constant('S_IFDIR',0o040000)
S_IFBLK = Constant('S_IFBLK',0o060000)
S_IFREG = Constant('S_IFREG',0o100000)
S_IFLNK = Constant('S_IFLNK',0o120000)
S_IFSOCK = Constant('S_IFSOCK',0o140000)
S_ISVTX = Constant('S_ISVTX',0o001000)
S_IFWHT = Constant('S_IFWHT',0o160000)
ACCESSPERMS = Constant('ACCESSPERMS',(0o000700|0o000070|0o000007))
ALLPERMS = Constant('ALLPERMS',(0o004000|0o002000|0o001000|0o000700|0o000070|0o000007))
DEFFILEMODE = Constant('DEFFILEMODE',(0o000400|0o000200|0o000040|0o000020|0o000004|0o000002))
S_BLKSIZE = Constant('S_BLKSIZE',512)
UF_SETTABLE = Constant('UF_SETTABLE',0x0000ffff)
UF_NODUMP = Constant('UF_NODUMP',0x00000001)
UF_IMMUTABLE = Constant('UF_IMMUTABLE',0x00000002)
UF_APPEND = Constant('UF_APPEND',0x00000004)
UF_OPAQUE = Constant('UF_OPAQUE',0x00000008)
UF_NOUNLINK = Constant('UF_NOUNLINK',0x00000010)
SF_SETTABLE = Constant('SF_SETTABLE',0xffff0000)
SF_ARCHIVED = Constant('SF_ARCHIVED',0x00010000)
SF_IMMUTABLE = Constant('SF_IMMUTABLE',0x00020000)
SF_APPEND = Constant('SF_APPEND',0x00040000)
SF_NOUNLINK = Constant('SF_NOUNLINK',0x00100000)
SF_SNAPSHOT = Constant('SF_SNAPSHOT',0x00200000)
SYS_syscall = Constant('SYS_syscall',0)
SYS_exit = Constant('SYS_exit',1)
SYS_fork = Constant('SYS_fork',2)
SYS_read = Constant('SYS_read',3)
SYS_write = Constant('SYS_write',4)
SYS_open = Constant('SYS_open',5)
SYS_close = Constant('SYS_close',6)
SYS_wait4 = Constant('SYS_wait4',7)
SYS_link = Constant('SYS_link',9)
SYS_unlink = Constant('SYS_unlink',10)
SYS_chdir = Constant('SYS_chdir',12)
SYS_fchdir = Constant('SYS_fchdir',13)
SYS_mknod = Constant('SYS_mknod',14)
SYS_chmod = Constant('SYS_chmod',15)
SYS_chown = Constant('SYS_chown',16)
SYS_break = Constant('SYS_break',17)
SYS_freebsd4_getfsstat = Constant('SYS_freebsd4_getfsstat',18)
SYS_getpid = Constant('SYS_getpid',20)
SYS_mount = Constant('SYS_mount',21)
SYS_unmount = Constant('SYS_unmount',22)
SYS_setuid = Constant('SYS_setuid',23)
SYS_getuid = Constant('SYS_getuid',24)
SYS_geteuid = Constant('SYS_geteuid',25)
SYS_ptrace = Constant('SYS_ptrace',26)
SYS_recvmsg = Constant('SYS_recvmsg',27)
SYS_sendmsg = Constant('SYS_sendmsg',28)
SYS_recvfrom = Constant('SYS_recvfrom',29)
SYS_accept = Constant('SYS_accept',30)
SYS_getpeername = Constant('SYS_getpeername',31)
SYS_getsockname = Constant('SYS_getsockname',32)
SYS_access = Constant('SYS_access',33)
SYS_chflags = Constant('SYS_chflags',34)
SYS_fchflags = Constant('SYS_fchflags',35)
SYS_sync = Constant('SYS_sync',36)
SYS_kill = Constant('SYS_kill',37)
SYS_getppid = Constant('SYS_getppid',39)
SYS_dup = Constant('SYS_dup',41)
SYS_pipe = Constant('SYS_pipe',42)
SYS_getegid = Constant('SYS_getegid',43)
SYS_profil = Constant('SYS_profil',44)
SYS_ktrace = Constant('SYS_ktrace',45)
SYS_getgid = Constant('SYS_getgid',47)
SYS_getlogin = Constant('SYS_getlogin',49)
SYS_setlogin = Constant('SYS_setlogin',50)
SYS_acct = Constant('SYS_acct',51)
SYS_sigaltstack = Constant('SYS_sigaltstack',53)
SYS_ioctl = Constant('SYS_ioctl',54)
SYS_reboot = Constant('SYS_reboot',55)
SYS_revoke = Constant('SYS_revoke',56)
SYS_symlink = Constant('SYS_symlink',57)
SYS_readlink = Constant('SYS_readlink',58)
SYS_execve = Constant('SYS_execve',59)
SYS_umask = Constant('SYS_umask',60)
SYS_chroot = Constant('SYS_chroot',61)
SYS_msync = Constant('SYS_msync',65)
SYS_vfork = Constant('SYS_vfork',66)
SYS_sbrk = Constant('SYS_sbrk',69)
SYS_sstk = Constant('SYS_sstk',70)
SYS_vadvise = Constant('SYS_vadvise',72)
SYS_munmap = Constant('SYS_munmap',73)
SYS_mprotect = Constant('SYS_mprotect',74)
SYS_madvise = Constant('SYS_madvise',75)
SYS_mincore = Constant('SYS_mincore',78)
SYS_getgroups = Constant('SYS_getgroups',79)
SYS_setgroups = Constant('SYS_setgroups',80)
SYS_getpgrp = Constant('SYS_getpgrp',81)
SYS_setpgid = Constant('SYS_setpgid',82)
SYS_setitimer = Constant('SYS_setitimer',83)
SYS_swapon = Constant('SYS_swapon',85)
SYS_getitimer = Constant('SYS_getitimer',86)
SYS_getdtablesize = Constant('SYS_getdtablesize',89)
SYS_dup2 = Constant('SYS_dup2',90)
SYS_fcntl = Constant('SYS_fcntl',92)
SYS_select = Constant('SYS_select',93)
SYS_fsync = Constant('SYS_fsync',95)
SYS_setpriority = Constant('SYS_setpriority',96)
SYS_socket = Constant('SYS_socket',97)
SYS_connect = Constant('SYS_connect',98)
SYS_getpriority = Constant('SYS_getpriority',100)
SYS_bind = Constant('SYS_bind',104)
SYS_setsockopt = Constant('SYS_setsockopt',105)
SYS_listen = Constant('SYS_listen',106)
SYS_gettimeofday = Constant('SYS_gettimeofday',116)
SYS_getrusage = Constant('SYS_getrusage',117)
SYS_getsockopt = Constant('SYS_getsockopt',118)
SYS_readv = Constant('SYS_readv',120)
SYS_writev = Constant('SYS_writev',121)
SYS_settimeofday = Constant('SYS_settimeofday',122)
SYS_fchown = Constant('SYS_fchown',123)
SYS_fchmod = Constant('SYS_fchmod',124)
SYS_setreuid = Constant('SYS_setreuid',126)
SYS_setregid = Constant('SYS_setregid',127)
SYS_rename = Constant('SYS_rename',128)
SYS_flock = Constant('SYS_flock',131)
SYS_mkfifo = Constant('SYS_mkfifo',132)
SYS_sendto = Constant('SYS_sendto',133)
SYS_shutdown = Constant('SYS_shutdown',134)
SYS_socketpair = Constant('SYS_socketpair',135)
SYS_mkdir = Constant('SYS_mkdir',136)
SYS_rmdir = Constant('SYS_rmdir',137)
SYS_utimes = Constant('SYS_utimes',138)
SYS_adjtime = Constant('SYS_adjtime',140)
SYS_setsid = Constant('SYS_setsid',147)
SYS_quotactl = Constant('SYS_quotactl',148)
SYS_nlm_syscall = Constant('SYS_nlm_syscall',154)
SYS_nfssvc = Constant('SYS_nfssvc',155)
SYS_freebsd4_statfs = Constant('SYS_freebsd4_statfs',157)
SYS_freebsd4_fstatfs = Constant('SYS_freebsd4_fstatfs',158)
SYS_lgetfh = Constant('SYS_lgetfh',160)
SYS_getfh = Constant('SYS_getfh',161)
SYS_freebsd4_getdomainname = Constant('SYS_freebsd4_getdomainname',162)
SYS_freebsd4_setdomainname = Constant('SYS_freebsd4_setdomainname',163)
SYS_freebsd4_uname = Constant('SYS_freebsd4_uname',164)
SYS_sysarch = Constant('SYS_sysarch',165)
SYS_rtprio = Constant('SYS_rtprio',166)
SYS_semsys = Constant('SYS_semsys',169)
SYS_msgsys = Constant('SYS_msgsys',170)
SYS_shmsys = Constant('SYS_shmsys',171)
SYS_freebsd6_pread = Constant('SYS_freebsd6_pread',173)
SYS_freebsd6_pwrite = Constant('SYS_freebsd6_pwrite',174)
SYS_setfib = Constant('SYS_setfib',175)
SYS_ntp_adjtime = Constant('SYS_ntp_adjtime',176)
SYS_setgid = Constant('SYS_setgid',181)
SYS_setegid = Constant('SYS_setegid',182)
SYS_seteuid = Constant('SYS_seteuid',183)
SYS_stat = Constant('SYS_stat',188)
SYS_fstat = Constant('SYS_fstat',189)
SYS_lstat = Constant('SYS_lstat',190)
SYS_pathconf = Constant('SYS_pathconf',191)
SYS_fpathconf = Constant('SYS_fpathconf',192)
SYS_getrlimit = Constant('SYS_getrlimit',194)
SYS_setrlimit = Constant('SYS_setrlimit',195)
SYS_getdirentries = Constant('SYS_getdirentries',196)
SYS_freebsd6_mmap = Constant('SYS_freebsd6_mmap',197)
SYS___syscall = Constant('SYS___syscall',198)
SYS_freebsd6_lseek = Constant('SYS_freebsd6_lseek',199)
SYS_freebsd6_truncate = Constant('SYS_freebsd6_truncate',200)
SYS_freebsd6_ftruncate = Constant('SYS_freebsd6_ftruncate',201)
SYS___sysctl = Constant('SYS___sysctl',202)
SYS_mlock = Constant('SYS_mlock',203)
SYS_munlock = Constant('SYS_munlock',204)
SYS_undelete = Constant('SYS_undelete',205)
SYS_futimes = Constant('SYS_futimes',206)
SYS_getpgid = Constant('SYS_getpgid',207)
SYS_poll = Constant('SYS_poll',209)
SYS_freebsd7___semctl = Constant('SYS_freebsd7___semctl',220)
SYS_semget = Constant('SYS_semget',221)
SYS_semop = Constant('SYS_semop',222)
SYS_freebsd7_msgctl = Constant('SYS_freebsd7_msgctl',224)
SYS_msgget = Constant('SYS_msgget',225)
SYS_msgsnd = Constant('SYS_msgsnd',226)
SYS_msgrcv = Constant('SYS_msgrcv',227)
SYS_shmat = Constant('SYS_shmat',228)
SYS_freebsd7_shmctl = Constant('SYS_freebsd7_shmctl',229)
SYS_shmdt = Constant('SYS_shmdt',230)
SYS_shmget = Constant('SYS_shmget',231)
SYS_clock_gettime = Constant('SYS_clock_gettime',232)
SYS_clock_settime = Constant('SYS_clock_settime',233)
SYS_clock_getres = Constant('SYS_clock_getres',234)
SYS_ktimer_create = Constant('SYS_ktimer_create',235)
SYS_ktimer_delete = Constant('SYS_ktimer_delete',236)
SYS_ktimer_settime = Constant('SYS_ktimer_settime',237)
SYS_ktimer_gettime = Constant('SYS_ktimer_gettime',238)
SYS_ktimer_getoverrun = Constant('SYS_ktimer_getoverrun',239)
SYS_nanosleep = Constant('SYS_nanosleep',240)
SYS_ntp_gettime = Constant('SYS_ntp_gettime',248)
SYS_minherit = Constant('SYS_minherit',250)
SYS_rfork = Constant('SYS_rfork',251)
SYS_openbsd_poll = Constant('SYS_openbsd_poll',252)
SYS_issetugid = Constant('SYS_issetugid',253)
SYS_lchown = Constant('SYS_lchown',254)
SYS_aio_read = Constant('SYS_aio_read',255)
SYS_aio_write = Constant('SYS_aio_write',256)
SYS_lio_listio = Constant('SYS_lio_listio',257)
SYS_getdents = Constant('SYS_getdents',272)
SYS_lchmod = Constant('SYS_lchmod',274)
SYS_netbsd_lchown = Constant('SYS_netbsd_lchown',275)
SYS_lutimes = Constant('SYS_lutimes',276)
SYS_netbsd_msync = Constant('SYS_netbsd_msync',277)
SYS_nstat = Constant('SYS_nstat',278)
SYS_nfstat = Constant('SYS_nfstat',279)
SYS_nlstat = Constant('SYS_nlstat',280)
SYS_preadv = Constant('SYS_preadv',289)
SYS_pwritev = Constant('SYS_pwritev',290)
SYS_freebsd4_fhstatfs = Constant('SYS_freebsd4_fhstatfs',297)
SYS_fhopen = Constant('SYS_fhopen',298)
SYS_fhstat = Constant('SYS_fhstat',299)
SYS_modnext = Constant('SYS_modnext',300)
SYS_modstat = Constant('SYS_modstat',301)
SYS_modfnext = Constant('SYS_modfnext',302)
SYS_modfind = Constant('SYS_modfind',303)
SYS_kldload = Constant('SYS_kldload',304)
SYS_kldunload = Constant('SYS_kldunload',305)
SYS_kldfind = Constant('SYS_kldfind',306)
SYS_kldnext = Constant('SYS_kldnext',307)
SYS_kldstat = Constant('SYS_kldstat',308)
SYS_kldfirstmod = Constant('SYS_kldfirstmod',309)
SYS_getsid = Constant('SYS_getsid',310)
SYS_setresuid = Constant('SYS_setresuid',311)
SYS_setresgid = Constant('SYS_setresgid',312)
SYS_aio_return = Constant('SYS_aio_return',314)
SYS_aio_suspend = Constant('SYS_aio_suspend',315)
SYS_aio_cancel = Constant('SYS_aio_cancel',316)
SYS_aio_error = Constant('SYS_aio_error',317)
SYS_oaio_read = Constant('SYS_oaio_read',318)
SYS_oaio_write = Constant('SYS_oaio_write',319)
SYS_olio_listio = Constant('SYS_olio_listio',320)
SYS_yield = Constant('SYS_yield',321)
SYS_mlockall = Constant('SYS_mlockall',324)
SYS_munlockall = Constant('SYS_munlockall',325)
SYS___getcwd = Constant('SYS___getcwd',326)
SYS_sched_setparam = Constant('SYS_sched_setparam',327)
SYS_sched_getparam = Constant('SYS_sched_getparam',328)
SYS_sched_setscheduler = Constant('SYS_sched_setscheduler',329)
SYS_sched_getscheduler = Constant('SYS_sched_getscheduler',330)
SYS_sched_yield = Constant('SYS_sched_yield',331)
SYS_sched_get_priority_max = Constant('SYS_sched_get_priority_max',332)
SYS_sched_get_priority_min = Constant('SYS_sched_get_priority_min',333)
SYS_sched_rr_get_interval = Constant('SYS_sched_rr_get_interval',334)
SYS_utrace = Constant('SYS_utrace',335)
SYS_freebsd4_sendfile = Constant('SYS_freebsd4_sendfile',336)
SYS_kldsym = Constant('SYS_kldsym',337)
SYS_jail = Constant('SYS_jail',338)
SYS_nnpfs_syscall = Constant('SYS_nnpfs_syscall',339)
SYS_sigprocmask = Constant('SYS_sigprocmask',340)
SYS_sigsuspend = Constant('SYS_sigsuspend',341)
SYS_freebsd4_sigaction = Constant('SYS_freebsd4_sigaction',342)
SYS_sigpending = Constant('SYS_sigpending',343)
SYS_freebsd4_sigreturn = Constant('SYS_freebsd4_sigreturn',344)
SYS_sigtimedwait = Constant('SYS_sigtimedwait',345)
SYS_sigwaitinfo = Constant('SYS_sigwaitinfo',346)
SYS___acl_get_file = Constant('SYS___acl_get_file',347)
SYS___acl_set_file = Constant('SYS___acl_set_file',348)
SYS___acl_get_fd = Constant('SYS___acl_get_fd',349)
SYS___acl_set_fd = Constant('SYS___acl_set_fd',350)
SYS___acl_delete_file = Constant('SYS___acl_delete_file',351)
SYS___acl_delete_fd = Constant('SYS___acl_delete_fd',352)
SYS___acl_aclcheck_file = Constant('SYS___acl_aclcheck_file',353)
SYS___acl_aclcheck_fd = Constant('SYS___acl_aclcheck_fd',354)
SYS_extattrctl = Constant('SYS_extattrctl',355)
SYS_extattr_set_file = Constant('SYS_extattr_set_file',356)
SYS_extattr_get_file = Constant('SYS_extattr_get_file',357)
SYS_extattr_delete_file = Constant('SYS_extattr_delete_file',358)
SYS_aio_waitcomplete = Constant('SYS_aio_waitcomplete',359)
SYS_getresuid = Constant('SYS_getresuid',360)
SYS_getresgid = Constant('SYS_getresgid',361)
SYS_kqueue = Constant('SYS_kqueue',362)
SYS_kevent = Constant('SYS_kevent',363)
SYS_extattr_set_fd = Constant('SYS_extattr_set_fd',371)
SYS_extattr_get_fd = Constant('SYS_extattr_get_fd',372)
SYS_extattr_delete_fd = Constant('SYS_extattr_delete_fd',373)
SYS___setugid = Constant('SYS___setugid',374)
SYS_eaccess = Constant('SYS_eaccess',376)
SYS_afs3_syscall = Constant('SYS_afs3_syscall',377)
SYS_nmount = Constant('SYS_nmount',378)
SYS___mac_get_proc = Constant('SYS___mac_get_proc',384)
SYS___mac_set_proc = Constant('SYS___mac_set_proc',385)
SYS___mac_get_fd = Constant('SYS___mac_get_fd',386)
SYS___mac_get_file = Constant('SYS___mac_get_file',387)
SYS___mac_set_fd = Constant('SYS___mac_set_fd',388)
SYS___mac_set_file = Constant('SYS___mac_set_file',389)
SYS_kenv = Constant('SYS_kenv',390)
SYS_lchflags = Constant('SYS_lchflags',391)
SYS_uuidgen = Constant('SYS_uuidgen',392)
SYS_sendfile = Constant('SYS_sendfile',393)
SYS_mac_syscall = Constant('SYS_mac_syscall',394)
SYS_getfsstat = Constant('SYS_getfsstat',395)
SYS_statfs = Constant('SYS_statfs',396)
SYS_fstatfs = Constant('SYS_fstatfs',397)
SYS_fhstatfs = Constant('SYS_fhstatfs',398)
SYS_ksem_close = Constant('SYS_ksem_close',400)
SYS_ksem_post = Constant('SYS_ksem_post',401)
SYS_ksem_wait = Constant('SYS_ksem_wait',402)
SYS_ksem_trywait = Constant('SYS_ksem_trywait',403)
SYS_ksem_init = Constant('SYS_ksem_init',404)
SYS_ksem_open = Constant('SYS_ksem_open',405)
SYS_ksem_unlink = Constant('SYS_ksem_unlink',406)
SYS_ksem_getvalue = Constant('SYS_ksem_getvalue',407)
SYS_ksem_destroy = Constant('SYS_ksem_destroy',408)
SYS___mac_get_pid = Constant('SYS___mac_get_pid',409)
SYS___mac_get_link = Constant('SYS___mac_get_link',410)
SYS___mac_set_link = Constant('SYS___mac_set_link',411)
SYS_extattr_set_link = Constant('SYS_extattr_set_link',412)
SYS_extattr_get_link = Constant('SYS_extattr_get_link',413)
SYS_extattr_delete_link = Constant('SYS_extattr_delete_link',414)
SYS___mac_execve = Constant('SYS___mac_execve',415)
SYS_sigaction = Constant('SYS_sigaction',416)
SYS_sigreturn = Constant('SYS_sigreturn',417)
SYS_getcontext = Constant('SYS_getcontext',421)
SYS_setcontext = Constant('SYS_setcontext',422)
SYS_swapcontext = Constant('SYS_swapcontext',423)
SYS_swapoff = Constant('SYS_swapoff',424)
SYS___acl_get_link = Constant('SYS___acl_get_link',425)
SYS___acl_set_link = Constant('SYS___acl_set_link',426)
SYS___acl_delete_link = Constant('SYS___acl_delete_link',427)
SYS___acl_aclcheck_link = Constant('SYS___acl_aclcheck_link',428)
SYS_sigwait = Constant('SYS_sigwait',429)
SYS_thr_create = Constant('SYS_thr_create',430)
SYS_thr_exit = Constant('SYS_thr_exit',431)
SYS_thr_self = Constant('SYS_thr_self',432)
SYS_thr_kill = Constant('SYS_thr_kill',433)
SYS__umtx_lock = Constant('SYS__umtx_lock',434)
SYS__umtx_unlock = Constant('SYS__umtx_unlock',435)
SYS_jail_attach = Constant('SYS_jail_attach',436)
SYS_extattr_list_fd = Constant('SYS_extattr_list_fd',437)
SYS_extattr_list_file = Constant('SYS_extattr_list_file',438)
SYS_extattr_list_link = Constant('SYS_extattr_list_link',439)
SYS_ksem_timedwait = Constant('SYS_ksem_timedwait',441)
SYS_thr_suspend = Constant('SYS_thr_suspend',442)
SYS_thr_wake = Constant('SYS_thr_wake',443)
SYS_kldunloadf = Constant('SYS_kldunloadf',444)
SYS_audit = Constant('SYS_audit',445)
SYS_auditon = Constant('SYS_auditon',446)
SYS_getauid = Constant('SYS_getauid',447)
SYS_setauid = Constant('SYS_setauid',448)
SYS_getaudit = Constant('SYS_getaudit',449)
SYS_setaudit = Constant('SYS_setaudit',450)
SYS_getaudit_addr = Constant('SYS_getaudit_addr',451)
SYS_setaudit_addr = Constant('SYS_setaudit_addr',452)
SYS_auditctl = Constant('SYS_auditctl',453)
SYS__umtx_op = Constant('SYS__umtx_op',454)
SYS_thr_new = Constant('SYS_thr_new',455)
SYS_sigqueue = Constant('SYS_sigqueue',456)
SYS_kmq_open = Constant('SYS_kmq_open',457)
SYS_kmq_setattr = Constant('SYS_kmq_setattr',458)
SYS_kmq_timedreceive = Constant('SYS_kmq_timedreceive',459)
SYS_kmq_timedsend = Constant('SYS_kmq_timedsend',460)
SYS_kmq_notify = Constant('SYS_kmq_notify',461)
SYS_kmq_unlink = Constant('SYS_kmq_unlink',462)
SYS_abort2 = Constant('SYS_abort2',463)
SYS_thr_set_name = Constant('SYS_thr_set_name',464)
SYS_aio_fsync = Constant('SYS_aio_fsync',465)
SYS_rtprio_thread = Constant('SYS_rtprio_thread',466)
SYS_sctp_peeloff = Constant('SYS_sctp_peeloff',471)
SYS_sctp_generic_sendmsg = Constant('SYS_sctp_generic_sendmsg',472)
SYS_sctp_generic_sendmsg_iov = Constant('SYS_sctp_generic_sendmsg_iov',473)
SYS_sctp_generic_recvmsg = Constant('SYS_sctp_generic_recvmsg',474)
SYS_pread = Constant('SYS_pread',475)
SYS_pwrite = Constant('SYS_pwrite',476)
SYS_mmap = Constant('SYS_mmap',477)
SYS_lseek = Constant('SYS_lseek',478)
SYS_truncate = Constant('SYS_truncate',479)
SYS_ftruncate = Constant('SYS_ftruncate',480)
SYS_thr_kill2 = Constant('SYS_thr_kill2',481)
SYS_shm_open = Constant('SYS_shm_open',482)
SYS_shm_unlink = Constant('SYS_shm_unlink',483)
SYS_cpuset = Constant('SYS_cpuset',484)
SYS_cpuset_setid = Constant('SYS_cpuset_setid',485)
SYS_cpuset_getid = Constant('SYS_cpuset_getid',486)
SYS_cpuset_getaffinity = Constant('SYS_cpuset_getaffinity',487)
SYS_cpuset_setaffinity = Constant('SYS_cpuset_setaffinity',488)
SYS_faccessat = Constant('SYS_faccessat',489)
SYS_fchmodat = Constant('SYS_fchmodat',490)
SYS_fchownat = Constant('SYS_fchownat',491)
SYS_fexecve = Constant('SYS_fexecve',492)
SYS_fstatat = Constant('SYS_fstatat',493)
SYS_futimesat = Constant('SYS_futimesat',494)
SYS_linkat = Constant('SYS_linkat',495)
SYS_mkdirat = Constant('SYS_mkdirat',496)
SYS_mkfifoat = Constant('SYS_mkfifoat',497)
SYS_mknodat = Constant('SYS_mknodat',498)
SYS_openat = Constant('SYS_openat',499)
SYS_readlinkat = Constant('SYS_readlinkat',500)
SYS_renameat = Constant('SYS_renameat',501)
SYS_symlinkat = Constant('SYS_symlinkat',502)
SYS_unlinkat = Constant('SYS_unlinkat',503)
SYS_posix_openpt = Constant('SYS_posix_openpt',504)
SYS_gssd_syscall = Constant('SYS_gssd_syscall',505)
SYS_jail_get = Constant('SYS_jail_get',506)
SYS_jail_set = Constant('SYS_jail_set',507)
SYS_jail_remove = Constant('SYS_jail_remove',508)
SYS_closefrom = Constant('SYS_closefrom',509)
SYS___semctl = Constant('SYS___semctl',510)
SYS_msgctl = Constant('SYS_msgctl',511)
SYS_shmctl = Constant('SYS_shmctl',512)
SYS_lpathconf = Constant('SYS_lpathconf',513)
SYS_cap_new = Constant('SYS_cap_new',514)
SYS_cap_getrights = Constant('SYS_cap_getrights',515)
SYS_cap_enter = Constant('SYS_cap_enter',516)
SYS_cap_getmode = Constant('SYS_cap_getmode',517)
SYS_pdfork = Constant('SYS_pdfork',518)
SYS_pdkill = Constant('SYS_pdkill',519)
SYS_pdgetpid = Constant('SYS_pdgetpid',520)
SYS_pselect = Constant('SYS_pselect',522)
SYS_getloginclass = Constant('SYS_getloginclass',523)
SYS_setloginclass = Constant('SYS_setloginclass',524)
SYS_rctl_get_racct = Constant('SYS_rctl_get_racct',525)
SYS_rctl_get_rules = Constant('SYS_rctl_get_rules',526)
SYS_rctl_get_limits = Constant('SYS_rctl_get_limits',527)
SYS_rctl_add_rule = Constant('SYS_rctl_add_rule',528)
SYS_rctl_remove_rule = Constant('SYS_rctl_remove_rule',529)
SYS_posix_fallocate = Constant('SYS_posix_fallocate',530)
SYS_posix_fadvise = Constant('SYS_posix_fadvise',531)
SYS_wait6 = Constant('SYS_wait6',532)
SYS_MAXSYSCALL = Constant('SYS_MAXSYSCALL',533)
_POSIX_ADVISORY_INFO = Constant('_POSIX_ADVISORY_INFO',200112)
_POSIX_ASYNCHRONOUS_IO = Constant('_POSIX_ASYNCHRONOUS_IO',0)
_POSIX_CHOWN_RESTRICTED = Constant('_POSIX_CHOWN_RESTRICTED',1)
_POSIX_CLOCK_SELECTION = Constant('_POSIX_CLOCK_SELECTION',(-1))
_POSIX_CPUTIME = Constant('_POSIX_CPUTIME',(-1))
_POSIX_FSYNC = Constant('_POSIX_FSYNC',200112)
_POSIX_IPV6 = Constant('_POSIX_IPV6',0)
_POSIX_JOB_CONTROL = Constant('_POSIX_JOB_CONTROL',1)
_POSIX_MAPPED_FILES = Constant('_POSIX_MAPPED_FILES',200112)
_POSIX_MEMLOCK = Constant('_POSIX_MEMLOCK',(-1))
_POSIX_MEMLOCK_RANGE = Constant('_POSIX_MEMLOCK_RANGE',200112)
_POSIX_MEMORY_PROTECTION = Constant('_POSIX_MEMORY_PROTECTION',200112)
_POSIX_MESSAGE_PASSING = Constant('_POSIX_MESSAGE_PASSING',200112)
_POSIX_MONOTONIC_CLOCK = Constant('_POSIX_MONOTONIC_CLOCK',200112)
_POSIX_NO_TRUNC = Constant('_POSIX_NO_TRUNC',1)
_POSIX_PRIORITIZED_IO = Constant('_POSIX_PRIORITIZED_IO',(-1))
_POSIX_PRIORITY_SCHEDULING = Constant('_POSIX_PRIORITY_SCHEDULING',200112)
_POSIX_RAW_SOCKETS = Constant('_POSIX_RAW_SOCKETS',200112)
_POSIX_REALTIME_SIGNALS = Constant('_POSIX_REALTIME_SIGNALS',200112)
_POSIX_SEMAPHORES = Constant('_POSIX_SEMAPHORES',200112)
_POSIX_SHARED_MEMORY_OBJECTS = Constant('_POSIX_SHARED_MEMORY_OBJECTS',200112)
_POSIX_SPORADIC_SERVER = Constant('_POSIX_SPORADIC_SERVER',(-1))
_POSIX_SYNCHRONIZED_IO = Constant('_POSIX_SYNCHRONIZED_IO',(-1))
_POSIX_TIMEOUTS = Constant('_POSIX_TIMEOUTS',200112)
_POSIX_TIMERS = Constant('_POSIX_TIMERS',200112)
_POSIX_TYPED_MEMORY_OBJECTS = Constant('_POSIX_TYPED_MEMORY_OBJECTS',(-1))
_POSIX_VDISABLE = Constant('_POSIX_VDISABLE',0xff)
_XOPEN_SHM = Constant('_XOPEN_SHM',1)
_XOPEN_STREAMS = Constant('_XOPEN_STREAMS',(-1))
_POSIX_VERSION = Constant('_POSIX_VERSION',200112)
F_OK = Constant('F_OK',0)
X_OK = Constant('X_OK',0x01)
W_OK = Constant('W_OK',0x02)
R_OK = Constant('R_OK',0x04)
SEEK_SET = Constant('SEEK_SET',0)
SEEK_CUR = Constant('SEEK_CUR',1)
SEEK_END = Constant('SEEK_END',2)
SEEK_DATA = Constant('SEEK_DATA',3)
SEEK_HOLE = Constant('SEEK_HOLE',4)
L_SET = Constant('L_SET',0)
L_INCR = Constant('L_INCR',1)
L_XTND = Constant('L_XTND',2)
_PC_LINK_MAX = Constant('_PC_LINK_MAX',1)
_PC_MAX_CANON = Constant('_PC_MAX_CANON',2)
_PC_MAX_INPUT = Constant('_PC_MAX_INPUT',3)
_PC_NAME_MAX = Constant('_PC_NAME_MAX',4)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',5)
_PC_PIPE_BUF = Constant('_PC_PIPE_BUF',6)
_PC_CHOWN_RESTRICTED = Constant('_PC_CHOWN_RESTRICTED',7)
_PC_NO_TRUNC = Constant('_PC_NO_TRUNC',8)
_PC_VDISABLE = Constant('_PC_VDISABLE',9)
_PC_ASYNC_IO = Constant('_PC_ASYNC_IO',53)
_PC_PRIO_IO = Constant('_PC_PRIO_IO',54)
_PC_SYNC_IO = Constant('_PC_SYNC_IO',55)
_PC_ALLOC_SIZE_MIN = Constant('_PC_ALLOC_SIZE_MIN',10)
_PC_FILESIZEBITS = Constant('_PC_FILESIZEBITS',12)
_PC_REC_INCR_XFER_SIZE = Constant('_PC_REC_INCR_XFER_SIZE',14)
_PC_REC_MAX_XFER_SIZE = Constant('_PC_REC_MAX_XFER_SIZE',15)
_PC_REC_MIN_XFER_SIZE = Constant('_PC_REC_MIN_XFER_SIZE',16)
_PC_REC_XFER_ALIGN = Constant('_PC_REC_XFER_ALIGN',17)
_PC_SYMLINK_MAX = Constant('_PC_SYMLINK_MAX',18)
_PC_ACL_EXTENDED = Constant('_PC_ACL_EXTENDED',59)
_PC_ACL_PATH_MAX = Constant('_PC_ACL_PATH_MAX',60)
_PC_CAP_PRESENT = Constant('_PC_CAP_PRESENT',61)
_PC_INF_PRESENT = Constant('_PC_INF_PRESENT',62)
_PC_MAC_PRESENT = Constant('_PC_MAC_PRESENT',63)
_PC_ACL_NFS4 = Constant('_PC_ACL_NFS4',64)
_PC_MIN_HOLE_SIZE = Constant('_PC_MIN_HOLE_SIZE',21)
RFNAMEG = Constant('RFNAMEG',(1<<0))
RFENVG = Constant('RFENVG',(1<<1))
RFFDG = Constant('RFFDG',(1<<2))
RFNOTEG = Constant('RFNOTEG',(1<<3))
RFPROC = Constant('RFPROC',(1<<4))
RFMEM = Constant('RFMEM',(1<<5))
RFNOWAIT = Constant('RFNOWAIT',(1<<6))
RFCNAMEG = Constant('RFCNAMEG',(1<<10))
RFCENVG = Constant('RFCENVG',(1<<11))
RFCFDG = Constant('RFCFDG',(1<<12))
RFTHREAD = Constant('RFTHREAD',(1<<13))
RFSIGSHARE = Constant('RFSIGSHARE',(1<<14))
RFLINUXTHPN = Constant('RFLINUXTHPN',(1<<16))
RFSTOPPED = Constant('RFSTOPPED',(1<<17))
RFHIGHPID = Constant('RFHIGHPID',(1<<18))
RFTSIGZMB = Constant('RFTSIGZMB',(1<<19))
RFTSIGSHIFT = Constant('RFTSIGSHIFT',20)
RFTSIGMASK = Constant('RFTSIGMASK',0xFF)
RFPROCDESC = Constant('RFPROCDESC',(1<<28))
RFPPWAIT = Constant('RFPPWAIT',(1<<31))
RFFLAGS = Constant('RFFLAGS',((1<<2) | (1<<4) | (1<<5) | (1<<6) | (1<<12) |      (1<<13) | (1<<14) | (1<<16) | (1<<17) | (1<<18) | (1<<19) |      (1<<28) | (1<<31)))
RFKERNELONLY = Constant('RFKERNELONLY',((1<<17) | (1<<18) | (1<<31) | (1<<28)))
