#define __NR_Linux 1024
#define __NR_ni_syscall (1024 + 0)
#define __NR_exit (1024 + 1)
#define __NR_read (1024 + 2)
#define __NR_write (1024 + 3)
#define __NR_open (1024 + 4)
#define __NR_close (1024 + 5)
#define __NR_creat (1024 + 6)
#define __NR_link (1024 + 7)
#define __NR_unlink (1024 + 8)
#define __NR_execve (1024 + 9)
#define __NR_chdir (1024 + 10)
#define __NR_fchdir (1024 + 11)
#define __NR_utimes (1024 + 12)
#define __NR_mknod (1024 + 13)
#define __NR_chmod (1024 + 14)
#define __NR_chown (1024 + 15)
#define __NR_lseek (1024 + 16)
#define __NR_getpid (1024 + 17)
#define __NR_getppid (1024 + 18)
#define __NR_mount (1024 + 19)
#define __NR_umount2 (1024 + 20)
#define __NR_setuid (1024 + 21)
#define __NR_getuid (1024 + 22)
#define __NR_geteuid (1024 + 23)
#define __NR_ptrace (1024 + 24)
#define __NR_access (1024 + 25)
#define __NR_sync (1024 + 26)
#define __NR_fsync (1024 + 27)
#define __NR_fdatasync (1024 + 28)
#define __NR_kill (1024 + 29)
#define __NR_rename (1024 + 30)
#define __NR_mkdir (1024 + 31)
#define __NR_rmdir (1024 + 32)
#define __NR_dup (1024 + 33)
#define __NR_pipe (1024 + 34)
#define __NR_times (1024 + 35)
#define __NR_brk (1024 + 36)
#define __NR_setgid (1024 + 37)
#define __NR_getgid (1024 + 38)
#define __NR_getegid (1024 + 39)
#define __NR_acct (1024 + 40)
#define __NR_ioctl (1024 + 41)
#define __NR_fcntl (1024 + 42)
#define __NR_umask (1024 + 43)
#define __NR_chroot (1024 + 44)
#define __NR_ustat (1024 + 45)
#define __NR_dup2 (1024 + 46)
#define __NR_setreuid (1024 + 47)
#define __NR_setregid (1024 + 48)
#define __NR_getresuid (1024 + 49)
#define __NR_setresuid (1024 + 50)
#define __NR_getresgid (1024 + 51)
#define __NR_setresgid (1024 + 52)
#define __NR_getgroups (1024 + 53)
#define __NR_setgroups (1024 + 54)
#define __NR_getpgid (1024 + 55)
#define __NR_setpgid (1024 + 56)
#define __NR_setsid (1024 + 57)
#define __NR_getsid (1024 + 58)
#define __NR_sethostname (1024 + 59)
#define __NR_setrlimit (1024 + 60)
#define __NR_getrlimit (1024 + 61)
#define __NR_getrusage (1024 + 62)
#define __NR_gettimeofday (1024 + 63)
#define __NR_settimeofday (1024 + 64)
#define __NR_select (1024 + 65)
#define __NR_poll (1024 + 66)
#define __NR_symlink (1024 + 67)
#define __NR_readlink (1024 + 68)
#define __NR_uselib (1024 + 69)
#define __NR_swapon (1024 + 70)
#define __NR_swapoff (1024 + 71)
#define __NR_reboot (1024 + 72)
#define __NR_truncate (1024 + 73)
#define __NR_ftruncate (1024 + 74)
#define __NR_fchmod (1024 + 75)
#define __NR_fchown (1024 + 76)
#define __NR_getpriority (1024 + 77)
#define __NR_setpriority (1024 + 78)
#define __NR_statfs (1024 + 79)
#define __NR_fstatfs (1024 + 80)
#define __NR_gettid (1024 + 81)
#define __NR_semget (1024 + 82)
#define __NR_semop (1024 + 83)
#define __NR_semctl (1024 + 84)
#define __NR_msgget (1024 + 85)
#define __NR_msgsnd (1024 + 86)
#define __NR_msgrcv (1024 + 87)
#define __NR_msgctl (1024 + 88)
#define __NR_shmget (1024 + 89)
#define __NR_shmat (1024 + 90)
#define __NR_shmdt (1024 + 91)
#define __NR_shmctl (1024 + 92)
#define __NR_syslog (1024 + 93)
#define __NR_setitimer (1024 + 94)
#define __NR_getitimer (1024 + 95)
#define __NR_vhangup (1024 + 99)
#define __NR_lchown (1024 + 100)
#define __NR_remap_file_pages (1024 + 101)
#define __NR_wait4 (1024 + 102)
#define __NR_sysinfo (1024 + 103)
#define __NR_clone (1024 + 104)
#define __NR_setdomainname (1024 + 105)
#define __NR_uname (1024 + 106)
#define __NR_adjtimex (1024 + 107)
#define __NR_init_module (1024 + 109)
#define __NR_delete_module (1024 + 110)
#define __NR_quotactl (1024 + 113)
#define __NR_bdflush (1024 + 114)
#define __NR_sysfs (1024 + 115)
#define __NR_personality (1024 + 116)
#define __NR_afs_syscall (1024 + 117)
#define __NR_setfsuid (1024 + 118)
#define __NR_setfsgid (1024 + 119)
#define __NR_getdents (1024 + 120)
#define __NR_flock (1024 + 121)
#define __NR_readv (1024 + 122)
#define __NR_writev (1024 + 123)
#define __NR_pread64 (1024 + 124)
#define __NR_pwrite64 (1024 + 125)
#define __NR__sysctl (1024 + 126)
#define __NR_mmap (1024 + 127)
#define __NR_munmap (1024 + 128)
#define __NR_mlock (1024 + 129)
#define __NR_mlockall (1024 + 130)
#define __NR_mprotect (1024 + 131)
#define __NR_mremap (1024 + 132)
#define __NR_msync (1024 + 133)
#define __NR_munlock (1024 + 134)
#define __NR_munlockall (1024 + 135)
#define __NR_sched_getparam (1024 + 136)
#define __NR_sched_setparam (1024 + 137)
#define __NR_sched_getscheduler (1024 + 138)
#define __NR_sched_setscheduler (1024 + 139)
#define __NR_sched_yield (1024 + 140)
#define __NR_sched_get_priority_max (1024 + 141)
#define __NR_sched_get_priority_min (1024 + 142)
#define __NR_sched_rr_get_interval (1024 + 143)
#define __NR_nanosleep (1024 + 144)
#define __NR_nfsservctl (1024 + 145)
#define __NR_prctl (1024 + 146)
#define __NR_old_getpagesize (1024 + 147)
#define __NR_mmap2 (1024 + 148)
#define __NR_pciconfig_read (1024 + 149)
#define __NR_pciconfig_write (1024 + 150)
#define __NR_perfmonctl (1024 + 151)
#define __NR_sigaltstack (1024 + 152)
#define __NR_rt_sigaction (1024 + 153)
#define __NR_rt_sigpending (1024 + 154)
#define __NR_rt_sigprocmask (1024 + 155)
#define __NR_rt_sigqueueinfo (1024 + 156)
#define __NR_rt_sigreturn (1024 + 157)
#define __NR_rt_sigsuspend (1024 + 158)
#define __NR_rt_sigtimedwait (1024 + 159)
#define __NR_getcwd (1024 + 160)
#define __NR_capget (1024 + 161)
#define __NR_capset (1024 + 162)
#define __NR_sendfile (1024 + 163)
#define __NR_getpmsg (1024 + 164)
#define __NR_putpmsg (1024 + 165)
#define __NR_socket (1024 + 166)
#define __NR_bind (1024 + 167)
#define __NR_connect (1024 + 168)
#define __NR_listen (1024 + 169)
#define __NR_accept (1024 + 170)
#define __NR_getsockname (1024 + 171)
#define __NR_getpeername (1024 + 172)
#define __NR_socketpair (1024 + 173)
#define __NR_send (1024 + 174)
#define __NR_sendto (1024 + 175)
#define __NR_recv (1024 + 176)
#define __NR_recvfrom (1024 + 177)
#define __NR_shutdown (1024 + 178)
#define __NR_setsockopt (1024 + 179)
#define __NR_getsockopt (1024 + 180)
#define __NR_sendmsg (1024 + 181)
#define __NR_recvmsg (1024 + 182)
#define __NR_pivot_root (1024 + 183)
#define __NR_mincore (1024 + 184)
#define __NR_madvise (1024 + 185)
#define __NR_stat (1024 + 186)
#define __NR_lstat (1024 + 187)
#define __NR_fstat (1024 + 188)
#define __NR_clone2 (1024 + 189)
#define __NR_getdents64 (1024 + 190)
#define __NR_getunwind (1024 + 191)
#define __NR_readahead (1024 + 192)
#define __NR_setxattr (1024 + 193)
#define __NR_lsetxattr (1024 + 194)
#define __NR_fsetxattr (1024 + 195)
#define __NR_getxattr (1024 + 196)
#define __NR_lgetxattr (1024 + 197)
#define __NR_fgetxattr (1024 + 198)
#define __NR_listxattr (1024 + 199)
#define __NR_llistxattr (1024 + 200)
#define __NR_flistxattr (1024 + 201)
#define __NR_removexattr (1024 + 202)
#define __NR_lremovexattr (1024 + 203)
#define __NR_fremovexattr (1024 + 204)
#define __NR_tkill (1024 + 205)
#define __NR_futex (1024 + 206)
#define __NR_sched_setaffinity (1024 + 207)
#define __NR_sched_getaffinity (1024 + 208)
#define __NR_set_tid_address (1024 + 209)
#define __NR_fadvise64 (1024 + 210)
#define __NR_tgkill (1024 + 211)
#define __NR_exit_group (1024 + 212)
#define __NR_lookup_dcookie (1024 + 213)
#define __NR_io_setup (1024 + 214)
#define __NR_io_destroy (1024 + 215)
#define __NR_io_getevents (1024 + 216)
#define __NR_io_submit (1024 + 217)
#define __NR_io_cancel (1024 + 218)
#define __NR_epoll_create (1024 + 219)
#define __NR_epoll_ctl (1024 + 220)
#define __NR_epoll_wait (1024 + 221)
#define __NR_restart_syscall (1024 + 222)
#define __NR_semtimedop (1024 + 223)
#define __NR_timer_create (1024 + 224)
#define __NR_timer_settime (1024 + 225)
#define __NR_timer_gettime (1024 + 226)
#define __NR_timer_getoverrun (1024 + 227)
#define __NR_timer_delete (1024 + 228)
#define __NR_clock_settime (1024 + 229)
#define __NR_clock_gettime (1024 + 230)
#define __NR_clock_getres (1024 + 231)
#define __NR_clock_nanosleep (1024 + 232)
#define __NR_fstatfs64 (1024 + 233)
#define __NR_statfs64 (1024 + 234)
#define __NR_mbind (1024 + 235)
#define __NR_get_mempolicy (1024 + 236)
#define __NR_set_mempolicy (1024 + 237)
#define __NR_mq_open (1024 + 238)
#define __NR_mq_unlink (1024 + 239)
#define __NR_mq_timedsend (1024 + 240)
#define __NR_mq_timedreceive (1024 + 241)
#define __NR_mq_notify (1024 + 242)
#define __NR_mq_getsetattr (1024 + 243)
#define __NR_kexec_load (1024 + 244)
#define __NR_vserver (1024 + 245)
#define __NR_waitid (1024 + 246)
#define __NR_add_key (1024 + 247)
#define __NR_request_key (1024 + 248)
#define __NR_keyctl (1024 + 249)
#define __NR_ioprio_set (1024 + 250)
#define __NR_ioprio_get (1024 + 251)
#define __NR_move_pages (1024 + 252)
#define __NR_inotify_init (1024 + 253)
#define __NR_inotify_add_watch (1024 + 254)
#define __NR_inotify_rm_watch (1024 + 255)
#define __NR_migrate_pages (1024 + 256)
#define __NR_openat (1024 + 257)
#define __NR_mkdirat (1024 + 258)
#define __NR_mknodat (1024 + 259)
#define __NR_fchownat (1024 + 260)
#define __NR_futimesat (1024 + 261)
#define __NR_newfstatat (1024 + 262)
#define __NR_unlinkat (1024 + 263)
#define __NR_renameat (1024 + 264)
#define __NR_linkat (1024 + 265)
#define __NR_symlinkat (1024 + 266)
#define __NR_readlinkat (1024 + 267)
#define __NR_fchmodat (1024 + 268)
#define __NR_faccessat (1024 + 269)
#define __NR_pselect6 (1024 + 270)
#define __NR_ppoll (1024 + 271)
#define __NR_unshare (1024 + 272)
#define __NR_splice (1024 + 273)
#define __NR_set_robust_list (1024 + 274)
#define __NR_get_robust_list (1024 + 275)
#define __NR_sync_file_range (1024 + 276)
#define __NR_tee (1024 + 277)
#define __NR_vmsplice (1024 + 278)
#define __NR_fallocate (1024 + 279)
#define __NR_getcpu (1024 + 280)
#define __NR_epoll_pwait (1024 + 281)
#define __NR_utimensat (1024 + 282)
#define __NR_signalfd (1024 + 283)
#define __NR_timerfd (1024 + 284)
#define __NR_eventfd (1024 + 285)
#define __NR_timerfd_create (1024 + 286)
#define __NR_timerfd_settime (1024 + 287)
#define __NR_timerfd_gettime (1024 + 288)
#define __NR_signalfd4 (1024 + 289)
#define __NR_eventfd2 (1024 + 290)
#define __NR_epoll_create1 (1024 + 291)
#define __NR_dup3 (1024 + 292)
#define __NR_pipe2 (1024 + 293)
#define __NR_inotify_init1 (1024 + 294)
#define __NR_preadv (1024 + 295)
#define __NR_pwritev (1024 + 296)
#define __NR_rt_tgsigqueueinfo (1024 + 297)
#define __NR_recvmmsg (1024 + 298)
#define __NR_fanotify_init (1024 + 299)
#define __NR_fanotify_mark (1024 + 300)
#define __NR_prlimit64 (1024 + 301)
#define __NR_name_to_handle_at (1024 + 302)
#define __NR_open_by_handle_at (1024 + 303)
#define __NR_clock_adjtime (1024 + 304)
#define __NR_syncfs (1024 + 305)
#define __NR_setns (1024 + 306)
#define __NR_sendmmsg (1024 + 307)
#define __NR_process_vm_readv (1024 + 308)
#define __NR_process_vm_writev (1024 + 309)
#define __NR_accept4 (1024 + 310)
#define __NR_finit_module (1024 + 311)
#define __NR_sched_setattr (1024 + 312)
#define __NR_sched_getattr (1024 + 313)
#define __NR_renameat2 (1024 + 314)
#define __NR_getrandom (1024 + 315)
#define __NR_memfd_create (1024 + 316)
#define __NR_bpf (1024 + 317)
#define __NR_execveat (1024 + 318)
#define __NR_userfaultfd (1024 + 319)
#define __NR_membarrier (1024 + 320)
#define __NR_kcmp (1024 + 321)
#define __NR_mlock2 (1024 + 322)
#define __NR_copy_file_range (1024 + 323)
#define __NR_preadv2 (1024 + 324)
#define __NR_pwritev2 (1024 + 325)
#define __NR_statx (1024 + 326)
#define __NR_io_pgetevents (1024 + 327)
#define __NR_perf_event_open (1024 + 328)
#define __NR_seccomp (1024 + 329)
#define __NR_pkey_mprotect (1024 + 330)
#define __NR_pkey_alloc (1024 + 331)
#define __NR_pkey_free (1024 + 332)
#define __NR_rseq (1024 + 333)
#define __NR_pidfd_send_signal (1024 + 424)
#define __NR_io_uring_setup (1024 + 425)
#define __NR_io_uring_enter (1024 + 426)
#define __NR_io_uring_register (1024 + 427)
#define __NR_open_tree (1024 + 428)
#define __NR_move_mount (1024 + 429)
#define __NR_fsopen (1024 + 430)
#define __NR_fsconfig (1024 + 431)
#define __NR_fsmount (1024 + 432)
#define __NR_fspick (1024 + 433)
#define __NR_pidfd_open (1024 + 434)
#define __NR_openat2 (1024 + 437)
#define __NR_pidfd_getfd (1024 + 438)
#define MAP_32BIT 0x40
#define INADDR_ANY 0
#define INADDR_BROADCAST 0xffffffff
#define INADDR_NONE 0xffffffff
#define INADDR_LOOPBACK 0x7f000001
#define EPERM 1
#define ENOENT 2
#define ESRCH 3
#define EINTR 4
#define EIO 5
#define ENXIO 6
#define E2BIG 7
#define ENOEXEC 8
#define EBADF 9
#define ECHILD 10
#define EAGAIN 11
#define ENOMEM 12
#define EACCES 13
#define EFAULT 14
#define ENOTBLK 15
#define EBUSY 16
#define EEXIST 17
#define EXDEV 18
#define ENODEV 19
#define ENOTDIR 20
#define EISDIR 21
#define EINVAL 22
#define ENFILE 23
#define EMFILE 24
#define ENOTTY 25
#define ETXTBSY 26
#define EFBIG 27
#define ENOSPC 28
#define ESPIPE 29
#define EROFS 30
#define EMLINK 31
#define EPIPE 32
#define EDOM 33
#define ERANGE 34
#define EDEADLK 35
#define ENAMETOOLONG 36
#define ENOLCK 37
#define ENOSYS 38
#define ENOTEMPTY 39
#define ELOOP 40
#define EWOULDBLOCK 11
#define ENOMSG 42
#define EIDRM 43
#define ECHRNG 44
#define EL2NSYNC 45
#define EL3HLT 46
#define EL3RST 47
#define ELNRNG 48
#define EUNATCH 49
#define ENOCSI 50
#define EL2HLT 51
#define EBADE 52
#define EBADR 53
#define EXFULL 54
#define ENOANO 55
#define EBADRQC 56
#define EBADSLT 57
#define EDEADLOCK 35
#define EBFONT 59
#define ENOSTR 60
#define ENODATA 61
#define ETIME 62
#define ENOSR 63
#define ENONET 64
#define ENOPKG 65
#define EREMOTE 66
#define ENOLINK 67
#define EADV 68
#define ESRMNT 69
#define ECOMM 70
#define EPROTO 71
#define EMULTIHOP 72
#define EDOTDOT 73
#define EBADMSG 74
#define EOVERFLOW 75
#define ENOTUNIQ 76
#define EBADFD 77
#define EREMCHG 78
#define ELIBACC 79
#define ELIBBAD 80
#define ELIBSCN 81
#define ELIBMAX 82
#define ELIBEXEC 83
#define EILSEQ 84
#define ERESTART 85
#define ESTRPIPE 86
#define EUSERS 87
#define ENOTSOCK 88
#define EDESTADDRREQ 89
#define EMSGSIZE 90
#define EPROTOTYPE 91
#define ENOPROTOOPT 92
#define EPROTONOSUPPORT 93
#define ESOCKTNOSUPPORT 94
#define EOPNOTSUPP 95
#define ENOTSUP 95
#define EPFNOSUPPORT 96
#define EAFNOSUPPORT 97
#define EADDRINUSE 98
#define EADDRNOTAVAIL 99
#define ENETDOWN 100
#define ENETUNREACH 101
#define ENETRESET 102
#define ECONNABORTED 103
#define ECONNRESET 104
#define ENOBUFS 105
#define EISCONN 106
#define ENOTCONN 107
#define ESHUTDOWN 108
#define ETOOMANYREFS 109
#define ETIMEDOUT 110
#define ECONNREFUSED 111
#define EHOSTDOWN 112
#define EHOSTUNREACH 113
#define EALREADY 114
#define EINPROGRESS 115
#define ESTALE 116
#define EUCLEAN 117
#define ENOTNAM 118
#define ENAVAIL 119
#define EISNAM 120
#define EREMOTEIO 121
#define EDQUOT 122
#define ENOMEDIUM 123
#define EMEDIUMTYPE 124
#define ECANCELED 125
#define ENOKEY 126
#define EKEYEXPIRED 127
#define EKEYREVOKED 128
#define EKEYREJECTED 129
#define EOWNERDEAD 130
#define ENOTRECOVERABLE 131
#define ERFKILL 132
#define EHWPOISON 133
#define __SYS_NERR ((133) + 1)
#define __LITTLE_ENDIAN 1234
#define __BIG_ENDIAN 4321
#define __BYTE_ORDER 1234
#define __FLOAT_WORD_ORDER 1234
#define LITTLE_ENDIAN 1234
#define BIG_ENDIAN 4321
#define BYTE_ORDER 1234
#define __WORDSIZE 64
#define INT8_MAX (127)
#define INT16_MAX (32767)
#define INT32_MAX (2147483647)
#define INT64_MAX (9223372036854775807)
#define INT8_MIN (-1 - (127))
#define INT16_MIN (-1 - (32767))
#define INT32_MIN (-1 - (2147483647))
#define INT64_MIN (-1 - (9223372036854775807))
#define INT_LEAST8_MAX (127)
#define INT_LEAST8_MIN (-1 - (127))
#define INT_LEAST16_MAX (32767)
#define INT_LEAST16_MIN (-1 - (32767))
#define INT_LEAST32_MAX (2147483647)
#define INT_LEAST32_MIN (-1 - (2147483647))
#define INT_LEAST64_MAX (9223372036854775807)
#define INT_LEAST64_MIN (-1 - (9223372036854775807))
#define UINT8_MAX 0xff
#define UINT16_MAX 0xffff
#define UINT32_MAX 0xffffffff
#define UINT64_MAX 0xffffffffffffffff
#define UINT_LEAST8_MAX 0xff
#define UINT_LEAST16_MAX 0xffff
#define UINT_LEAST32_MAX 0xffffffff
#define UINT_LEAST64_MAX 0xffffffffffffffff
#define INTPTR_MIN (-1 - (9223372036854775807))
#define INTPTR_MAX (9223372036854775807)
#define UINTPTR_MAX 0xffffffffffffffff
#define SIZE_MAX 0xffffffffffffffff
#define PTRDIFF_MIN (-1 - (9223372036854775807))
#define PTRDIFF_MAX (9223372036854775807)
#define INTMAX_MIN (-1 - (9223372036854775807))
#define INTMAX_MAX (9223372036854775807)
#define UINTMAX_MAX 0xffffffffffffffff
#define INT_FAST8_MIN (-1 - (127))
#define INT_FAST8_MAX (127)
#define INT_FAST64_MIN (-1 - (9223372036854775807))
#define INT_FAST64_MAX (9223372036854775807)
#define UINT_FAST8_MAX 0xff
#define UINT_FAST64_MAX 0xffffffffffffffff
#define INT_FAST16_MIN (-1 - (9223372036854775807))
#define INT_FAST16_MAX (9223372036854775807)
#define UINT_FAST16_MAX 0xffffffffffffffff
#define INT_FAST32_MIN (-1 - (9223372036854775807))
#define INT_FAST32_MAX (9223372036854775807)
#define UINT_FAST32_MAX 0xffffffffffffffff
#define WINT_MIN 0
#define __FSUID_H 1
#define NSIG 32
#define _NSIG 65
#define SIGHUP 1
#define SIGINT 2
#define SIGQUIT 3
#define SIGILL 4
#define SIGTRAP 5
#define SIGABRT 6
#define SIGIOT 6
#define SIGFPE 8
#define SIGKILL 9
#define SIGSEGV 11
#define SIGPIPE 13
#define SIGALRM 14
#define SIGTERM 15
#define SIGUNUSED 31
#define SIGBUS 7
#define SIGUSR1 10
#define SIGUSR2 12
#define SIGSTKFLT 16
#define SIGCHLD 17
#define SIGCONT 18
#define SIGSTOP 19
#define SIGTSTP 20
#define SIGTTIN 21
#define SIGTTOU 22
#define SIGURG 23
#define SIGXCPU 24
#define SIGXFSZ 25
#define SIGVTALRM 26
#define SIGPROF 27
#define SIGWINCH 28
#define SIGIO 29
#define SIGPWR 30
#define SIGSYS 31
#define SIGCLD 17
#define SIGPOLL 29
#define SIGLOST 30
#define SIGRTMIN 32
#define SIGRTMAX (65-1)
#define SA_NOCLDSTOP 0x00000001
#define SA_NOCLDWAIT 0x00000002
#define SA_SIGINFO 0x00000004
#define SA_RESTORER 0x04000000
#define SA_ONSTACK 0x08000000
#define SA_RESTART 0x10000000
#define SA_INTERRUPT 0x20000000
#define SA_NODEFER 0x40000000
#define SA_RESETHAND 0x80000000
#define SA_NOMASK 0x40000000
#define SA_ONESHOT 0x80000000
#define SS_ONSTACK 1
#define SS_DISABLE 2
#define MINSIGSTKSZ 2048
#define SIGSTKSZ 8192
#define SIG_BLOCK 0
#define SIG_UNBLOCK 1
#define SIG_SETMASK 2
#define SI_MAX_SIZE 128
#define SIGEV_SIGNAL 0
#define SIGEV_NONE 1
#define SIGEV_THREAD 2
#define SIGEV_THREAD_ID 4
#define SIGEV_MAX_SIZE 64
#define _SYS_TIME_H 1
#define ITIMER_REAL 0
#define ITIMER_VIRTUAL 1
#define ITIMER_PROF 2
#define PTRACE_TRACEME 0
#define PTRACE_PEEKTEXT 1
#define PTRACE_PEEKDATA 2
#define PTRACE_PEEKUSR 3
#define PTRACE_PEEKUSER 3
#define PTRACE_POKETEXT 4
#define PTRACE_POKEDATA 5
#define PTRACE_POKEUSR 6
#define PTRACE_POKEUSER 6
#define PTRACE_CONT 7
#define PTRACE_KILL 8
#define PTRACE_SINGLESTEP 9
#define PTRACE_ATTACH 0x10
#define PTRACE_DETACH 0x11
#define PTRACE_SYSCALL 24
#define PTRACE_GETEVENTMSG 0x4201
#define PTRACE_GETSIGINFO 0x4202
#define PTRACE_SETSIGINFO 0x4203
#define PTRACE_O_TRACESYSGOOD 0x00000001
#define PTRACE_O_TRACEFORK 0x00000002
#define PTRACE_O_TRACEVFORK 0x00000004
#define PTRACE_O_TRACECLONE 0x00000008
#define PTRACE_O_TRACEEXEC 0x00000010
#define PTRACE_O_TRACEVFORKDONE 0x00000020
#define PTRACE_O_TRACEEXIT 0x00000040
#define PTRACE_O_MASK 0x0000007f
#define PTRACE_EVENT_FORK 1
#define PTRACE_EVENT_VFORK 2
#define PTRACE_EVENT_CLONE 3
#define PTRACE_EVENT_EXEC 4
#define PTRACE_EVENT_VFORK_DONE 5
#define PTRACE_EVENT_EXIT 6
#define PT_TRACE_ME 0
#define PT_READ_I 1
#define PT_READ_D 2
#define PT_READ_U 3
#define PT_WRITE_I 4
#define PT_WRITE_D 5
#define PT_WRITE_U 6
#define PT_CONTINUE 7
#define PT_KILL 8
#define PT_STEP 9
#define PT_ATTACH 0x10
#define PT_DETACH 0x11
#define FD_SETSIZE 1024
#define R_OK 4
#define W_OK 2
#define X_OK 1
#define F_OK 0
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
#define STDIN_FILENO 0
#define STDOUT_FILENO 1
#define STDERR_FILENO 2
#define _CS_PATH 1
#define _SC_CLK_TCK 1
#define _SC_ARG_MAX 2
#define _SC_NGROUPS_MAX 3
#define _SC_OPEN_MAX 4
#define _SC_PAGESIZE 5
#define _SC_NPROCESSORS_ONLN 6
#define _SC_NPROCESSORS_CONF 6
#define _SC_PHYS_PAGES 7
#define _SC_GETPW_R_SIZE_MAX 8
#define _SC_GETGR_R_SIZE_MAX 9
#define _PC_PATH_MAX 1
#define _PC_VDISABLE 2
#define L_cuserid 17
#define _POSIX_VERSION 199506
#define F_ULOCK 0
#define F_LOCK 1
#define F_TLOCK 2
#define F_TEST 3
#define _POSIX_MAPPED_FILES 200809
#define S_IFMT 0xf000
#define S_IFSOCK 0xc000
#define S_IFLNK 0xa000
#define S_IFREG 0x8000
#define S_IFBLK 0x6000
#define S_IFDIR 0x4000
#define S_IFCHR 0x2000
#define S_IFIFO 0x1000
#define S_ISUID 0x800
#define S_ISGID 0x400
#define S_ISVTX 0x200
#define S_IRWXU 0x1c0
#define S_IRUSR 0x100
#define S_IWUSR 0x80
#define S_IXUSR 0x40
#define S_IRWXG 0x38
#define S_IRGRP 0x20
#define S_IWGRP 0x10
#define S_IXGRP 0x8
#define S_IRWXO 0x7
#define S_IROTH 0x4
#define S_IWOTH 0x2
#define S_IXOTH 0x1
#define S_IREAD 0x100
#define S_IWRITE 0x80
#define S_IEXEC 0x40
#define _SYS_UIO 1
#define SOL_SOCKET 1
#define SO_DEBUG 1
#define SO_REUSEADDR 2
#define SO_TYPE 3
#define SO_ERROR 4
#define SO_DONTROUTE 5
#define SO_BROADCAST 6
#define SO_SNDBUF 7
#define SO_RCVBUF 8
#define SO_KEEPALIVE 9
#define SO_OOBINLINE 10
#define SO_NO_CHECK 11
#define SO_PRIORITY 12
#define SO_LINGER 13
#define SO_BSDCOMPAT 14
#define SO_REUSEPORT 15
#define SO_PASSCRED 16
#define SO_PEERCRED 17
#define SO_RCVLOWAT 18
#define SO_SNDLOWAT 19
#define SO_RCVTIMEO 20
#define SO_SNDTIMEO 21
#define SO_SECURITY_AUTHENTICATION 22
#define SO_SECURITY_ENCRYPTION_TRANSPORT 23
#define SO_SECURITY_ENCRYPTION_NETWORK 24
#define SO_BINDTODEVICE 25
#define SO_ATTACH_FILTER 26
#define SO_DETACH_FILTER 27
#define SO_GET_FILTER 26
#define SO_PEERNAME 28
#define SO_TIMESTAMP 29
#define SCM_TIMESTAMP 29
#define SO_ACCEPTCONN 30
#define SO_PEERSEC 31
#define SO_SNDBUFFORCE 32
#define SO_RCVBUFFORCE 33
#define SO_PASSSEC 34
#define SO_TIMESTAMPNS 35
#define SCM_TIMESTAMPNS 35
#define SO_MARK 36
#define SO_TIMESTAMPING 37
#define SCM_TIMESTAMPING 37
#define SO_PROTOCOL 38
#define SO_DOMAIN 39
#define SO_RXQ_OVFL 40
#define SO_WIFI_STATUS 41
#define SCM_WIFI_STATUS 41
#define SO_PEEK_OFF 42
#define SO_NOFCS 43
#define SO_LOCK_FILTER 44
#define SO_SELECT_ERR_QUEUE 45
#define SO_BUSY_POLL 46
#define SO_MAX_PACING_RATE 47
#define SO_BPF_EXTENSIONS 48
#define SO_INCOMING_CPU 49
#define SO_ATTACH_BPF 50
#define SO_DETACH_BPF 27
#define SO_ATTACH_REUSEPORT_CBPF 51
#define SO_ATTACH_REUSEPORT_EBPF 52
#define SO_CNX_ADVICE 53
#define SCM_TIMESTAMPING_OPT_STATS 54
#define SO_MEMINFO 55
#define SO_INCOMING_NAPI_ID 56
#define SO_COOKIE 57
#define SCM_TIMESTAMPING_PKTINFO 58
#define SO_PEERGROUPS 59
#define SO_ZEROCOPY 60
#define SOCK_STREAM 1
#define SOCK_DGRAM 2
#define SOCK_RAW 3
#define SOCK_RDM 4
#define SOCK_SEQPACKET 5
#define SOCK_DCCP 6
#define SOCK_PACKET 10
#define UIO_FASTIOV 8
#define UIO_MAXIOV 1024
#define SCM_RIGHTS 0x01
#define SCM_CREDENTIALS 0x02
#define SCM_CONNECT 0x03
#define AF_UNSPEC 0
#define AF_UNIX 1
#define AF_LOCAL 1
#define AF_INET 2
#define AF_AX25 3
#define AF_IPX 4
#define AF_APPLETALK 5
#define AF_NETROM 6
#define AF_BRIDGE 7
#define AF_ATMPVC 8
#define AF_X25 9
#define AF_INET6 10
#define AF_ROSE 11
#define AF_DECnet 12
#define AF_NETBEUI 13
#define AF_SECURITY 14
#define AF_KEY 15
#define AF_NETLINK 16
#define AF_ROUTE 16
#define AF_PACKET 17
#define AF_ASH 18
#define AF_ECONET 19
#define AF_ATMSVC 20
#define AF_SNA 22
#define AF_IRDA 23
#define AF_PPPOX 24
#define AF_WANPIPE 25
#define AF_LLC 26
#define AF_IB 27
#define AF_MPLS 28
#define AF_CAN 29
#define AF_TIPC 30
#define AF_BLUETOOTH 31
#define AF_IUCV 32
#define AF_RXRPC 33
#define AF_ISDN 34
#define AF_PHONET 35
#define AF_IEEE802154 36
#define AF_CAIF 37
#define AF_ALG 38
#define AF_NFC 39
#define AF_VSOCK 40
#define AF_KCM 41
#define AF_QIPCRTR 42
#define AF_SMC 43
#define AF_MAX 44
#define PF_UNSPEC 0
#define PF_UNIX 1
#define PF_LOCAL 1
#define PF_INET 2
#define PF_AX25 3
#define PF_IPX 4
#define PF_APPLETALK 5
#define PF_NETROM 6
#define PF_BRIDGE 7
#define PF_ATMPVC 8
#define PF_X25 9
#define PF_INET6 10
#define PF_ROSE 11
#define PF_DECnet 12
#define PF_NETBEUI 13
#define PF_SECURITY 14
#define PF_KEY 15
#define PF_NETLINK 16
#define PF_ROUTE 16
#define PF_PACKET 17
#define PF_ASH 18
#define PF_ECONET 19
#define PF_ATMSVC 20
#define PF_SNA 22
#define PF_IRDA 23
#define PF_PPPOX 24
#define PF_WANPIPE 25
#define PF_LLC 26
#define PF_IB 27
#define PF_MPLS 28
#define PF_CAN 29
#define PF_TIPC 30
#define PF_BLUETOOTH 31
#define PF_IUCV 32
#define PF_RXRPC 33
#define PF_ISDN 34
#define PF_PHONET 35
#define PF_IEEE802154 36
#define PF_CAIF 37
#define PF_ALG 38
#define PF_NFC 39
#define PF_VSOCK 40
#define PF_KCM 41
#define PF_QIPCRTR 42
#define PF_SMC 43
#define PF_MAX 44
#define SOMAXCONN 128
#define MSG_OOB 1
#define MSG_PEEK 2
#define MSG_DONTROUTE 4
#define MSG_TRYHARD 4
#define MSG_CTRUNC 8
#define MSG_PROBE 0x10
#define MSG_TRUNC 0x20
#define MSG_DONTWAIT 0x40
#define MSG_EOR 0x80
#define MSG_WAITALL 0x100
#define MSG_FIN 0x200
#define MSG_SYN 0x400
#define MSG_CONFIRM 0x800
#define MSG_RST 0x1000
#define MSG_ERRQUEUE 0x2000
#define MSG_NOSIGNAL 0x4000
#define MSG_MORE 0x8000
#define MSG_WAITFORONE 0x10000
#define MSG_SENDPAGE_NOTLAST 0x20000
#define MSG_BATCH 0x40000
#define MSG_EOF 0x200
#define MSG_ZEROCOPY 0x4000000
#define MSG_FASTOPEN 0x20000000
#define MSG_CMSG_CLOEXEC 0x40000000
#define SOL_IP 0
#define SOL_TCP 6
#define SOL_UDP 17
#define SOL_IPV6 41
#define SOL_ICMPV6 58
#define SOL_SCTP 132
#define SOL_UDPLITE 136
#define SOL_RAW 255
#define SOL_IPX 256
#define SOL_AX25 257
#define SOL_ATALK 258
#define SOL_NETROM 259
#define SOL_ROSE 260
#define SOL_DECNET 261
#define SOL_X25 262
#define SOL_PACKET 263
#define SOL_ATM 264
#define SOL_AAL 265
#define SOL_IRDA 266
#define SOL_NETBEUI 267
#define SOL_LLC 268
#define SOL_DCCP 269
#define SOL_NETLINK 270
#define SOL_TIPC 271
#define SOL_RXRPC 272
#define SOL_PPPOL2TP 273
#define SOL_BLUETOOTH 274
#define SOL_PNPIPE 275
#define SOL_RDS 276
#define SOL_IUCV 277
#define SOL_CAIF 278
#define SOL_ALG 279
#define SOL_NFC 280
#define SOL_KCM 281
#define SOL_TLS 282
#define IPX_TYPE 1
#define SHUT_RD 0
#define SHUT_WR 1
#define SHUT_RDWR 2
#define NI_NOFQDN 1
#define NI_NUMERICHOST 2
#define NI_NAMEREQD 4
#define NI_NUMERICSERV 8
#define NI_DGRAM 16
#define EAI_FAMILY -1
#define EAI_SOCKTYPE -2
#define EAI_BADFLAGS -3
#define EAI_NONAME -4
#define EAI_SERVICE -5
#define EAI_ADDRFAMILY -6
#define EAI_NODATA -7
#define EAI_MEMORY -8
#define EAI_FAIL -9
#define EAI_AGAIN -10
#define EAI_SYSTEM -11
#define AI_NUMERICHOST 1
#define AI_CANONNAME 2
#define AI_PASSIVE 4
#define AI_NUMERICSERV 8
#define AI_ADDRCONFIG 16
#define AI_V4MAPPED 32
#define AI_ALL 64
#define SIOCADDRT 0x890B
#define SIOCDELRT 0x890C
#define SIOCRTMSG 0x890D
#define SIOCGIFNAME 0x8910
#define SIOCSIFLINK 0x8911
#define SIOCGIFCONF 0x8912
#define SIOCGIFFLAGS 0x8913
#define SIOCSIFFLAGS 0x8914
#define SIOCGIFADDR 0x8915
#define SIOCSIFADDR 0x8916
#define SIOCGIFDSTADDR 0x8917
#define SIOCSIFDSTADDR 0x8918
#define SIOCGIFBRDADDR 0x8919
#define SIOCSIFBRDADDR 0x891a
#define SIOCGIFNETMASK 0x891b
#define SIOCSIFNETMASK 0x891c
#define SIOCGIFMETRIC 0x891d
#define SIOCSIFMETRIC 0x891e
#define SIOCGIFMEM 0x891f
#define SIOCSIFMEM 0x8920
#define SIOCGIFMTU 0x8921
#define SIOCSIFMTU 0x8922
#define SIOCSIFNAME 0x8923
#define SIOCSIFHWADDR 0x8924
#define SIOCGIFENCAP 0x8925
#define SIOCSIFENCAP 0x8926
#define SIOCGIFHWADDR 0x8927
#define SIOCGIFSLAVE 0x8929
#define SIOCSIFSLAVE 0x8930
#define SIOCADDMULTI 0x8931
#define SIOCDELMULTI 0x8932
#define SIOCGIFINDEX 0x8933
#define SIOGIFINDEX 0x8933
#define SIOCSIFPFLAGS 0x8934
#define SIOCGIFPFLAGS 0x8935
#define SIOCDIFADDR 0x8936
#define SIOCSIFHWBROADCAST 0x8937
#define SIOCGIFCOUNT 0x8938
#define SIOCGIFBR 0x8940
#define SIOCSIFBR 0x8941
#define SIOCGIFTXQLEN 0x8942
#define SIOCSIFTXQLEN 0x8943
#define SIOCGIFDIVERT 0x8944
#define SIOCSIFDIVERT 0x8945
#define SIOCETHTOOL 0x8946
#define SIOCDARP 0x8953
#define SIOCGARP 0x8954
#define SIOCSARP 0x8955
#define SIOCDRARP 0x8960
#define SIOCGRARP 0x8961
#define SIOCSRARP 0x8962
#define SIOCGIFMAP 0x8970
#define SIOCSIFMAP 0x8971
#define SIOCADDDLCI 0x8980
#define SIOCDELDLCI 0x8981
#define SIOCDEVPRIVATE 0x89F0
#define F_LINUX_SPECIFIC_BASE 1024
#define O_ACCMODE 0x3
#define O_RDONLY 0x0
#define O_WRONLY 0x1
#define O_RDWR 0x2
#define O_CREAT 0x40
#define O_EXCL 0x80
#define O_NOCTTY 0x100
#define O_TRUNC 0x200
#define O_APPEND 0x400
#define O_NONBLOCK 0x800
#define O_NDELAY 0x800
#define O_DSYNC 0x1000
#define FASYNC 0x2000
#define O_DIRECT 0x4000
#define O_LARGEFILE 0x8000
#define O_DIRECTORY 0x10000
#define O_NOFOLLOW 0x20000
#define O_NOATIME 0x40000
#define O_CLOEXEC 0x80000
#define O_SYNC 0x101000
#define O_PATH 0x200000
#define __O_TMPFILE 0x400000
#define F_DUPFD 0
#define F_GETFD 1
#define F_SETFD 2
#define F_GETFL 3
#define F_SETFL 4
#define F_GETLK 5
#define F_SETLK 6
#define F_SETLKW 7
#define F_SETOWN 8
#define F_GETOWN 9
#define F_SETSIG 10
#define F_GETSIG 11
#define F_GETLK64 12
#define F_SETLK64 13
#define F_SETLKW64 14
#define FD_CLOEXEC 1
#define F_RDLCK 0
#define F_WRLCK 1
#define F_UNLCK 2
#define F_EXLCK 4
#define F_SHLCK 8
#define F_INPROGRESS 16
#define LOCK_SH 1
#define LOCK_EX 2
#define LOCK_NB 4
#define LOCK_UN 8
#define LOCK_MAND 32
#define LOCK_READ 64
#define LOCK_WRITE 128
#define LOCK_RW 192
#define O_TMPFILE 0x410000
#define O_ASYNC 0x2000
#define F_SETOWN_EX 15
#define F_GETOWN_EX 16
#define F_GETOWNER_UIDS 17
#define F_OFD_GETLK 36
#define F_OFD_SETLK 37
#define F_OFD_SETLKW 38
#define F_OWNER_TID 0
#define F_OWNER_PID 1
#define F_OWNER_PGRP 2
#define AT_FDCWD -100
#define AT_SYMLINK_NOFOLLOW 0x100
#define AT_REMOVEDIR 0x200
#define AT_SYMLINK_FOLLOW 0x400
#define AT_NO_AUTOMOUNT 0x800
#define AT_EMPTY_PATH 0x1000
#define AT_EACCESS 0x200
#define MREMAP_MAYMOVE 1
#define MREMAP_FIXED 2
#define PROT_READ 0x1
#define PROT_WRITE 0x2
#define PROT_EXEC 0x4
#define PROT_SEM 0x8
#define PROT_NONE 0x0
#define PROT_GROWSDOWN 0x01000000
#define PROT_GROWSUP 0x02000000
#define MAP_SHARED 0x01
#define MAP_PRIVATE 0x02
#define MAP_TYPE 0xf
#define MADV_REMOVE 9
#define MADV_DONTFORK 10
#define MADV_DOFORK 11
#define MADV_MERGEABLE 12
#define MADV_UNMERGEABLE 13
#define MADV_HUGEPAGE 14
#define MADV_NOHUGEPAGE 15
#define MADV_DONTDUMP 16
#define MADV_DODUMP 17
#define MADV_HWPOISON 100
#define MADV_SOFT_OFFLINE 101
#define MLOCK_ONFAULT 1
#define MAP_FIXED 0x10
#define MAP_ANONYMOUS 0x20
#define MAP_GROWSDOWN 0x0100
#define MAP_GROWSUP 0x0200
#define MAP_DENYWRITE 0x0800
#define MAP_EXECUTABLE 0x1000
#define MAP_LOCKED 0x2000
#define MAP_NORESERVE 0x4000
#define MAP_POPULATE 0x8000
#define MAP_NONBLOCK 0x10000
#define MAP_STACK 0x20000
#define MAP_HUGETLB 0x40000
#define MS_ASYNC 1
#define MS_INVALIDATE 2
#define MS_SYNC 4
#define MADV_NORMAL 0x0
#define MADV_RANDOM 0x1
#define MADV_SEQUENTIAL 0x2
#define MADV_WILLNEED 0x3
#define MADV_DONTNEED 0x4
#define MAP_ANON 0x20
#define MAP_FILE 0
#define POSIX_MADV_NORMAL 0x0
#define POSIX_MADV_SEQUENTIAL 0x2
#define POSIX_MADV_RANDOM 0x1
#define POSIX_MADV_WILLNEED 0x3
#define POSIX_MADV_DONTNEED 0x4
#define SYS_accept (1024 + 170)
#define SYS_accept4 (1024 + 310)
#define SYS_access (1024 + 25)
#define SYS_acct (1024 + 40)
#define SYS_add_key (1024 + 247)
#define SYS_adjtimex (1024 + 107)
#define SYS_afs_syscall (1024 + 117)
#define SYS_bdflush (1024 + 114)
#define SYS_bind (1024 + 167)
#define SYS_bpf (1024 + 317)
#define SYS_brk (1024 + 36)
#define SYS_capget (1024 + 161)
#define SYS_capset (1024 + 162)
#define SYS_chdir (1024 + 10)
#define SYS_chmod (1024 + 14)
#define SYS_chown (1024 + 15)
#define SYS_chroot (1024 + 44)
#define SYS_clock_adjtime (1024 + 304)
#define SYS_clock_getres (1024 + 231)
#define SYS_clock_gettime (1024 + 230)
#define SYS_clock_nanosleep (1024 + 232)
#define SYS_clock_settime (1024 + 229)
#define SYS_clone (1024 + 104)
#define SYS_clone2 (1024 + 189)
#define SYS_close (1024 + 5)
#define SYS_connect (1024 + 168)
#define SYS_copy_file_range (1024 + 323)
#define SYS_creat (1024 + 6)
#define SYS_delete_module (1024 + 110)
#define SYS_dup (1024 + 33)
#define SYS_dup2 (1024 + 46)
#define SYS_dup3 (1024 + 292)
#define SYS_epoll_create (1024 + 219)
#define SYS_epoll_create1 (1024 + 291)
#define SYS_epoll_ctl (1024 + 220)
#define SYS_epoll_pwait (1024 + 281)
#define SYS_epoll_wait (1024 + 221)
#define SYS_eventfd (1024 + 285)
#define SYS_eventfd2 (1024 + 290)
#define SYS_execve (1024 + 9)
#define SYS_execveat (1024 + 318)
#define SYS_exit (1024 + 1)
#define SYS_exit_group (1024 + 212)
#define SYS_faccessat (1024 + 269)
#define SYS_fadvise64 (1024 + 210)
#define SYS_fallocate (1024 + 279)
#define SYS_fanotify_init (1024 + 299)
#define SYS_fanotify_mark (1024 + 300)
#define SYS_fchdir (1024 + 11)
#define SYS_fchmod (1024 + 75)
#define SYS_fchmodat (1024 + 268)
#define SYS_fchown (1024 + 76)
#define SYS_fchownat (1024 + 260)
#define SYS_fcntl (1024 + 42)
#define SYS_fdatasync (1024 + 28)
#define SYS_fgetxattr (1024 + 198)
#define SYS_finit_module (1024 + 311)
#define SYS_flistxattr (1024 + 201)
#define SYS_flock (1024 + 121)
#define SYS_fremovexattr (1024 + 204)
#define SYS_fsconfig (1024 + 431)
#define SYS_fsetxattr (1024 + 195)
#define SYS_fsmount (1024 + 432)
#define SYS_fsopen (1024 + 430)
#define SYS_fspick (1024 + 433)
#define SYS_fstat (1024 + 188)
#define SYS_fstatfs (1024 + 80)
#define SYS_fstatfs64 (1024 + 233)
#define SYS_fsync (1024 + 27)
#define SYS_ftruncate (1024 + 74)
#define SYS_futex (1024 + 206)
#define SYS_futimesat (1024 + 261)
#define SYS_getcpu (1024 + 280)
#define SYS_getcwd (1024 + 160)
#define SYS_getdents (1024 + 120)
#define SYS_getdents64 (1024 + 190)
#define SYS_getegid (1024 + 39)
#define SYS_geteuid (1024 + 23)
#define SYS_getgid (1024 + 38)
#define SYS_getgroups (1024 + 53)
#define SYS_getitimer (1024 + 95)
#define SYS_get_mempolicy (1024 + 236)
#define SYS_getpeername (1024 + 172)
#define SYS_getpgid (1024 + 55)
#define SYS_getpid (1024 + 17)
#define SYS_getpmsg (1024 + 164)
#define SYS_getppid (1024 + 18)
#define SYS_getpriority (1024 + 77)
#define SYS_getrandom (1024 + 315)
#define SYS_getresgid (1024 + 51)
#define SYS_getresuid (1024 + 49)
#define SYS_getrlimit (1024 + 61)
#define SYS_get_robust_list (1024 + 275)
#define SYS_getrusage (1024 + 62)
#define SYS_getsid (1024 + 58)
#define SYS_getsockname (1024 + 171)
#define SYS_getsockopt (1024 + 180)
#define SYS_gettid (1024 + 81)
#define SYS_gettimeofday (1024 + 63)
#define SYS_getuid (1024 + 22)
#define SYS_getunwind (1024 + 191)
#define SYS_getxattr (1024 + 196)
#define SYS_init_module (1024 + 109)
#define SYS_inotify_add_watch (1024 + 254)
#define SYS_inotify_init (1024 + 253)
#define SYS_inotify_init1 (1024 + 294)
#define SYS_inotify_rm_watch (1024 + 255)
#define SYS_io_cancel (1024 + 218)
#define SYS_ioctl (1024 + 41)
#define SYS_io_destroy (1024 + 215)
#define SYS_io_getevents (1024 + 216)
#define SYS_io_pgetevents (1024 + 327)
#define SYS_ioprio_get (1024 + 251)
#define SYS_ioprio_set (1024 + 250)
#define SYS_io_setup (1024 + 214)
#define SYS_io_submit (1024 + 217)
#define SYS_io_uring_enter (1024 + 426)
#define SYS_io_uring_register (1024 + 427)
#define SYS_io_uring_setup (1024 + 425)
#define SYS_kcmp (1024 + 321)
#define SYS_kexec_load (1024 + 244)
#define SYS_keyctl (1024 + 249)
#define SYS_kill (1024 + 29)
#define SYS_lchown (1024 + 100)
#define SYS_lgetxattr (1024 + 197)
#define SYS_link (1024 + 7)
#define SYS_linkat (1024 + 265)
#define SYS_Linux 1024
#define SYS_listen (1024 + 169)
#define SYS_listxattr (1024 + 199)
#define SYS_llistxattr (1024 + 200)
#define SYS_lookup_dcookie (1024 + 213)
#define SYS_lremovexattr (1024 + 203)
#define SYS_lseek (1024 + 16)
#define SYS_lsetxattr (1024 + 194)
#define SYS_lstat (1024 + 187)
#define SYS_madvise (1024 + 185)
#define SYS_mbind (1024 + 235)
#define SYS_membarrier (1024 + 320)
#define SYS_memfd_create (1024 + 316)
#define SYS_migrate_pages (1024 + 256)
#define SYS_mincore (1024 + 184)
#define SYS_mkdir (1024 + 31)
#define SYS_mkdirat (1024 + 258)
#define SYS_mknod (1024 + 13)
#define SYS_mknodat (1024 + 259)
#define SYS_mlock (1024 + 129)
#define SYS_mlock2 (1024 + 322)
#define SYS_mlockall (1024 + 130)
#define SYS_mmap (1024 + 127)
#define SYS_mmap2 (1024 + 148)
#define SYS_mount (1024 + 19)
#define SYS_move_mount (1024 + 429)
#define SYS_move_pages (1024 + 252)
#define SYS_mprotect (1024 + 131)
#define SYS_mq_getsetattr (1024 + 243)
#define SYS_mq_notify (1024 + 242)
#define SYS_mq_open (1024 + 238)
#define SYS_mq_timedreceive (1024 + 241)
#define SYS_mq_timedsend (1024 + 240)
#define SYS_mq_unlink (1024 + 239)
#define SYS_mremap (1024 + 132)
#define SYS_msgctl (1024 + 88)
#define SYS_msgget (1024 + 85)
#define SYS_msgrcv (1024 + 87)
#define SYS_msgsnd (1024 + 86)
#define SYS_msync (1024 + 133)
#define SYS_munlock (1024 + 134)
#define SYS_munlockall (1024 + 135)
#define SYS_munmap (1024 + 128)
#define SYS_name_to_handle_at (1024 + 302)
#define SYS_nanosleep (1024 + 144)
#define SYS_newfstatat (1024 + 262)
#define SYS_nfsservctl (1024 + 145)
#define SYS_ni_syscall (1024 + 0)
#define SYS_old_getpagesize (1024 + 147)
#define SYS_open (1024 + 4)
#define SYS_openat (1024 + 257)
#define SYS_openat2 (1024 + 437)
#define SYS_open_by_handle_at (1024 + 303)
#define SYS_open_tree (1024 + 428)
#define SYS_pciconfig_read (1024 + 149)
#define SYS_pciconfig_write (1024 + 150)
#define SYS_perf_event_open (1024 + 328)
#define SYS_perfmonctl (1024 + 151)
#define SYS_personality (1024 + 116)
#define SYS_pidfd_getfd (1024 + 438)
#define SYS_pidfd_open (1024 + 434)
#define SYS_pidfd_send_signal (1024 + 424)
#define SYS_pipe (1024 + 34)
#define SYS_pipe2 (1024 + 293)
#define SYS_pivot_root (1024 + 183)
#define SYS_pkey_alloc (1024 + 331)
#define SYS_pkey_free (1024 + 332)
#define SYS_pkey_mprotect (1024 + 330)
#define SYS_poll (1024 + 66)
#define SYS_ppoll (1024 + 271)
#define SYS_prctl (1024 + 146)
#define SYS_pread64 (1024 + 124)
#define SYS_preadv (1024 + 295)
#define SYS_preadv2 (1024 + 324)
#define SYS_prlimit64 (1024 + 301)
#define SYS_process_vm_readv (1024 + 308)
#define SYS_process_vm_writev (1024 + 309)
#define SYS_pselect6 (1024 + 270)
#define SYS_ptrace (1024 + 24)
#define SYS_putpmsg (1024 + 165)
#define SYS_pwrite64 (1024 + 125)
#define SYS_pwritev (1024 + 296)
#define SYS_pwritev2 (1024 + 325)
#define SYS_quotactl (1024 + 113)
#define SYS_read (1024 + 2)
#define SYS_readahead (1024 + 192)
#define SYS_readlink (1024 + 68)
#define SYS_readlinkat (1024 + 267)
#define SYS_readv (1024 + 122)
#define SYS_reboot (1024 + 72)
#define SYS_recv (1024 + 176)
#define SYS_recvfrom (1024 + 177)
#define SYS_recvmmsg (1024 + 298)
#define SYS_recvmsg (1024 + 182)
#define SYS_remap_file_pages (1024 + 101)
#define SYS_removexattr (1024 + 202)
#define SYS_rename (1024 + 30)
#define SYS_renameat (1024 + 264)
#define SYS_renameat2 (1024 + 314)
#define SYS_request_key (1024 + 248)
#define SYS_restart_syscall (1024 + 222)
#define SYS_rmdir (1024 + 32)
#define SYS_rseq (1024 + 333)
#define SYS_rt_sigaction (1024 + 153)
#define SYS_rt_sigpending (1024 + 154)
#define SYS_rt_sigprocmask (1024 + 155)
#define SYS_rt_sigqueueinfo (1024 + 156)
#define SYS_rt_sigreturn (1024 + 157)
#define SYS_rt_sigsuspend (1024 + 158)
#define SYS_rt_sigtimedwait (1024 + 159)
#define SYS_rt_tgsigqueueinfo (1024 + 297)
#define SYS_sched_getaffinity (1024 + 208)
#define SYS_sched_getattr (1024 + 313)
#define SYS_sched_getparam (1024 + 136)
#define SYS_sched_get_priority_max (1024 + 141)
#define SYS_sched_get_priority_min (1024 + 142)
#define SYS_sched_getscheduler (1024 + 138)
#define SYS_sched_rr_get_interval (1024 + 143)
#define SYS_sched_setaffinity (1024 + 207)
#define SYS_sched_setattr (1024 + 312)
#define SYS_sched_setparam (1024 + 137)
#define SYS_sched_setscheduler (1024 + 139)
#define SYS_sched_yield (1024 + 140)
#define SYS_seccomp (1024 + 329)
#define SYS_select (1024 + 65)
#define SYS_semctl (1024 + 84)
#define SYS_semget (1024 + 82)
#define SYS_semop (1024 + 83)
#define SYS_semtimedop (1024 + 223)
#define SYS_send (1024 + 174)
#define SYS_sendfile (1024 + 163)
#define SYS_sendmmsg (1024 + 307)
#define SYS_sendmsg (1024 + 181)
#define SYS_sendto (1024 + 175)
#define SYS_setdomainname (1024 + 105)
#define SYS_setfsgid (1024 + 119)
#define SYS_setfsuid (1024 + 118)
#define SYS_setgid (1024 + 37)
#define SYS_setgroups (1024 + 54)
#define SYS_sethostname (1024 + 59)
#define SYS_setitimer (1024 + 94)
#define SYS_set_mempolicy (1024 + 237)
#define SYS_setns (1024 + 306)
#define SYS_setpgid (1024 + 56)
#define SYS_setpriority (1024 + 78)
#define SYS_setregid (1024 + 48)
#define SYS_setresgid (1024 + 52)
#define SYS_setresuid (1024 + 50)
#define SYS_setreuid (1024 + 47)
#define SYS_setrlimit (1024 + 60)
#define SYS_set_robust_list (1024 + 274)
#define SYS_setsid (1024 + 57)
#define SYS_setsockopt (1024 + 179)
#define SYS_set_tid_address (1024 + 209)
#define SYS_settimeofday (1024 + 64)
#define SYS_setuid (1024 + 21)
#define SYS_setxattr (1024 + 193)
#define SYS_shmat (1024 + 90)
#define SYS_shmctl (1024 + 92)
#define SYS_shmdt (1024 + 91)
#define SYS_shmget (1024 + 89)
#define SYS_shutdown (1024 + 178)
#define SYS_sigaltstack (1024 + 152)
#define SYS_signalfd (1024 + 283)
#define SYS_signalfd4 (1024 + 289)
#define SYS_socket (1024 + 166)
#define SYS_socketpair (1024 + 173)
#define SYS_splice (1024 + 273)
#define SYS_stat (1024 + 186)
#define SYS_statfs (1024 + 79)
#define SYS_statfs64 (1024 + 234)
#define SYS_statx (1024 + 326)
#define SYS_swapoff (1024 + 71)
#define SYS_swapon (1024 + 70)
#define SYS_symlink (1024 + 67)
#define SYS_symlinkat (1024 + 266)
#define SYS_sync (1024 + 26)
#define SYS_sync_file_range (1024 + 276)
#define SYS_syncfs (1024 + 305)
#define SYS__sysctl (1024 + 126)
#define SYS_sysfs (1024 + 115)
#define SYS_sysinfo (1024 + 103)
#define SYS_syslog (1024 + 93)
#define SYS_tee (1024 + 277)
#define SYS_tgkill (1024 + 211)
#define SYS_timer_create (1024 + 224)
#define SYS_timer_delete (1024 + 228)
#define SYS_timerfd (1024 + 284)
#define SYS_timerfd_create (1024 + 286)
#define SYS_timerfd_gettime (1024 + 288)
#define SYS_timerfd_settime (1024 + 287)
#define SYS_timer_getoverrun (1024 + 227)
#define SYS_timer_gettime (1024 + 226)
#define SYS_timer_settime (1024 + 225)
#define SYS_times (1024 + 35)
#define SYS_tkill (1024 + 205)
#define SYS_truncate (1024 + 73)
#define SYS_umask (1024 + 43)
#define SYS_umount2 (1024 + 20)
#define SYS_uname (1024 + 106)
#define SYS_unlink (1024 + 8)
#define SYS_unlinkat (1024 + 263)
#define SYS_unshare (1024 + 272)
#define SYS_uselib (1024 + 69)
#define SYS_userfaultfd (1024 + 319)
#define SYS_ustat (1024 + 45)
#define SYS_utimensat (1024 + 282)
#define SYS_utimes (1024 + 12)
#define SYS_vhangup (1024 + 99)
#define SYS_vmsplice (1024 + 278)
#define SYS_vserver (1024 + 245)
#define SYS_wait4 (1024 + 102)
#define SYS_waitid (1024 + 246)
#define SYS_write (1024 + 3)
#define SYS_writev (1024 + 123)
